@@ -26,7 +26,7 @@ namespace cli {
  */
 template<typename T>
 std::string GetPrintableParamValue(
-    const util::ParamData& /* data */,
+    util::ParamData& /* data */,
     const std::string& input,
     const typename boost::disable_if<arma::is_arma_type<T>>::type*,
     const typename boost::disable_if<data::HasSerialize<T>>::type*,
@@ -42,7 +42,7 @@ std::string GetPrintableParamValue(
  */
 template<typename T>
 std::string GetPrintableParamValue(
-    const util::ParamData& /* data */,
+    util::ParamData& /* data */,
     const std::string& input,
     const typename boost::enable_if<arma::is_arma_type<T>>::type*)
 {
@@ -55,7 +55,7 @@ std::string GetPrintableParamValue(
  */
 template<typename T>
 std::string GetPrintableParamValue(
-    const util::ParamData& /* data */,
+    util::ParamData& /* data */,
     const std::string& input,
     const typename boost::disable_if<arma::is_arma_type<T>>::type*,
     const typename boost::enable_if<data::HasSerialize<T>>::type*)
@@ -69,7 +69,7 @@ std::string GetPrintableParamValue(
  */
 template<typename T>
 std::string GetPrintableParamValue(
-    const util::ParamData& /* data */,
+    util::ParamData& /* data */,
     const std::string& input,
     const typename boost::enable_if<std::is_same<T,
         std::tuple<data::DatasetInfo, arma::mat>>>::type*)
