@@ -22,7 +22,7 @@ namespace julia {
  */
 template<typename T>
 std::string GetPrintableType(
-    const util::ParamData& data,
+    util::ParamData& data,
     const typename boost::disable_if<arma::is_arma_type<T>>::type* = 0,
     const typename boost::disable_if<util::IsStdVector<T>>::type* = 0,
     const typename boost::disable_if<data::HasSerialize<T>>::type* = 0,
@@ -34,7 +34,7 @@ std::string GetPrintableType(
  */
 template<typename T>
 std::string GetPrintableType(
-    const util::ParamData& data,
+    util::ParamData& data,
     const typename std::enable_if<util::IsStdVector<T>::value>::type* = 0);
 
 /**
@@ -42,7 +42,7 @@ std::string GetPrintableType(
  */
 template<typename T>
 std::string GetPrintableType(
-    const util::ParamData& data,
+    util::ParamData& data,
     const typename std::enable_if<arma::is_arma_type<T>::value>::type* = 0);
 
 /**
@@ -50,7 +50,7 @@ std::string GetPrintableType(
  */
 template<typename T>
 std::string GetPrintableType(
-    const util::ParamData& data,
+    util::ParamData& data,
     const typename std::enable_if<std::is_same<T,
         std::tuple<data::DatasetInfo, arma::mat>>::value>::type* = 0);
 
@@ -59,7 +59,7 @@ std::string GetPrintableType(
  */
 template<typename T>
 std::string GetPrintableType(
-    const util::ParamData& data,
+    util::ParamData& data,
     const typename boost::disable_if<arma::is_arma_type<T>>::type* = 0,
     const typename boost::enable_if<data::HasSerialize<T>>::type* = 0);
 
@@ -67,7 +67,7 @@ std::string GetPrintableType(
  * Print the command-line type of an option into a string.
  */
 template<typename T>
-void GetPrintableType(const util::ParamData& data,
+void GetPrintableType(util::ParamData& data,
                        const void* /* input */,
                        void* output)
 {
