@@ -17,14 +17,15 @@ namespace bindings {
 namespace julia {
 
 template<typename T>
-void PrintDoc(const util::ParamData& d, const void* /* input */, void* output)
+void PrintDoc(util::ParamData& d, const void* /* input */, void* output)
 {
   // "type" is a reserved keyword or function.
   const std::string juliaName = (d.name == "type") ? "type_" : d.name;
 
   std::ostringstream& oss = *((std::ostringstream*) output);
 
-  oss << "`" << juliaName << "::" << GetJuliaType<T>(d) << "`: " << d.desc;
+  oss << "`" << juliaName << "::" << GetJuliaType<typename std::remove_pointer
+      <T>::type>(d) << "`: " << d.desc;
 
   // Print a default, if possible.  Defaults aren't printed for matrix or model
   // parameters.
