@@ -17,12 +17,12 @@ namespace bindings {
 namespace julia {
 
 /**
- * Print the input processing (basically calling CLI::GetParam<>()) for a
+ * Print the input processing (basically calling IO::GetParam<>()) for a
  * non-serializable type.
  */
 template<typename T>
 void PrintInputProcessing(
-    const util::ParamData& d,
+    util::ParamData& d,
     const std::string& functionName,
     const typename std::enable_if<!data::HasSerialize<T>::value>::type* = 0,
     const typename std::enable_if<!std::is_same<T,
@@ -33,7 +33,7 @@ void PrintInputProcessing(
  */
 template<typename T>
 void PrintInputProcessing(
-    const util::ParamData& d,
+    util::ParamData& d,
     const std::string& functionName,
     const typename std::enable_if<arma::is_arma_type<T>::value>::type* = 0,
     const typename std::enable_if<!std::is_same<T,
@@ -44,7 +44,7 @@ void PrintInputProcessing(
  */
 template<typename T>
 void PrintInputProcessing(
-    const util::ParamData& d,
+    util::ParamData& d,
     const std::string& functionName,
     const typename std::enable_if<!arma::is_arma_type<T>::value>::type* = 0,
     const typename std::enable_if<data::HasSerialize<T>::value>::type* = 0,
@@ -52,21 +52,21 @@ void PrintInputProcessing(
         std::tuple<data::DatasetInfo, arma::mat>>::value>::type* = 0);
 
 /**
- * Print the input processing (basically calling CLI::GetParam<>()) for a
+ * Print the input processing (basically calling IO::GetParam<>()) for a
  * matrix with DatasetInfo type.
  */
 template<typename T>
 void PrintInputProcessing(
-    const util::ParamData& d,
+    util::ParamData& d,
     const std::string& functionName,
     const typename std::enable_if<std::is_same<T,
         std::tuple<data::DatasetInfo, arma::mat>>::value>::type* = 0);
 
 /**
- * Print the input processing (basically calling CLI::GetParam<>()) for a type.
+ * Print the input processing (basically calling IO::GetParam<>()) for a type.
  */
 template<typename T>
-void PrintInputProcessing(const util::ParamData& d,
+void PrintInputProcessing(util::ParamData& d,
                           const void* input,
                           void* /* output */)
 {
