@@ -19,12 +19,12 @@ namespace bindings {
 namespace julia {
 
 /**
- * Print the output processing (basically calling CLI::GetParam<>()) for a
+ * Print the output processing (basically calling IO::GetParam<>()) for a
  * non-serializable type.
  */
 template<typename T>
 void PrintOutputProcessing(
-    const util::ParamData& d,
+    util::ParamData& d,
     const std::string& functionName,
     const typename std::enable_if<!data::HasSerialize<T>::value>::type* = 0,
     const typename std::enable_if<!std::is_same<T,
@@ -35,7 +35,7 @@ void PrintOutputProcessing(
  */
 template<typename T>
 void PrintOutputProcessing(
-    const util::ParamData& d,
+    util::ParamData& d,
     const std::string& functionName,
     const typename std::enable_if<arma::is_arma_type<T>::value>::type* = 0,
     const typename std::enable_if<!std::is_same<T,
@@ -46,7 +46,7 @@ void PrintOutputProcessing(
  */
 template<typename T>
 void PrintOutputProcessing(
-    const util::ParamData& d,
+    util::ParamData& d,
     const std::string& functionName,
     const typename std::enable_if<!arma::is_arma_type<T>::value>::type* = 0,
     const typename std::enable_if<data::HasSerialize<T>::value>::type* = 0,
@@ -58,16 +58,16 @@ void PrintOutputProcessing(
  */
 template<typename T>
 void PrintOutputProcessing(
-    const util::ParamData& d,
+    util::ParamData& d,
     const std::string& functionName,
     const typename std::enable_if<std::is_same<T,
         std::tuple<data::DatasetInfo, arma::mat>>::value>::type* = 0);
 
 /**
- * Print the output processing (basically calling CLI::GetParam<>()) for a type.
+ * Print the output processing (basically calling IO::GetParam<>()) for a type.
  */
 template<typename T>
-void PrintOutputProcessing(const util::ParamData& d,
+void PrintOutputProcessing(util::ParamData& d,
                            const void* input,
                            void* /* output */)
 {
