@@ -25,7 +25,7 @@ namespace python {
  */
 template<typename T>
 std::string DefaultParamImpl(
-    const util::ParamData& data,
+    util::ParamData& data,
     const typename boost::disable_if<arma::is_arma_type<T>>::type* = 0,
     const typename boost::disable_if<util::IsStdVector<T>>::type* = 0,
     const typename boost::disable_if<data::HasSerialize<T>>::type* = 0,
@@ -38,7 +38,7 @@ std::string DefaultParamImpl(
  */
 template<typename T>
 std::string DefaultParamImpl(
-    const util::ParamData& data,
+    util::ParamData& data,
     const typename boost::enable_if<util::IsStdVector<T>>::type* = 0);
 
 /**
@@ -46,7 +46,7 @@ std::string DefaultParamImpl(
  */
 template<typename T>
 std::string DefaultParamImpl(
-    const util::ParamData& data,
+    util::ParamData& data,
     const typename boost::enable_if<std::is_same<T, std::string>>::type* = 0);
 
 /**
@@ -56,7 +56,7 @@ std::string DefaultParamImpl(
  */
 template<typename T>
 std::string DefaultParamImpl(
-    const util::ParamData& data,
+    util::ParamData& data,
     const typename boost::enable_if_c<
         arma::is_arma_type<T>::value ||
         std::is_same<T, std::tuple<mlpack::data::DatasetInfo,
@@ -68,16 +68,16 @@ std::string DefaultParamImpl(
  */
 template<typename T>
 std::string DefaultParamImpl(
-    const util::ParamData& data,
+    util::ParamData& data,
     const typename boost::disable_if<arma::is_arma_type<T>>::type* = 0,
     const typename boost::enable_if<data::HasSerialize<T>>::type* = 0);
 
 /**
  * Return the default value of an option.  This is the function that will be
- * placed into the CLI functionMap.
+ * placed into the IO functionMap.
  */
 template<typename T>
-void DefaultParam(const util::ParamData& data,
+void DefaultParam(util::ParamData& data,
                   const void* /* input */,
                   void* output)
 {
