@@ -1,6 +1,7 @@
 /**
  * @file core/cv/metrics/facilities.hpp
  * @author Kirill Mishchenko
+ * @author Khizir Siddiqui
  *
  * Functionality that is used more than in one metric.
  *
@@ -13,6 +14,7 @@
 #define MLPACK_CORE_CV_METRICS_FACILITIES_HPP
 
 #include <mlpack/core.hpp>
+#include <mlpack/core/metrics/lmetric.hpp>
 
 namespace mlpack {
 namespace cv {
@@ -40,6 +42,29 @@ void AssertSizes(const DataType& data,
   }
 }
 
+/**
+  * Pairwise distance of the given data.
+  *
+  * @param data Column-major matrix.
+  * @param metric Distance metric to be used.
+  */
+template<typename DataType, typename Metric>
+DataType PairwiseDistances(const DataType& data,
+                           const Metric& metric)
+{
+  DataType distances = DataType(data.n_cols, data.n_cols, arma::fill::none);
+  for (size_t i = 0; i < data.n_cols; i++)
+  {
+    for (size_t j = 0; j < i; j++)
+    {
+      distances(i, j) = metric.Evaluate(data.col(i), data.col(j));
+      distances(j, i) = distances(i, j);
+    }
+  }
+  distances.diag().zeros();
+  return distances;
+}
+
 } // namespace cv
 } // namespace mlpack
 
