@@ -40,22 +40,12 @@ class GreedySingleTreeTraverser
   //! Get the number of prunes.
   size_t NumPrunes() const { return numPrunes; }
 
-  //! Set value of minBaseCases.
-  size_t& MinBaseCases() { return minBaseCases; }
-
-  //! Get value of minBaseCases.
-  size_t MinBaseCases() const { return minBaseCases; }
-
  private:
   //! Reference to the rules with which the tree will be traversed.
   RuleType& rule;
 
   //! The number of nodes which have been pruned during traversal.
   size_t numPrunes;
-
-  //! The number of base cases required. For example the number of nearest
-  //! neighbours(k) in case of knn.
-  size_t minBaseCases;
 };
 
 } // namespace tree
