@@ -15,7 +15,6 @@
 // In case it wasn't included already for some reason.
 #include "rectangle_tree.hpp"
 
-#include <mlpack/core/util/cli.hpp>
 #include <mlpack/core/util/log.hpp>
 
 namespace mlpack {
@@ -74,7 +73,7 @@ RectangleTree(const MatType& data,
   // For now, just insert the points in order.
   RectangleTree* root = this;
 
-  for (size_t i = firstDataIndex; i < data.n_cols; i++)
+  for (size_t i = firstDataIndex; i < data.n_cols; ++i)
     root->InsertPoint(i);
 
   // Initialize statistic recursively after tree construction is complete.
@@ -115,7 +114,7 @@ RectangleTree(MatType&& data,
   // For now, just insert the points in order.
   RectangleTree* root = this;
 
-  for (size_t i = firstDataIndex; i < dataset->n_cols; i++)
+  for (size_t i = firstDataIndex; i < dataset->n_cols; ++i)
     root->InsertPoint(i);
 
   // Initialize statistic recursively after tree construction is complete.
@@ -196,7 +195,7 @@ RectangleTree(
   {
     if (numChildren > 0)
     {
-      for (size_t i = 0; i < numChildren; i++)
+      for (size_t i = 0; i < numChildren; ++i)
         children[i] = new RectangleTree(other.Child(i), true, this);
     }
   }
@@ -244,7 +243,7 @@ RectangleTree(RectangleTree&& other) :
   }
   if (!IsLeaf())
   {
-    for (size_t i = 0; i < numChildren; i++)
+    for (size_t i = 0; i < numChildren; ++i)
       children[i]->parent = this;
   }
   // Now we are a clone of the other tree.  But we must also clear the other
@@ -283,7 +282,7 @@ operator=(const RectangleTree& other)
     return *this;
 
   // Freeing memory that will not be used anymore.
-  for (size_t i = 0; i < numChildren; i++)
+  for (size_t i = 0; i < numChildren; ++i)
     delete children[i];
 
   if (ownsDataset)
@@ -309,7 +308,7 @@ operator=(const RectangleTree& other)
 
   if (numChildren > 0)
   {
-    for (size_t i = 0; i < numChildren; i++)
+    for (size_t i = 0; i < numChildren; ++i)
       children[i] = new RectangleTree(other.Child(i), true, this);
   }
 
@@ -336,7 +335,7 @@ operator=(RectangleTree&& other)
     return *this;
 
   // Freeing memory that will not be used anymore.
-  for (size_t i = 0; i < numChildren; i++)
+  for (size_t i = 0; i < numChildren; ++i)
     delete children[i];
 
   if (ownsDataset)
@@ -414,7 +413,7 @@ RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
               AuxiliaryInformationType>::
 ~RectangleTree()
 {
-  for (size_t i = 0; i < numChildren; i++)
+  for (size_t i = 0; i < numChildren; ++i)
     delete children[i];
 
   if (ownsDataset)
@@ -437,7 +436,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
 {
   parent = NULL;
 
-  for (size_t i = 0; i < children.size(); i++)
+  for (size_t i = 0; i < children.size(); ++i)
     children[i] = NULL;
 
   numChildren = 0;
@@ -597,7 +596,7 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
 
   if (numChildren == 0)
   {
-    for (size_t i = 0; i < count; i++)
+    for (size_t i = 0; i < count; ++i)
     {
       if (points[i] == point)
       {
@@ -617,7 +616,7 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
     }
   }
 
-  for (size_t i = 0; i < numChildren; i++)
+  for (size_t i = 0; i < numChildren; ++i)
     if (children[i]->Bound().Contains(dataset->col(point)))
       if (children[i]->DeletePoint(point, lvls))
         return true;
@@ -641,7 +640,7 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
 {
   if (numChildren == 0)
   {
-    for (size_t i = 0; i < count; i++)
+    for (size_t i = 0; i < count; ++i)
     {
       if (points[i] == point)
       {
@@ -661,7 +660,7 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
     }
   }
 
-  for (size_t i = 0; i < numChildren; i++)
+  for (size_t i = 0; i < numChildren; ++i)
     if (children[i]->Bound().Contains(dataset->col(point)))
       if (children[i]->DeletePoint(point, relevels))
         return true;
@@ -684,7 +683,7 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
                    AuxiliaryInformationType>::
     RemoveNode(const RectangleTree* node, std::vector<bool>& relevels)
 {
-  for (size_t i = 0; i < numChildren; i++)
+  for (size_t i = 0; i < numChildren; ++i)
   {
     if (children[i] == node)
     {
@@ -703,7 +702,7 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
     }
 
     bool contains = true;
-    for (size_t j = 0; j < node->Bound().Dim(); j++)
+    for (size_t j = 0; j < node->Bound().Dim(); ++j)
       contains &= Child(i).Bound()[j].Contains(node->Bound()[j]);
 
     if (contains)
@@ -724,7 +723,7 @@ size_t RectangleTree<MetricType, StatisticType, MatType, SplitType,
                      DescentType, AuxiliaryInformationType>::TreeSize() const
 {
   int n = 0;
-  for (int i = 0; i < numChildren; i++)
+  for (int i = 0; i < numChildren; ++i)
     n += children[i]->TreeSize();
 
   return n + 1; // Add one for this node.
@@ -1084,7 +1083,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
   if (IsLeaf() && count < minLeafSize && parent != NULL)
   {
     // We can't delete the root node.
-    for (size_t i = 0; i < parent->NumChildren(); i++)
+    for (size_t i = 0; i < parent->NumChildren(); ++i)
     {
       if (parent->children[i] == this)
       {
@@ -1125,7 +1124,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
           root->AuxiliaryInfo().UpdateAuxiliaryInfo(root);
 
        // Reinsert the points at the root node.
-        for (size_t j = 0; j < count; j++)
+        for (size_t j = 0; j < count; ++j)
           root->InsertPoint(points[j], relevels);
 
         // This will check the minFill of the parent.
@@ -1144,7 +1143,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
     if (parent != NULL)
     {
       // The normal case.  We need to be careful with the root.
-      for (size_t j = 0; j < parent->NumChildren(); j++)
+      for (size_t j = 0; j < parent->NumChildren(); ++j)
       {
         if (parent->children[j] == this)
         {
@@ -1186,7 +1185,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
             root->AuxiliaryInfo().UpdateAuxiliaryInfo(root);
 
           // Reinsert the nodes at the root node.
-          for (size_t i = 0; i < numChildren; i++)
+          for (size_t i = 0; i < numChildren; ++i)
             root->InsertNode(children[i], level, relevels);
 
           // This will check the minFill of the point.
@@ -1210,7 +1209,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
         children.resize(maxNumChildren + 1);
       }
 
-      for (size_t i = 0; i < child->NumChildren(); i++)
+      for (size_t i = 0; i < child->NumChildren(); ++i)
       {
         children[i] = child->children[i];
         children[i]->Parent() = this;
@@ -1220,7 +1219,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
       numChildren = child->NumChildren();
       child->NumChildren() = 0;
 
-      for (size_t i = 0; i < child->Count(); i++)
+      for (size_t i = 0; i < child->Count(); ++i)
       {
         // In case the tree has a height of two.
         points[i] = child->Point(i);
@@ -1264,12 +1263,12 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
   bool shrunk = false;
   if (IsLeaf())
   {
-    for (size_t i = 0; i < bound.Dim(); i++)
+    for (size_t i = 0; i < bound.Dim(); ++i)
     {
       if (bound[i].Lo() == point[i])
       {
         ElemType min = std::numeric_limits<ElemType>::max();
-        for (size_t j = 0; j < count; j++)
+        for (size_t j = 0; j < count; ++j)
         {
           if (dataset->col(points[j])[i] < min)
             min = dataset->col(points[j])[i];
@@ -1288,7 +1287,7 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
       else if (bound[i].Hi() == point[i])
       {
         ElemType max = std::numeric_limits<ElemType>::lowest();
-        for (size_t j = 0; j < count; j++)
+        for (size_t j = 0; j < count; ++j)
         {
           if (dataset->col(points[j])[i] > max)
             max = dataset->col(points[j])[i];
@@ -1308,12 +1307,12 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
   }
   else
   {
-    for (size_t i = 0; i < bound.Dim(); i++)
+    for (size_t i = 0; i < bound.Dim(); ++i)
     {
       if (bound[i].Lo() == point[i])
       {
         ElemType min = std::numeric_limits<ElemType>::max();
-        for (size_t j = 0; j < numChildren; j++)
+        for (size_t j = 0; j < numChildren; ++j)
         {
           if (children[j]->Bound()[i].Lo() < min)
             min = children[j]->Bound()[i].Lo();
@@ -1328,7 +1327,7 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
       else if (bound[i].Hi() == point[i])
       {
         ElemType max = std::numeric_limits<ElemType>::lowest();
-        for (size_t j = 0; j < numChildren; j++)
+        for (size_t j = 0; j < numChildren; ++j)
         {
           if (children[j]->Bound()[i].Hi() > max)
             max = children[j]->Bound()[i].Hi();
@@ -1363,20 +1362,20 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
   ElemType sum = 0;
 
   // I think it may be faster to just recalculate the whole thing.
-  for (size_t i = 0; i < bound.Dim(); i++)
+  for (size_t i = 0; i < bound.Dim(); ++i)
   {
     sum += bound[i].Width();
     bound[i].Lo() = std::numeric_limits<ElemType>::max();
     bound[i].Hi() = std::numeric_limits<ElemType>::lowest();
   }
 
-  for (size_t i = 0; i < numChildren; i++)
+  for (size_t i = 0; i < numChildren; ++i)
   {
     bound |= children[i]->Bound();
   }
 
   ElemType sum2 = 0;
-  for (size_t i = 0; i < bound.Dim(); i++)
+  for (size_t i = 0; i < bound.Dim(); ++i)
     sum2 += bound[i].Width();
 
   return sum != sum2;
@@ -1400,7 +1399,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType,
   // Clean up memory, if necessary.
   if (Archive::is_loading::value)
   {
-    for (size_t i = 0; i < numChildren; i++)
+    for (size_t i = 0; i < numChildren; ++i)
       delete children[i];
     children.clear();
 
