@@ -78,7 +78,23 @@ class NguyenWidrowInitialization
     RandomInitialization randomInit(lowerBound, upperBound);
     randomInit.Initialize(W, rows, cols);
 
-    double beta = 0.7 * std::pow(cols, 1 / rows);
+    double beta = 0.7 * std::pow(cols, 1.0 / rows);
+    W *= (beta / arma::norm(W));
+  }
+
+  /**
+   * Initialize the elements of the specified weight matrix with the
+   * Nguyen-Widrow method.
+   *
+   * @param W Weight matrix to initialize.
+   */
+  template<typename eT>
+  void Initialize(arma::Mat<eT>& W)
+  {
+    RandomInitialization randomInit(lowerBound, upperBound);
+    randomInit.Initialize(W);
+
+    double beta = 0.7 * std::pow(W.n_cols, 1.0 / W.n_rows);
     W *= (beta / arma::norm(W));
   }
 
@@ -97,12 +113,29 @@ class NguyenWidrowInitialization
                   const size_t cols,
                   const size_t slices)
   {
-    W = arma::Cube<eT>(rows, cols, slices);
+    if (W.is_empty())
+      W.set_size(rows, cols, slices);
 
-    for (size_t i = 0; i < slices; i++)
+    for (size_t i = 0; i < slices; ++i)
       Initialize(W.slice(i), rows, cols);
   }
 
+  /**
+   * Initialize the elements of the specified weight 3rd order tensor with the
+   * Nguyen-Widrow method.
+   *
+   * @param W Weight matrix to initialize.
+   */
+  template<typename eT>
+  void Initialize(arma::Cube<eT>& W)
+  {
+    if (W.is_empty())
+      Log::Fatal << "Cannot initialize an empty matrix." << std::endl;
+
+    for (size_t i = 0; i < W.n_slices; ++i)
+      Initialize(W.slice(i));
+  }
+
  private:
   //! The number used as lower bound.
   double lowerBound;
