@@ -64,8 +64,14 @@ class BatchNorm
    *
    * @param size The number of input units / channels.
    * @param eps The epsilon added to variance to ensure numerical stability.
+   * @param average Boolean to determine whether cumulative average is used for
+   *                updating the parameters or momentum is used.
+   * @param momentum Parameter used to to update the running mean and variance.
    */
-  BatchNorm(const size_t size, const double eps = 1e-8);
+  BatchNorm(const size_t size,
+            const double eps = 1e-8,
+            const bool average = true,
+            const double momentum = 0.1);
 
   /**
    * Reset the layer parameters
@@ -133,17 +139,30 @@ class BatchNorm
   bool& Deterministic() { return deterministic; }
 
   //! Get the mean over the training data.
-  OutputDataType TrainingMean() { return runningMean; }
+  OutputDataType const& TrainingMean() const { return runningMean; }
+  //! Modify the mean over the training data.
+  OutputDataType& TrainingMean() { return runningMean; }
 
   //! Get the variance over the training data.
-  OutputDataType TrainingVariance() { return runningVariance / count; }
+  OutputDataType const& TrainingVariance() const { return runningVariance; }
+  //! Modify the variance over the training data.
+  OutputDataType& TrainingVariance() { return runningVariance; }
 
-  //! Get the number of input units.
+  //! Get the number of input units / channels.
   size_t InputSize() const { return size; }
 
   //! Get the epsilon value.
   double Epsilon() const { return eps; }
 
+  //! Get the momentum value.
+  double Momentum() const { return momentum; }
+
+  //! Get the average parameter.
+  bool Average() const { return average; }
+
+  //! Get size of weights.
+  size_t WeightSize() const { return 2 * size; }
+
   /**
    * Serialize the layer
    */
@@ -157,6 +176,13 @@ class BatchNorm
   //! Locally-stored epsilon value.
   double eps;
 
+  //! If true use average else use momentum for computing running mean
+  //! and variance
+  bool average;
+
+  //! Locally-stored value for momentum.
+  double momentum;
+
   //! Variable to keep track of whether we are in loading or saving mode.
   bool loading;
 
@@ -166,6 +192,12 @@ class BatchNorm
   //! Locally-stored shift parameter.
   OutputDataType beta;
 
+  //! Locally-stored mean object.
+  OutputDataType mean;
+
+  //! Locally-stored variance object.
+  OutputDataType variance;
+
   //! Locally-stored parameters.
   OutputDataType weights;
 
@@ -178,11 +210,9 @@ class BatchNorm
   //! Locally-stored running mean/variance counter.
   size_t count;
 
-  //! Locally-stored mean object.
-  OutputDataType mean;
-
-  //! Locally-stored variance object.
-  OutputDataType variance;
+  //! Locally-stored value for average factor which used to update running
+  //! mean and variance.
+  double averageFactor;
 
   //! Locally-stored mean object.
   OutputDataType runningMean;
@@ -200,10 +230,10 @@ class BatchNorm
   OutputDataType outputParameter;
 
   //! Locally-stored normalized input.
-  OutputDataType normalized;
+  arma::cube normalized;
 
   //! Locally-stored zero mean input.
-  OutputDataType inputMean;
+  arma::cube inputMean;
 }; // class BatchNorm
 
 } // namespace ann
