@@ -1,5 +1,5 @@
 /**
- * @file concat_performance.hpp
+ * @file methods/ann/layer/concat_performance.hpp
  * @author Marcus Edel
  *
  * Definition of the ConcatPerformance class.
@@ -83,6 +83,9 @@ class ConcatPerformance
   //! Modify the delta.
   OutputDataType& Delta() { return delta; }
 
+  //! Get the number of inputs.
+  size_t InSize() const { return inSize; }
+
   /**
    * Serialize the layer
    */
