@@ -52,7 +52,7 @@ void ELU<InputDataType, OutputDataType>::Forward(
     const InputType& input, OutputType& output)
 {
   output = arma::ones<OutputDataType>(arma::size(input));
-  for (size_t i = 0; i < input.n_elem; i++)
+  for (size_t i = 0; i < input.n_elem; ++i)
   {
     if (input(i) < DBL_MAX)
     {
@@ -64,7 +64,7 @@ void ELU<InputDataType, OutputDataType>::Forward(
     if (!deterministic)
     {
       derivative.set_size(arma::size(input));
-      for (size_t i = 0; i < input.n_elem; i++)
+      for (size_t i = 0; i < input.n_elem; ++i)
       {
         derivative(i) = (input(i) > 0) ? lambda : output(i) +
             lambda * alpha;
