@@ -21,12 +21,12 @@ namespace ann /** Artificial Neural Network. */ {
 
 template <typename InputDataType, typename OutputDataType>
 Lookup<InputDataType, OutputDataType>::Lookup(
-    const size_t inSize,
-    const size_t outSize) :
-    inSize(inSize),
-    outSize(outSize)
+    const size_t vocabSize,
+    const size_t embeddingSize) :
+    vocabSize(vocabSize),
+    embeddingSize(embeddingSize)
 {
-  weights.set_size(outSize, inSize);
+  weights.set_size(embeddingSize, vocabSize);
 }
 
 template<typename InputDataType, typename OutputDataType>
@@ -34,17 +34,29 @@ template<typename eT>
 void Lookup<InputDataType, OutputDataType>::Forward(
     const arma::Mat<eT>& input, arma::Mat<eT>& output)
 {
-  output = weights.cols(arma::conv_to<arma::uvec>::from(input) - 1);
+  const size_t seqLength = input.n_rows;
+  const size_t batchSize = input.n_cols;
+
+  output.set_size(embeddingSize * seqLength, batchSize);
+
+  for (size_t i = 0; i < batchSize; ++i)
+  {
+    // ith column of output is a vectorized form of a matrix of shape
+    // (embeddingSize, seqLength) selected as a combination of columns from the
+    // weights.
+    output.col(i) = arma::vectorise(weights.cols(
+        arma::conv_to<arma::uvec>::from(input.col(i)) - 1));
+  }
 }
 
 template<typename InputDataType, typename OutputDataType>
 template<typename eT>
 void Lookup<InputDataType, OutputDataType>::Backward(
     const arma::Mat<eT>& /* input */,
-    const arma::Mat<eT>& gy,
-    arma::Mat<eT>& g)
+    const arma::Mat<eT>& /* gy */,
+    arma::Mat<eT>& /* g */)
 {
-  g = gy;
+  Log::Fatal << "Lookup cannot be used as an intermediate layer." << std::endl;
 }
 
 template<typename InputDataType, typename OutputDataType>
@@ -54,8 +66,20 @@ void Lookup<InputDataType, OutputDataType>::Gradient(
     const arma::Mat<eT>& error,
     arma::Mat<eT>& gradient)
 {
-  gradient = arma::zeros<arma::Mat<eT> >(weights.n_rows, weights.n_cols);
-  gradient.cols(arma::conv_to<arma::uvec>::from(input) - 1) = error;
+  const size_t seqLength = input.n_rows;
+  const size_t batchSize = input.n_cols;
+
+  arma::Cube<eT> errorTemp(const_cast<arma::Mat<eT>&>(error).memptr(),
+      embeddingSize, seqLength, batchSize, false, false);
+
+  gradient.set_size(arma::size(weights));
+  gradient.zeros();
+
+  for (size_t i = 0; i < batchSize; ++i)
+  {
+    gradient.cols(arma::conv_to<arma::uvec>::from(input.col(i)) - 1)
+        += errorTemp.slice(i);
+  }
 }
 
 template<typename InputDataType, typename OutputDataType>
@@ -63,8 +87,13 @@ template<typename Archive>
 void Lookup<InputDataType, OutputDataType>::serialize(
     Archive& ar, const unsigned int /* version */)
 {
-  ar & BOOST_SERIALIZATION_NVP(inSize);
-  ar & BOOST_SERIALIZATION_NVP(outSize);
+  ar & BOOST_SERIALIZATION_NVP(vocabSize);
+  ar & BOOST_SERIALIZATION_NVP(embeddingSize);
+
+  // This is inefficient, but we have to allocate this memory so that
+  // WeightSetVisitor gets the right size.
+  if (Archive::is_loading::value)
+    weights.set_size(embeddingSize, vocabSize);
 }
 
 } // namespace ann
