@@ -1,5 +1,5 @@
 /**
- * @file recurrent_attention.hpp
+ * @file methods/ann/layer/recurrent_attention.hpp
  * @author Marcus Edel
  *
  * Definition of the RecurrentAttention class.
@@ -91,7 +91,7 @@ class RecurrentAttention
    * f(x) by propagating x backwards trough f. Using the results from the feed
    * forward pass.
    *
-   * @param input The propagated input activation.
+   * @param * (input) The propagated input activation.
    * @param gy The backpropagated error.
    * @param g The calculated gradient.
    */
@@ -103,9 +103,9 @@ class RecurrentAttention
   /*
    * Calculate the gradient using the output delta and the input activation.
    *
-   * @param input The input parameter used for calculating the gradient.
-   * @param error The calculated error.
-   * @param gradient The calculated gradient.
+   * @param * (input) The input parameter used for calculating the gradient.
+   * @param * (error) The calculated error.
+   * @param * (gradient) The calculated gradient.
    */
   template<typename eT>
   void Gradient(const arma::Mat<eT>& /* input */,
@@ -140,6 +140,12 @@ class RecurrentAttention
   //! Modify the gradient.
   OutputDataType& Gradient() { return gradient; }
 
+  //! Get the module output size.
+  size_t OutSize() const { return outSize; }
+
+  //! Get the number of steps to backpropagate through time.
+  size_t const& Rho() const { return rho; }
+
   /**
    * Serialize the layer
    */
