@@ -10,7 +10,7 @@
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/prereqs.hpp>
-#include <mlpack/core/util/cli.hpp>
+#include <mlpack/core/util/io.hpp>
 #include <mlpack/core/util/mlpack_main.hpp>
 #include <mlpack/core/math/random.hpp>
 
@@ -41,13 +41,17 @@ using namespace mlpack::svd;
 using namespace mlpack::util;
 using namespace std;
 
-// Document program.
-PROGRAM_INFO("Collaborative Filtering",
-    // Short description.
+// Program Name.
+BINDING_NAME("Collaborative Filtering");
+
+// Short description.
+BINDING_SHORT_DESC(
     "An implementation of several collaborative filtering (CF) techniques for "
     "recommender systems.  This can be used to train a new CF model, or use an"
-    " existing CF model to compute recommendations.",
-    // Long description.
+    " existing CF model to compute recommendations.");
+
+// Long description.
+BINDING_LONG_DESC(
     "This program performs collaborative "
     "filtering (CF) on the given dataset. Given a list of user, item and "
     "preferences (the " + PRINT_PARAM_STRING("training") + " parameter), "
@@ -111,8 +115,10 @@ PROGRAM_INFO("Collaborative Filtering",
     " - 'z_score'  -- Z-Score Normalization\n"
     "\n"
     "A trained model may be saved to with the " +
-    PRINT_PARAM_STRING("output_model") + " output parameter."
-    "\n\n"
+    PRINT_PARAM_STRING("output_model") + " output parameter.");
+
+// Example.
+BINDING_EXAMPLE(
     "To train a CF model on a dataset " + PRINT_DATASET("training_set") + " "
     "using NMF for decomposition and saving the trained model to " +
     PRINT_MODEL("model") + ", one could call: "
@@ -126,20 +132,23 @@ PROGRAM_INFO("Collaborative Filtering",
     "call "
     "\n\n" +
     PRINT_CALL("cf", "input_model", "model", "query", "users",
-        "recommendations", 5, "output", "recommendations"),
-    SEE_ALSO("Collaborative filtering tutorial", "@doxygen/cftutorial.html"),
-    SEE_ALSO("Alternating Matrix Factorization tutorial",
-        "@doxygen/amftutorial.html"),
-    SEE_ALSO("Collaborative Filtering on Wikipedia",
-        "https://en.wikipedia.org/wiki/Collaborative_filtering"),
-    SEE_ALSO("Matrix factorization on Wikipedia",
+        "recommendations", 5, "output", "recommendations"));
+
+// See also...
+BINDING_SEE_ALSO("Collaborative filtering tutorial",
+        "@doxygen/cftutorial.html");
+BINDING_SEE_ALSO("Alternating Matrix Factorization tutorial",
+        "@doxygen/amftutorial.html");
+BINDING_SEE_ALSO("Collaborative Filtering on Wikipedia",
+        "https://en.wikipedia.org/wiki/Collaborative_filtering");
+BINDING_SEE_ALSO("Matrix factorization on Wikipedia",
         "https://en.wikipedia.org/wiki/Matrix_factorization_"
-        "(recommender_systems)"),
-    SEE_ALSO("Matrix factorization techniques for recommender systems (pdf)",
-        "http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.441.3234"
-        "&rep=rep1&type=pdf"),
-    SEE_ALSO("mlpack::cf::CFType class documentation",
-        "@doxygen/classmlpack_1_1cf_1_1CFType.html"));
+        "(recommender_systems)");
+BINDING_SEE_ALSO("Matrix factorization techniques for recommender systems"
+        " (pdf)", "http://citeseerx.ist.psu.edu/viewdoc/download?doi="
+        "10.1.1.441.3234&rep=rep1&type=pdf");
+BINDING_SEE_ALSO("mlpack::cf::CFType class documentation",
+        "@doxygen/classmlpack_1_1cf_1_1CFType.html");
 
 // Parameters for training a model.
 PARAM_MATRIX_IN("training", "Input dataset to perform CF on.", "t");
@@ -192,11 +201,11 @@ void ComputeRecommendations(CFModel* cf,
                             arma::Mat<size_t>& recommendations)
 {
   // Reading users.
-  if (CLI::HasParam("query"))
+  if (IO::HasParam("query"))
   {
     // User matrix.
     arma::Mat<size_t> users =
-        std::move(CLI::GetParam<arma::Mat<size_t>>("query"));
+        std::move(IO::GetParam<arma::Mat<size_t>>("query"));
     if (users.n_rows > 1)
       users = users.t();
     if (users.n_rows > 1)
@@ -228,7 +237,7 @@ void ComputeRecommendations(CFModel* cf,
       "regression", "similarity" }, true, "unknown interpolation algorithm");
 
   // Taking Interpolation Alternatives
-  const string interpolationAlgorithm = CLI::GetParam<string>("interpolation");
+  const string interpolationAlgorithm = IO::GetParam<string>("interpolation");
 
   // Determining the Interpolation Algorithm
   if (interpolationAlgorithm == "average")
@@ -257,7 +266,7 @@ void ComputeRecommendations(CFModel* cf,
       "euclidean", "pearson" }, true, "unknown neighbor search algorithm");
 
   //  Taking Neighbor Search alternatives
-  const string neighborSearchAlgorithm = CLI::GetParam<string>
+  const string neighborSearchAlgorithm = IO::GetParam<string>
       ("neighbor_search");
 
 
@@ -281,7 +290,7 @@ template <typename NeighborSearchType,
 void ComputeRMSE(CFModel* cf)
 {
   // Now, compute each test point.
-  arma::mat testData = std::move(CLI::GetParam<arma::mat>("test"));
+  arma::mat testData = std::move(IO::GetParam<arma::mat>("test"));
 
   // Assemble the combination matrix to get RMSE value.
   arma::Mat<size_t> combinations(2, testData.n_cols);
@@ -314,7 +323,7 @@ void ComputeRMSE(CFModel* cf)
       "regression", "similarity" }, true, "unknown interpolation algorithm");
 
   //  Taking Interpolation Alternatives
-  const string interpolationAlgorithm = CLI::GetParam<string>("interpolation");
+  const string interpolationAlgorithm = IO::GetParam<string>("interpolation");
 
   if (interpolationAlgorithm == "average")
   {
@@ -337,7 +346,7 @@ void ComputeRMSE(CFModel* cf)
       "euclidean", "pearson" }, true, "unknown neighbor search algorithm");
 
   //  Taking Neighbor Search alternatives
-  const string neighborSearchAlgorithm = CLI::GetParam<string>
+  const string neighborSearchAlgorithm = IO::GetParam<string>
     ("neighbor_search");
 
   if (neighborSearchAlgorithm == "cosine")
@@ -356,23 +365,23 @@ void ComputeRMSE(CFModel* cf)
 
 void PerformAction(CFModel* c)
 {
-  if (CLI::HasParam("query") || CLI::HasParam("all_user_recommendations"))
+  if (IO::HasParam("query") || IO::HasParam("all_user_recommendations"))
   {
     // Get parameters for generating recommendations.
-    const size_t numRecs = (size_t) CLI::GetParam<int>("recommendations");
+    const size_t numRecs = (size_t) IO::GetParam<int>("recommendations");
 
     // Get the recommendations.
     arma::Mat<size_t> recommendations;
     ComputeRecommendations(c, numRecs, recommendations);
 
     // Save the output.
-    CLI::GetParam<arma::Mat<size_t>>("output") = recommendations;
+    IO::GetParam<arma::Mat<size_t>>("output") = recommendations;
   }
 
-  if (CLI::HasParam("test"))
+  if (IO::HasParam("test"))
     ComputeRMSE(c);
 
-  CLI::GetParam<CFModel*>("output_model") = c;
+  IO::GetParam<CFModel*>("output_model") = c;
 }
 
 template<typename DecompositionPolicy>
@@ -381,7 +390,7 @@ void PerformAction(arma::mat& dataset,
                    const size_t maxIterations,
                    const double minResidue)
 {
-  const size_t neighborhood = (size_t) CLI::GetParam<int>("neighborhood");
+  const size_t neighborhood = (size_t) IO::GetParam<int>("neighborhood");
 
   // Make sure the normalization strategy is valid.
   RequireParamInSet<string>("normalization", { "overall_mean", "item_mean",
@@ -389,10 +398,10 @@ void PerformAction(arma::mat& dataset,
 
   CFModel* c = new CFModel();
 
-  const string normalizationType = CLI::GetParam<string>("normalization");
+  const string normalizationType = IO::GetParam<string>("normalization");
 
   c->template Train<DecompositionPolicy>(dataset, neighborhood, rank,
-      maxIterations, minResidue, CLI::HasParam("iteration_only_termination"),
+      maxIterations, minResidue, IO::HasParam("iteration_only_termination"),
       normalizationType);
 
   try
@@ -411,8 +420,8 @@ void AssembleFactorizerType(const std::string& algorithm,
                             arma::mat& dataset,
                             const size_t rank)
 {
-  const size_t maxIterations = (size_t) CLI::GetParam<int>("max_iterations");
-  const double minResidue = CLI::GetParam<double>("min_residue");
+  const size_t maxIterations = (size_t) IO::GetParam<int>("max_iterations");
+  const double minResidue = IO::GetParam<double>("min_residue");
 
   if (algorithm == "NMF")
   {
@@ -460,21 +469,21 @@ void AssembleFactorizerType(const std::string& algorithm,
 
 static void mlpackMain()
 {
-  if (CLI::GetParam<int>("seed") == 0)
+  if (IO::GetParam<int>("seed") == 0)
     math::RandomSeed(std::time(NULL));
   else
-    math::RandomSeed(CLI::GetParam<int>("seed"));
+    math::RandomSeed(IO::GetParam<int>("seed"));
 
   // Validate parameters.
   RequireOnlyOnePassed({ "training", "input_model" }, true);
 
   // Check that nothing stupid is happening.
-  if (CLI::HasParam("query") || CLI::HasParam("all_user_recommendations"))
+  if (IO::HasParam("query") || IO::HasParam("all_user_recommendations"))
     RequireOnlyOnePassed({ "query", "all_user_recommendations" }, true);
 
   RequireAtLeastOnePassed({ "output", "output_model" }, false,
       "no output will be saved");
-  if (!CLI::HasParam("query") && !CLI::HasParam("all_user_recommendations"))
+  if (!IO::HasParam("query") && !IO::HasParam("all_user_recommendations"))
     ReportIgnoredParam("output", "no recommendations requested");
 
   RequireParamInSet<string>("algorithm", { "NMF", "BatchSVD",
@@ -487,7 +496,7 @@ static void mlpackMain()
         "recommendations must be positive");
 
   // Either load from a model, or train a model.
-  if (CLI::HasParam("training"))
+  if (IO::HasParam("training"))
   {
     // Train a model.
     // Validate Parameters.
@@ -502,7 +511,7 @@ static void mlpackMain()
         "neighborhood must be positive");
 
     // Read from the input file.
-    arma::mat dataset = std::move(CLI::GetParam<arma::mat>("training"));
+    arma::mat dataset = std::move(IO::GetParam<arma::mat>("training"));
 
     RequireParamValue<int>("neighborhood",
         [&dataset](int x) { return x <= max(dataset.row(0)) + 1; }, true,
@@ -512,12 +521,12 @@ static void mlpackMain()
     arma::Mat<size_t> recommendations;
 
     // Get parameters.
-    const size_t rank = (size_t) CLI::GetParam<int>("rank");
+    const size_t rank = (size_t) IO::GetParam<int>("rank");
 
     // Perform decomposition to prepare for recommendations.
     Log::Info << "Performing CF matrix decomposition on dataset..." << endl;
 
-    const string algo = CLI::GetParam<string>("algorithm");
+    const string algo = IO::GetParam<string>("algorithm");
 
     // Perform the factorization and do whatever the user wanted.
     AssembleFactorizerType(algo, dataset, rank);
@@ -529,7 +538,7 @@ static void mlpackMain()
         "test" }, true);
 
     // Load an input model.
-    CFModel* c = std::move(CLI::GetParam<CFModel*>("input_model"));
+    CFModel* c = std::move(IO::GetParam<CFModel*>("input_model"));
 
     PerformAction(c);
   }
