@@ -163,7 +163,7 @@ class SVDPlusPlusPolicy
     // Temporarily store feature vector of queried users.
     arma::mat query(h.n_rows, users.n_elem);
     // Select feature vectors of queried users.
-    for (size_t i = 0; i < users.n_elem; i++)
+    for (size_t i = 0; i < users.n_elem; ++i)
       query.col(i) = h.col(users(i));
 
     NeighborSearchPolicy neighborSearch(h);
