@@ -65,7 +65,7 @@ class ItemMeanNormalization
 
     // Calculate item mean and subtract item mean from ratings.
     // Set item mean to 0 if the item has no rating.
-    for (size_t i = 0; i < itemNum; i++)
+    for (size_t i = 0; i < itemNum; ++i)
     {
       if (ratingNum(i) != 0)
         itemMean(i) /= ratingNum(i);
@@ -99,7 +99,7 @@ class ItemMeanNormalization
       itemMean(it.row()) += *it;
       ratingNum(it.row()) += 1;
     }
-    for (size_t i = 0; i < itemMean.n_elem; i++)
+    for (size_t i = 0; i < itemMean.n_elem; ++i)
     {
       if (ratingNum(i) != 0)
         itemMean(i) /= ratingNum(i);
@@ -143,7 +143,7 @@ class ItemMeanNormalization
   void Denormalize(const arma::Mat<size_t>& combinations,
                    arma::vec& predictions) const
   {
-    for (size_t i = 0; i < predictions.n_elem; i++)
+    for (size_t i = 0; i < predictions.n_elem; ++i)
     {
       const size_t item = combinations(1, i);
       predictions(i) += itemMean(item);
