@@ -10,7 +10,7 @@
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/prereqs.hpp>
-#include <mlpack/core/util/cli.hpp>
+#include <mlpack/core/util/io.hpp>
 #include <mlpack/core/util/mlpack_main.hpp>
 #include <mlpack/core/tree/binary_space_tree.hpp>
 #include <mlpack/core/tree/rectangle_tree.hpp>
@@ -27,11 +27,16 @@ using namespace mlpack::tree;
 using namespace mlpack::util;
 using namespace std;
 
-PROGRAM_INFO("DBSCAN clustering",
-    // Short description.
+// Program Name.
+BINDING_NAME("DBSCAN clustering");
+
+// Short description.
+BINDING_SHORT_DESC(
     "An implementation of DBSCAN clustering.  Given a dataset, this can "
-    "compute and return a clustering of that dataset.",
-    // Long description.
+    "compute and return a clustering of that dataset.");
+
+// Long description.
+BINDING_LONG_DESC(
     "This program implements the DBSCAN algorithm for clustering using "
     "accelerated tree-based range search.  The type of tree that is used "
     "may be parameterized, or brute-force range search may also be used."
@@ -58,19 +63,23 @@ PROGRAM_INFO("DBSCAN clustering",
     " 'hilbert-r', 'r-plus', 'r-plus-plus', 'cover', 'ball'. The " +
     PRINT_PARAM_STRING("single_mode") + " parameter will force single-tree "
     "search (as opposed to the default dual-tree search), and '" +
-    PRINT_PARAM_STRING("naive") + " will force brute-force range search."
-    "\n\n"
+    PRINT_PARAM_STRING("naive") + " will force brute-force range search.");
+
+// Example.
+BINDING_EXAMPLE(
     "An example usage to run DBSCAN on the dataset in " +
     PRINT_DATASET("input") + " with a radius of 0.5 and a minimum cluster size"
     " of 5 is given below:"
     "\n\n" +
-    PRINT_CALL("dbscan", "input", "input", "epsilon", 0.5, "min_size", 5),
-    SEE_ALSO("DBSCAN on Wikipedia", "https://en.wikipedia.org/wiki/DBSCAN"),
-    SEE_ALSO("A density-based algorithm for discovering clusters in large "
+    PRINT_CALL("dbscan", "input", "input", "epsilon", 0.5, "min_size", 5));
+
+// See also...
+BINDING_SEE_ALSO("DBSCAN on Wikipedia", "https://en.wikipedia.org/wiki/DBSCAN");
+BINDING_SEE_ALSO("A density-based algorithm for discovering clusters in large "
         "spatial databases with noise (pdf)",
-        "http://www.aaai.org/Papers/KDD/1996/KDD96-037.pdf"),
-    SEE_ALSO("mlpack::dbscan::DBSCAN class documentation",
-        "@doxygen/classmlpack_1_1dbscan_1_1DBSCAN.html"));
+        "http://www.aaai.org/Papers/KDD/1996/KDD96-037.pdf");
+BINDING_SEE_ALSO("mlpack::dbscan::DBSCAN class documentation",
+        "@doxygen/classmlpack_1_1dbscan_1_1DBSCAN.html");
 
 PARAM_MATRIX_IN_REQ("input", "Input dataset to cluster.", "i");
 PARAM_UROW_OUT("assignments", "Output matrix for assignments of each "
@@ -95,41 +104,41 @@ template<typename RangeSearchType, typename PointSelectionPolicy>
 void RunDBSCAN(RangeSearchType rs,
                PointSelectionPolicy pointSelector = PointSelectionPolicy())
 {
-  if (CLI::HasParam("single_mode"))
+  if (IO::HasParam("single_mode"))
     rs.SingleMode() = true;
 
   // Load dataset.
-  arma::mat dataset = std::move(CLI::GetParam<arma::mat>("input"));
-  const double epsilon = CLI::GetParam<double>("epsilon");
-  const size_t minSize = (size_t) CLI::GetParam<int>("min_size");
+  arma::mat dataset = std::move(IO::GetParam<arma::mat>("input"));
+  const double epsilon = IO::GetParam<double>("epsilon");
+  const size_t minSize = (size_t) IO::GetParam<int>("min_size");
   arma::Row<size_t> assignments;
 
   DBSCAN<RangeSearchType, PointSelectionPolicy> d(epsilon, minSize,
-      !CLI::HasParam("single_mode"), rs, pointSelector);
+      !IO::HasParam("single_mode"), rs, pointSelector);
 
   // If possible, avoid the overhead of calculating centroids.
-  if (CLI::HasParam("centroids"))
+  if (IO::HasParam("centroids"))
   {
     arma::mat centroids;
 
     d.Cluster(dataset, assignments, centroids);
 
-    CLI::GetParam<arma::mat>("centroids") = std::move(centroids);
+    IO::GetParam<arma::mat>("centroids") = std::move(centroids);
   }
   else
   {
     d.Cluster(dataset, assignments);
   }
 
-  if (CLI::HasParam("assignments"))
-    CLI::GetParam<arma::Row<size_t>>("assignments") = std::move(assignments);
+  if (IO::HasParam("assignments"))
+    IO::GetParam<arma::Row<size_t>>("assignments") = std::move(assignments);
 }
 
 // Choose the point selection policy.
 template<typename RangeSearchType>
 void ChoosePointSelectionPolicy(RangeSearchType rs = RangeSearchType())
 {
-  const string selectionType = CLI::GetParam<string>("selection_type");
+  const string selectionType = IO::GetParam<string>("selection_type");
 
   if (selectionType == "ordered")
     RunDBSCAN<RangeSearchType, OrderedPointSelection>(rs);
@@ -157,14 +166,14 @@ static void mlpackMain()
       true, "invalid value of min_size specified");
 
   // Fire off naive search if needed.
-  if (CLI::HasParam("naive"))
+  if (IO::HasParam("naive"))
   {
     RangeSearch<> rs(true);
     ChoosePointSelectionPolicy(rs);
   }
   else
   {
-    const string treeType = CLI::GetParam<string>("tree_type");
+    const string treeType = IO::GetParam<string>("tree_type");
     if (treeType == "kd")
     {
       ChoosePointSelectionPolicy<RangeSearch<>>();
