@@ -10,7 +10,7 @@
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/prereqs.hpp>
-#include <mlpack/core/util/cli.hpp>
+#include <mlpack/core/util/io.hpp>
 #include <mlpack/core/util/mlpack_main.hpp>
 #include "decision_tree.hpp"
 
@@ -20,13 +20,18 @@ using namespace mlpack::tree;
 using namespace mlpack::data;
 using namespace mlpack::util;
 
-PROGRAM_INFO("Decision tree",
-    // Short description.
+// Program Name.
+BINDING_NAME("Decision tree");
+
+// Short description.
+BINDING_SHORT_DESC(
     "An implementation of an ID3-style decision tree for classification, which"
     " supports categorical data.  Given labeled data with numeric or "
     "categorical features, a decision tree can be trained and saved; or, an "
-    "existing decision tree can be used for classification on new points.",
-    // Long description.
+    "existing decision tree can be used for classification on new points.");
+
+// Long description.
+BINDING_LONG_DESC(
     "Train and evaluate using a decision tree.  Given a dataset containing "
     "numeric or categorical features, and associated labels for each point in "
     "the dataset, this program can train a decision tree on that data."
@@ -59,8 +64,10 @@ PROGRAM_INFO("Decision tree",
     " parameter.  Predictions for each test point may be saved via the " +
     PRINT_PARAM_STRING("predictions") + " output parameter.  Class "
     "probabilities for each prediction may be saved with the " +
-    PRINT_PARAM_STRING("probabilities") + " output parameter."
-    "\n\n"
+    PRINT_PARAM_STRING("probabilities") + " output parameter.");
+
+// Example.
+BINDING_EXAMPLE(
     "For example, to train a decision tree with a minimum leaf size of 20 on "
     "the dataset contained in " + PRINT_DATASET("data") + " with labels " +
     PRINT_DATASET("labels") + ", saving the output model to " +
@@ -78,15 +85,17 @@ PROGRAM_INFO("Decision tree",
     PRINT_DATASET("predictions") + ", one could call "
     "\n\n" +
     PRINT_CALL("decision_tree", "input_model", "tree", "test", "test_set",
-        "test_labels", "test_labels", "predictions", "predictions"),
-    SEE_ALSO("Decision stump", "#decision_stump"),
-    SEE_ALSO("Random forest", "#random_forest"),
-    SEE_ALSO("Decision trees on Wikipedia",
-        "https://en.wikipedia.org/wiki/Decision_tree_learning"),
-    SEE_ALSO("Induction of Decision Trees (pdf)",
-        "https://link.springer.com/content/pdf/10.1007/BF00116251.pdf"),
-    SEE_ALSO("mlpack::tree::DecisionTree class documentation",
-        "@doxygen/classmlpack_1_1tree_1_1DecisionTree.html"));
+        "test_labels", "test_labels", "predictions", "predictions"));
+
+// See also...
+BINDING_SEE_ALSO("Decision stump", "#decision_stump");
+BINDING_SEE_ALSO("Random forest", "#random_forest");
+BINDING_SEE_ALSO("Decision trees on Wikipedia",
+        "https://en.wikipedia.org/wiki/Decision_tree_learning");
+BINDING_SEE_ALSO("Induction of Decision Trees (pdf)",
+        "https://link.springer.com/content/pdf/10.1007/BF00116251.pdf");
+BINDING_SEE_ALSO("mlpack::tree::DecisionTree class documentation",
+        "@doxygen/classmlpack_1_1tree_1_1DecisionTree.html");
 
 // Datasets.
 PARAM_MATRIX_AND_INFO_IN("training", "Training dataset (may be categorical).",
@@ -168,7 +177,7 @@ static void mlpackMain()
                          { return (x > 0.0 && x < 1.0); }, true,
                          "gain split must be a fraction in range [0,1]");
 
-  if (CLI::HasParam("print_training_error"))
+  if (IO::HasParam("print_training_error"))
   {
     Log::Warn << "The option " << PRINT_PARAM_STRING("print_training_error")
         << " is deprecated and will be removed in mlpack 4.0.0." << std::endl;
@@ -179,14 +188,14 @@ static void mlpackMain()
   arma::mat trainingSet;
   arma::Row<size_t> labels;
 
-  if (CLI::HasParam("training"))
+  if (IO::HasParam("training"))
   {
     model = new DecisionTreeModel();
-    model->info = std::move(std::get<0>(CLI::GetParam<TupleType>("training")));
-    trainingSet = std::move(std::get<1>(CLI::GetParam<TupleType>("training")));
-    if (CLI::HasParam("labels"))
+    model->info = std::move(std::get<0>(IO::GetParam<TupleType>("training")));
+    trainingSet = std::move(std::get<1>(IO::GetParam<TupleType>("training")));
+    if (IO::HasParam("labels"))
     {
-      labels = std::move(CLI::GetParam<arma::Row<size_t>>("labels"));
+      labels = std::move(IO::GetParam<arma::Row<size_t>>("labels"));
     }
     else
     {
@@ -201,18 +210,18 @@ static void mlpackMain()
     const size_t numClasses = arma::max(arma::max(labels)) + 1;
 
     // Now build the tree.
-    const size_t minLeafSize = (size_t) CLI::GetParam<int>("minimum_leaf_size");
-    const size_t maxDepth = (size_t) CLI::GetParam<int>("maximum_depth");
+    const size_t minLeafSize = (size_t) IO::GetParam<int>("minimum_leaf_size");
+    const size_t maxDepth = (size_t) IO::GetParam<int>("maximum_depth");
     const double minimumGainSplit =
-                           (double) CLI::GetParam<double>("minimum_gain_split");
+                           (double) IO::GetParam<double>("minimum_gain_split");
 
     // Create decision tree with weighted labels.
-    if (CLI::HasParam("weights"))
+    if (IO::HasParam("weights"))
     {
       arma::Row<double> weights =
-          std::move(CLI::GetParam<arma::Mat<double>>("weights"));
-      if (CLI::HasParam("print_training_error") ||
-          CLI::HasParam("print_training_accuracy"))
+          std::move(IO::GetParam<arma::Mat<double>>("weights"));
+      if (IO::HasParam("print_training_error") ||
+          IO::HasParam("print_training_accuracy"))
       {
         model->tree = DecisionTree<>(trainingSet, model->info, labels,
             numClasses, std::move(weights), minLeafSize, minimumGainSplit,
@@ -227,7 +236,7 @@ static void mlpackMain()
     }
     else
     {
-      if (CLI::HasParam("print_training_error"))
+      if (IO::HasParam("print_training_error"))
       {
         model->tree = DecisionTree<>(trainingSet, model->info, labels,
             numClasses, minLeafSize, minimumGainSplit, maxDepth);
@@ -241,7 +250,8 @@ static void mlpackMain()
     }
 
     // Do we need to print training error?
-    if (CLI::HasParam("print_training_error"))
+    if (IO::HasParam("print_training_error") ||
+        IO::HasParam("print_training_accuracy"))
     {
       arma::Row<size_t> predictions;
       arma::mat probabilities;
@@ -261,14 +271,14 @@ static void mlpackMain()
   }
   else
   {
-    model = CLI::GetParam<DecisionTreeModel*>("input_model");
+    model = IO::GetParam<DecisionTreeModel*>("input_model");
   }
 
   // Do we need to get predictions?
-  if (CLI::HasParam("test"))
+  if (IO::HasParam("test"))
   {
-    std::get<0>(CLI::GetRawParam<TupleType>("test")) = model->info;
-    arma::mat testPoints = std::get<1>(CLI::GetParam<TupleType>("test"));
+    std::get<0>(IO::GetRawParam<TupleType>("test")) = model->info;
+    arma::mat testPoints = std::get<1>(IO::GetParam<TupleType>("test"));
 
     arma::Row<size_t> predictions;
     arma::mat probabilities;
@@ -276,10 +286,10 @@ static void mlpackMain()
     model->tree.Classify(testPoints, predictions, probabilities);
 
     // Do we need to calculate accuracy?
-    if (CLI::HasParam("test_labels"))
+    if (IO::HasParam("test_labels"))
     {
       arma::Row<size_t> testLabels =
-          std::move(CLI::GetParam<arma::Row<size_t>>("test_labels"));
+          std::move(IO::GetParam<arma::Row<size_t>>("test_labels"));
 
       size_t correct = 0;
       for (size_t i = 0; i < testPoints.n_cols; ++i)
@@ -293,10 +303,10 @@ static void mlpackMain()
     }
 
     // Do we need to save outputs?
-    CLI::GetParam<arma::Row<size_t>>("predictions") = predictions;
-    CLI::GetParam<arma::mat>("probabilities") = probabilities;
+    IO::GetParam<arma::Row<size_t>>("predictions") = predictions;
+    IO::GetParam<arma::mat>("probabilities") = probabilities;
   }
 
   // Do we need to save the model?
-  CLI::GetParam<DecisionTreeModel*>("output_model") = model;
+  IO::GetParam<DecisionTreeModel*>("output_model") = model;
 }
