@@ -10,7 +10,7 @@
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/prereqs.hpp>
-#include <mlpack/core/util/cli.hpp>
+#include <mlpack/core/util/io.hpp>
 #include <mlpack/core/util/mlpack_main.hpp>
 
 #include "hmm.hpp"
@@ -28,39 +28,50 @@ using namespace mlpack::math;
 using namespace arma;
 using namespace std;
 
-PROGRAM_INFO("Hidden Markov Model (HMM) Training",
-    // Short description.
+// Program Name.
+BINDING_NAME("Hidden Markov Model (HMM) Training");
+
+// Short description.
+BINDING_SHORT_DESC(
     "An implementation of training algorithms for Hidden Markov Models (HMMs). "
     "Given labeled or unlabeled data, an HMM can be trained for further use "
-    "with other mlpack HMM tools.",
-    // Long description.
+    "with other mlpack HMM tools.");
+
+// Long description.
+BINDING_LONG_DESC(
     "This program allows a Hidden Markov Model to be trained on labeled or "
     "unlabeled data.  It supports four types of HMMs: Discrete HMMs, "
     "Gaussian HMMs, GMM HMMs, or Diagonal GMM HMMs"
     "\n\n"
-    "Either one input sequence can be specified (with --input_file), or, a "
-    "file containing files in which input sequences can be found (when "
-    "--input_file and --batch are used together).  In addition, labels can be "
-    "provided in the file specified by --labels_file, and if --batch is used, "
-    "the file given to --labels_file should contain a list of files of labels "
-    "corresponding to the sequences in the file given to --input_file."
+    "Either one input sequence can be specified (with " +
+    PRINT_PARAM_STRING("input_file") + "), or, a file containing files in "
+    "which input sequences can be found (when "+
+    PRINT_PARAM_STRING("input_file") + "and" + PRINT_PARAM_STRING("batch") +
+    " are used together).  In addition, labels can be "
+    "provided in the file specified by " + PRINT_PARAM_STRING("labels_file") +
+    ", and if " + PRINT_PARAM_STRING("batch") + " is used, "
+    "the file given to " + PRINT_PARAM_STRING("labels_file") +
+    " should contain a list of files of labels corresponding to the sequences"
+    " in the file given to " + PRINT_PARAM_STRING("input_file") + "."
     "\n\n"
     "The HMM is trained with the Baum-Welch algorithm if no labels are "
     "provided.  The tolerance of the Baum-Welch algorithm can be set with the "
-    "--tolerance option.  By default, the transition matrix is randomly "
-    "initialized and the emission distributions are initialized to fit the "
-    "extent of the data."
+    + PRINT_PARAM_STRING("tolerance") + "option.  By default, the transition "
+    "matrix is randomly initialized and the emission distributions are "
+    "initialized to fit the extent of the data."
     "\n\n"
     "Optionally, a pre-created HMM model can be used as a guess for the "
-    "transition matrix and emission probabilities; this is specifiable with "
-    "--model_file.",
-    SEE_ALSO("@hmm_generate", "#hmm_generate"),
-    SEE_ALSO("@hmm_loglik", "#hmm_loglik"),
-    SEE_ALSO("@hmm_viterbi", "#hmm_viterbi"),
-    SEE_ALSO("Hidden Mixture Models on Wikipedia",
-        "https://en.wikipedia.org/wiki/Hidden_Markov_model"),
-    SEE_ALSO("mlpack::hmm::HMM class documentation",
-        "@doxygen/classmlpack_1_1hmm_1_1HMM.html"));
+    "transition matrix and emission probabilities; this is specifiable with " +
+    PRINT_PARAM_STRING("output_model") + ".");
+
+// See also...
+BINDING_SEE_ALSO("@hmm_generate", "#hmm_generate");
+BINDING_SEE_ALSO("@hmm_loglik", "#hmm_loglik");
+BINDING_SEE_ALSO("@hmm_viterbi", "#hmm_viterbi");
+BINDING_SEE_ALSO("Hidden Mixture Models on Wikipedia",
+        "https://en.wikipedia.org/wiki/Hidden_Markov_model");
+BINDING_SEE_ALSO("mlpack::hmm::HMM class documentation",
+        "@doxygen/classmlpack_1_1hmm_1_1HMM.html");
 
 PARAM_STRING_IN_REQ("input_file", "File containing input observations.", "i");
 PARAM_STRING_IN("type", "Type of HMM: discrete | gaussian | diag_gmm | gmm.",
@@ -89,8 +100,8 @@ struct Init
   template<typename HMMType>
   static void Apply(HMMType& hmm, vector<mat>* trainSeq)
   {
-    const size_t states = CLI::GetParam<int>("states");
-    const double tolerance = CLI::GetParam<double>("tolerance");
+    const size_t states = IO::GetParam<int>("states");
+    const double tolerance = IO::GetParam<double>("tolerance");
 
     // Create the initialized-to-zero model.
     Create(hmm, *trainSeq, states, tolerance);
@@ -155,7 +166,7 @@ struct Init
   {
     // Find dimension of the data.
     const size_t dimensionality = trainSeq[0].n_rows;
-    const int gaussians = CLI::GetParam<int>("gaussians");
+    const int gaussians = IO::GetParam<int>("gaussians");
 
     if (gaussians == 0)
     {
@@ -174,7 +185,7 @@ struct Init
         tolerance);
 
     // Issue a warning if the user didn't give labels.
-    if (!CLI::HasParam("labels_file"))
+    if (!IO::HasParam("labels_file"))
     {
       Log::Warn << "Unlabeled training of GMM HMMs is almost certainly not "
           << "going to produce good results!" << endl;
@@ -189,7 +200,7 @@ struct Init
   {
     // Find dimension of the data.
     const size_t dimensionality = trainSeq[0].n_rows;
-    const int gaussians = CLI::GetParam<int>("gaussians");
+    const int gaussians = IO::GetParam<int>("gaussians");
 
     if (gaussians == 0)
     {
@@ -208,7 +219,7 @@ struct Init
         dimensionality), tolerance);
 
     // Issue a warning if the user didn't give labels.
-    if (!CLI::HasParam("labels_file"))
+    if (!IO::HasParam("labels_file"))
     {
       Log::Warn << "Unlabeled training of Diagonal GMM HMMs is almost "
           << "certainly not going to produce good results!" << endl;
@@ -248,7 +259,7 @@ struct Init
       e[i].Weights() /= arma::accu(e[i].Weights());
 
       // Random means and covariances.
-      for (int g = 0; g < CLI::GetParam<int>("gaussians"); ++g)
+      for (int g = 0; g < IO::GetParam<int>("gaussians"); ++g)
       {
         const size_t dimensionality = e[i].Component(g).Mean().n_rows;
         e[i].Component(g).Mean().randu();
@@ -271,7 +282,7 @@ struct Init
       e[i].Weights() /= arma::accu(e[i].Weights());
 
       // Random means and covariances.
-      for (int g = 0; g < CLI::GetParam<int>("gaussians"); ++g)
+      for (int g = 0; g < IO::GetParam<int>("gaussians"); ++g)
       {
         const size_t dimensionality = e[i].Component(g).Mean().n_rows;
         e[i].Component(g).Mean().randu();
@@ -291,14 +302,14 @@ struct Train
   template<typename HMMType>
   static void Apply(HMMType& hmm, vector<mat>* trainSeqPtr)
   {
-    const bool batch = CLI::HasParam("batch");
-    const double tolerance = CLI::GetParam<double>("tolerance");
+    const bool batch = IO::HasParam("batch");
+    const double tolerance = IO::GetParam<double>("tolerance");
 
     // Do we need to replace the tolerance?
-    if (CLI::HasParam("tolerance"))
+    if (IO::HasParam("tolerance"))
       hmm.Tolerance() = tolerance;
 
-    const string labelsFile = CLI::GetParam<string>("labels_file");
+    const string labelsFile = IO::GetParam<string>("labels_file");
 
     // Verify that the dimensionality of our observations is the same as the
     // dimensionality of our HMM's emissions.
@@ -315,7 +326,7 @@ struct Train
     }
 
     vector<arma::Row<size_t>> labelSeq; // May be empty.
-    if (CLI::HasParam("labels_file"))
+    if (IO::HasParam("labels_file"))
     {
       // Do we have multiple label files to load?
       char lineBuf[1024];
@@ -413,19 +424,19 @@ struct Train
 static void mlpackMain()
 {
   // Set random seed.
-  if (CLI::GetParam<int>("seed") != 0)
-    RandomSeed((size_t) CLI::GetParam<int>("seed"));
+  if (IO::GetParam<int>("seed") != 0)
+    RandomSeed((size_t) IO::GetParam<int>("seed"));
   else
     RandomSeed((size_t) time(NULL));
 
   // Validate parameters.
-  const string inputFile = CLI::GetParam<string>("input_file");
-  const string type = CLI::GetParam<string>("type");
-  const bool batch = CLI::HasParam("batch");
-  const double tolerance = CLI::GetParam<double>("tolerance");
+  const string inputFile = IO::GetParam<string>("input_file");
+  const string type = IO::GetParam<string>("type");
+  const bool batch = IO::HasParam("batch");
+  const double tolerance = IO::GetParam<double>("tolerance");
 
   // If no model is specified, make sure we are training with valid parameters.
-  if (!CLI::HasParam("input_model"))
+  if (!IO::HasParam("input_model"))
   {
     // Validate number of states.
     RequireAtLeastOnePassed({ "states" }, true);
@@ -434,16 +445,16 @@ static void mlpackMain()
         "number of states must be positive");
   }
 
-  if (CLI::HasParam("input_model") && CLI::HasParam("tolerance"))
+  if (IO::HasParam("input_model") && IO::HasParam("tolerance"))
   {
     Log::Info << "Tolerance of existing model in '"
-        << CLI::GetPrintableParam<HMMModel*>("input_model") << "' will be "
+        << IO::GetPrintableParam<HMMModel*>("input_model") << "' will be "
         << "replaced with specified tolerance of " << tolerance << "." << endl;
   }
 
   ReportIgnoredParam({{ "input_model", true }}, "type");
 
-  if (!CLI::HasParam("input_model"))
+  if (!IO::HasParam("input_model"))
   {
     RequireParamInSet<string>("type", { "discrete", "gaussian", "gmm",
         "diag_gmm" }, true, "unknown HMM type");
@@ -512,9 +523,9 @@ static void mlpackMain()
 
   // If we have a model file, we can autodetect the type.
   HMMModel* hmm;
-  if (CLI::HasParam("input_model"))
+  if (IO::HasParam("input_model"))
   {
-    hmm = CLI::GetParam<HMMModel*>("input_model");
+    hmm = IO::GetParam<HMMModel*>("input_model");
 
     hmm->PerformAction<Train, vector<mat>>(&trainSeq);
   }
@@ -537,5 +548,5 @@ static void mlpackMain()
   }
 
   // If necessary, save the output.
-  CLI::GetParam<HMMModel*>("output_model") = hmm;
+  IO::GetParam<HMMModel*>("output_model") = hmm;
 }
