@@ -222,7 +222,7 @@ Cluster(const MatType& data,
 
     // If we are not allowing empty clusters, then check that all of our
     // clusters have points.
-    for (size_t i = 0; i < counts.n_elem; i++)
+    for (size_t i = 0; i < counts.n_elem; ++i)
     {
       if (counts[i] == 0)
       {
@@ -321,7 +321,7 @@ Cluster(const MatType& data,
     double minDistance = std::numeric_limits<double>::infinity();
     size_t closestCluster = centroids.n_cols; // Invalid value.
 
-    for (size_t j = 0; j < centroids.n_cols; j++)
+    for (size_t j = 0; j < centroids.n_cols; ++j)
     {
       const double distance = metric.Evaluate(data.col(i), centroids.col(j));
 
