@@ -243,7 +243,7 @@ double LARS::Train(const arma::mat& matX,
   {
     // Compute the maximum correlation among inactive dimensions.
     maxCorr = 0;
-    for (size_t i = 0; i < dataRef.n_cols; i++)
+    for (size_t i = 0; i < dataRef.n_cols; ++i)
     {
       if ((!isActive[i]) && (!isIgnored[i]) && (fabs(corr(i)) > maxCorr))
       {
@@ -257,7 +257,7 @@ double LARS::Train(const arma::mat& matX,
       if (useCholesky)
       {
         // vec newGramCol = vec(activeSet.size());
-        // for (size_t i = 0; i < activeSet.size(); i++)
+        // for (size_t i = 0; i < activeSet.size(); ++i)
         // {
         //   newGramCol[i] = dot(matX.col(activeSet[i]), matX.col(changeInd));
         // }
@@ -274,7 +274,7 @@ double LARS::Train(const arma::mat& matX,
 
     // Compute signs of correlations.
     arma::vec s = arma::vec(activeSet.size());
-    for (size_t i = 0; i < activeSet.size(); i++)
+    for (size_t i = 0; i < activeSet.size(); ++i)
       s(i) = corr(activeSet[i]) / fabs(corr(activeSet[i]));
 
     // Compute the "equiangular" direction in parameter space (betaDirection).
@@ -324,8 +324,8 @@ double LARS::Train(const arma::mat& matX,
     else
     {
       arma::mat matGramActive = arma::mat(activeSet.size(), activeSet.size());
-      for (size_t i = 0; i < activeSet.size(); i++)
-        for (size_t j = 0; j < activeSet.size(); j++)
+      for (size_t i = 0; i < activeSet.size(); ++i)
+        for (size_t j = 0; j < activeSet.size(); ++j)
           matGramActive(i, j) = (*matGram)(activeSet[i], activeSet[j]);
 
       // Check for singularity.
@@ -383,7 +383,7 @@ double LARS::Train(const arma::mat& matX,
       double lassoboundOnGamma = DBL_MAX;
       size_t activeIndToKickOut = -1;
 
-      for (size_t i = 0; i < activeSet.size(); i++)
+      for (size_t i = 0; i < activeSet.size(); ++i)
       {
         double val = -beta(activeSet[i]) / betaDirection(i);
         if ((val > 0) && (val < lassoboundOnGamma))
@@ -405,7 +405,7 @@ double LARS::Train(const arma::mat& matX,
     yHat += gamma * yHatDirection;
 
     // Update the estimator.
-    for (size_t i = 0; i < activeSet.size(); i++)
+    for (size_t i = 0; i < activeSet.size(); ++i)
     {
       beta(activeSet[i]) += gamma * betaDirection(i);
     }
@@ -433,7 +433,7 @@ double LARS::Train(const arma::mat& matX,
       corr -= lambda2 * beta;
 
     double curLambda = 0;
-    for (size_t i = 0; i < activeSet.size(); i++)
+    for (size_t i = 0; i < activeSet.size(); ++i)
       curLambda += fabs(corr(activeSet[i]));
 
     curLambda /= ((double) activeSet.size());
@@ -501,7 +501,7 @@ void LARS::ComputeYHatDirection(const arma::mat& matX,
                                 arma::vec& yHatDirection)
 {
   yHatDirection.fill(0);
-  for (size_t i = 0; i < activeSet.size(); i++)
+  for (size_t i = 0; i < activeSet.size(); ++i)
     yHatDirection += betaDirection(i) * matX.col(activeSet[i]);
 }
 
@@ -614,7 +614,7 @@ void LARS::CholeskyDelete(const size_t colToKill)
     matUtriCholFactor.shed_col(colToKill); // remove column colToKill
     n--;
 
-    for (size_t k = colToKill; k < n; k++)
+    for (size_t k = colToKill; k < n; ++k)
     {
       arma::mat matG;
       arma::vec::fixed<2> rotatedVec;
