@@ -10,7 +10,7 @@
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/prereqs.hpp>
-#include <mlpack/core/util/cli.hpp>
+#include <mlpack/core/util/io.hpp>
 #include <mlpack/core/util/mlpack_main.hpp>
 
 #include "logistic_regression.hpp"
@@ -22,12 +22,17 @@ using namespace mlpack;
 using namespace mlpack::regression;
 using namespace mlpack::util;
 
-PROGRAM_INFO("L2-regularized Logistic Regression and Prediction",
-    // Short description.
+// Program Name.
+BINDING_NAME("L2-regularized Logistic Regression and Prediction");
+
+// Short description.
+BINDING_SHORT_DESC(
     "An implementation of L2-regularized logistic regression for two-class "
     "classification.  Given labeled data, a model can be trained and saved for "
-    "future use; or, a pre-trained model can be used to classify new points.",
-    // Long description.
+    "future use; or, a pre-trained model can be used to classify new points.");
+
+// Long description.
+BINDING_LONG_DESC(
     "An implementation of L2-regularized logistic regression using either the "
     "L-BFGS optimizer or SGD (stochastic gradient descent).  This solves the "
     "regression problem"
@@ -92,8 +97,11 @@ PROGRAM_INFO("L2-regularized Logistic Regression and Prediction",
     "\n\n"
     "This implementation of logistic regression does not support the general "
     "multi-class case but instead only the two-class case.  Any labels must "
-    "be either 0 or 1.  For more classes, see the softmax_regression program."
-    "\n\n"
+    "be either 0 or 1.  For more classes, see the softmax_regression "
+    "program.");
+
+// Example.
+BINDING_EXAMPLE(
     "As an example, to train a logistic regression model on the data '" +
     PRINT_DATASET("data") + "' with labels '" + PRINT_DATASET("labels") + "' "
     "with L2 regularization of 0.1, saving the model to '" +
@@ -107,13 +115,16 @@ PROGRAM_INFO("L2-regularized Logistic Regression and Prediction",
     PRINT_DATASET("predictions") + "', the following command may be used: "
     "\n\n" +
     PRINT_CALL("logistic_regression", "input_model", "lr_model", "test", "test",
-        "output", "predictions"),
-    SEE_ALSO("@softmax_regression", "#softmax_regression"),
-    SEE_ALSO("@random_forest", "#random_forest"),
-    SEE_ALSO("Logistic regression on Wikipedia",
-        "https://en.wikipedia.org/wiki/Logistic_regression"),
-    SEE_ALSO("mlpack::regression::LogisticRegression C++ class documentation",
-        "@doxygen/classmlpack_1_1regression_1_1LogisticRegression.html"));
+        "output", "predictions"));
+
+// See also...
+BINDING_SEE_ALSO("@softmax_regression", "#softmax_regression");
+BINDING_SEE_ALSO("@random_forest", "#random_forest");
+BINDING_SEE_ALSO("Logistic regression on Wikipedia",
+        "https://en.wikipedia.org/wiki/Logistic_regression");
+BINDING_SEE_ALSO("mlpack::regression::LogisticRegression C++ class "
+        "documentation",
+        "@doxygen/classmlpack_1_1regression_1_1LogisticRegression.html");
 
 // Training parameters.
 PARAM_MATRIX_IN("training", "A matrix containing the training set (the matrix "
@@ -163,20 +174,20 @@ PARAM_DOUBLE_IN("decision_boundary", "Decision boundary for prediction; if the "
 static void mlpackMain()
 {
   // Collect command-line options.
-  const double lambda = CLI::GetParam<double>("lambda");
-  const string optimizerType = CLI::GetParam<string>("optimizer");
-  const double tolerance = CLI::GetParam<double>("tolerance");
-  const double stepSize = CLI::GetParam<double>("step_size");
-  const size_t batchSize = (size_t) CLI::GetParam<int>("batch_size");
-  const size_t maxIterations = (size_t) CLI::GetParam<int>("max_iterations");
-  const double decisionBoundary = CLI::GetParam<double>("decision_boundary");
+  const double lambda = IO::GetParam<double>("lambda");
+  const string optimizerType = IO::GetParam<string>("optimizer");
+  const double tolerance = IO::GetParam<double>("tolerance");
+  const double stepSize = IO::GetParam<double>("step_size");
+  const size_t batchSize = (size_t) IO::GetParam<int>("batch_size");
+  const size_t maxIterations = (size_t) IO::GetParam<int>("max_iterations");
+  const double decisionBoundary = IO::GetParam<double>("decision_boundary");
 
   // One of training and input_model must be specified.
   RequireAtLeastOnePassed({ "training", "input_model" }, true);
 
   // If no output file is given, the user should know that the model will not be
   // saved, but only if a model is being trained.
-  if (CLI::HasParam("training"))
+  if (IO::HasParam("training"))
   {
     RequireAtLeastOnePassed({ "output_model" }, false, "trained model will not "
         "be saved");
@@ -224,12 +235,12 @@ static void mlpackMain()
 
   if (optimizerType != "sgd")
   {
-    if (CLI::HasParam("step_size"))
+    if (IO::HasParam("step_size"))
     {
       Log::Warn << PRINT_PARAM_STRING("step_size") << " ignored because "
           << "optimizer type is not 'sgd'." << std::endl;
     }
-    if (CLI::HasParam("batch_size"))
+    if (IO::HasParam("batch_size"))
     {
       Log::Warn << PRINT_PARAM_STRING("batch_size") << " ignored because "
           << "optimizer type is not 'sgd'." << std::endl;
@@ -243,45 +254,45 @@ static void mlpackMain()
   arma::Row<size_t> predictions;
 
   // Load data matrix.
-  if (CLI::HasParam("training"))
-    regressors = std::move(CLI::GetParam<arma::mat>("training"));
+  if (IO::HasParam("training"))
+    regressors = std::move(IO::GetParam<arma::mat>("training"));
 
   // Load the model, if necessary.
   LogisticRegression<>* model;
-  if (CLI::HasParam("input_model"))
-    model = CLI::GetParam<LogisticRegression<>*>("input_model");
+  if (IO::HasParam("input_model"))
+    model = IO::GetParam<LogisticRegression<>*>("input_model");
   else
   {
     model = new LogisticRegression<>(0, 0);
 
     // Set the size of the parameters vector, if necessary.
-    if (!CLI::HasParam("labels"))
+    if (!IO::HasParam("labels"))
       model->Parameters() = arma::zeros<arma::rowvec>(regressors.n_rows);
     else
       model->Parameters() = arma::zeros<arma::rowvec>(regressors.n_rows + 1);
   }
 
   // Check if the responses are in a separate file.
-  if (CLI::HasParam("training") && CLI::HasParam("labels"))
+  if (IO::HasParam("training") && IO::HasParam("labels"))
   {
-    responses = std::move(CLI::GetParam<arma::Row<size_t>>("labels"));
+    responses = std::move(IO::GetParam<arma::Row<size_t>>("labels"));
     if (responses.n_cols != regressors.n_cols)
     {
       // Clean memory if needed.
-      if (!CLI::HasParam("input_model"))
+      if (!IO::HasParam("input_model"))
         delete model;
 
       Log::Fatal << "The labels must have the same number of points as the "
           << "training dataset." << endl;
     }
   }
-  else if (CLI::HasParam("training"))
+  else if (IO::HasParam("training"))
   {
     // Checking the size of training data if no labels are passed.
     if (regressors.n_rows < 2)
     {
       // Clean memory if needed.
-      if (!CLI::HasParam("input_model"))
+      if (!IO::HasParam("input_model"))
         delete model;
 
       Log::Fatal << "Can't get responses from training data since it has less "
@@ -295,10 +306,10 @@ static void mlpackMain()
   }
 
   // Verify the labels.
-  if (CLI::HasParam("training") && max(responses) > 1)
+  if (IO::HasParam("training") && max(responses) > 1)
   {
     // Clean memory if needed.
-    if (!CLI::HasParam("input_model"))
+    if (!IO::HasParam("input_model"))
       delete model;
 
     Log::Fatal << "The labels must be either 0 or 1, not " << max(responses)
@@ -306,7 +317,7 @@ static void mlpackMain()
   }
 
   // Now, do the training.
-  if (CLI::HasParam("training"))
+  if (IO::HasParam("training"))
   {
     model->Lambda() = lambda;
 
@@ -334,16 +345,16 @@ static void mlpackMain()
     }
   }
 
-  if (CLI::HasParam("test"))
+  if (IO::HasParam("test"))
   {
-    const arma::mat& testSet = CLI::GetParam<arma::mat>("test");
+    const arma::mat& testSet = IO::GetParam<arma::mat>("test");
 
     // Checking the dimensionality of the test data.
     if (testSet.n_rows != model->Parameters().n_cols - 1)
     {
       // Clean memory if needed.
       const size_t trainingDimensionality = model->Parameters().n_cols - 1;
-      if (!CLI::HasParam("input_model"))
+      if (!IO::HasParam("input_model"))
         delete model;
 
       Log::Fatal << "Test data dimensionality (" << testSet.n_rows << ") must "
@@ -353,36 +364,36 @@ static void mlpackMain()
 
     // We must perform predictions on the test set.  Training (and the
     // optimizer) are irrelevant here; we'll pass in the model we have.
-    if (CLI::HasParam("predictions") || CLI::HasParam("output"))
+    if (IO::HasParam("predictions") || IO::HasParam("output"))
     {
       Log::Info << "Predicting classes of points in '"
-          << CLI::GetPrintableParam<arma::mat>("test") << "'." << endl;
+          << IO::GetPrintableParam<arma::mat>("test") << "'." << endl;
       model->Classify(testSet, predictions, decisionBoundary);
 
-      // The CLI param "output" is deprecated and replaced by "predictions"
+      // The IO param "output" is deprecated and replaced by "predictions"
       // "output" parameter will be removed in mlpack 4.
-      if (CLI::HasParam("predictions"))
-        CLI::GetParam<arma::Row<size_t>>("predictions") = predictions;
-      if (CLI::HasParam("output"))
-        CLI::GetParam<arma::Row<size_t>>("output") = std::move(predictions);
+      if (IO::HasParam("predictions"))
+        IO::GetParam<arma::Row<size_t>>("predictions") = predictions;
+      if (IO::HasParam("output"))
+        IO::GetParam<arma::Row<size_t>>("output") = std::move(predictions);
     }
 
-    // The CLI param "output_probabilities" is deprecated
+    // The IO param "output_probabilities" is deprecated
     // and replaced by "probabilities"
     // "output_probabilities" parameter will be removed in mlpack 4.
-    if (CLI::HasParam("output_probabilities") || CLI::HasParam("probabilities"))
+    if (IO::HasParam("output_probabilities") || IO::HasParam("probabilities"))
     {
       Log::Info << "Calculating class probabilities of points in '"
-          << CLI::GetPrintableParam<arma::mat>("test") << "'." << endl;
+          << IO::GetPrintableParam<arma::mat>("test") << "'." << endl;
       arma::mat probabilities;
       model->Classify(testSet, probabilities);
 
-      if (CLI::HasParam("output_probabilities"))
-        CLI::GetParam<arma::mat>("output_probabilities") = probabilities;
-      if (CLI::HasParam("probabilities"))
-        CLI::GetParam<arma::mat>("probabilities") = std::move(probabilities);
+      if (IO::HasParam("output_probabilities"))
+        IO::GetParam<arma::mat>("output_probabilities") = probabilities;
+      if (IO::HasParam("probabilities"))
+        IO::GetParam<arma::mat>("probabilities") = std::move(probabilities);
     }
   }
 
-  CLI::GetParam<LogisticRegression<>*>("output_model") = model;
+  IO::GetParam<LogisticRegression<>*>("output_model") = model;
 }
