@@ -11,7 +11,7 @@
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/prereqs.hpp>
-#include <mlpack/core/util/cli.hpp>
+#include <mlpack/core/util/io.hpp>
 #include <mlpack/core/util/mlpack_main.hpp>
 
 #include <string>
@@ -32,19 +32,25 @@ using namespace mlpack::util;
 // Convenience typedef.
 typedef NSModel<FurthestNS> KFNModel;
 
-// Information about the program itself.
-PROGRAM_INFO("k-Furthest-Neighbors Search",
-    // Short description.
+// Program Name.
+BINDING_NAME("k-Furthest-Neighbors Search");
+
+// Short description.
+BINDING_SHORT_DESC(
     "An implementation of k-furthest-neighbor search using single-tree and "
     "dual-tree algorithms.  Given a set of reference points and query points, "
     "this can find the k furthest neighbors in the reference set of each query"
-    " point using trees; trees that are built can be saved for future use.",
-    // Long description.
+    " point using trees; trees that are built can be saved for future use.");
+
+// Long description.
+BINDING_LONG_DESC(
     "This program will calculate the k-furthest-neighbors of a set of "
     "points. You may specify a separate set of reference points and query "
     "points, or just a reference set which will be used as both the reference "
-    "and query set."
-    "\n\n"
+    "and query set.");
+
+// Example.
+BINDING_EXAMPLE(
     "For example, the following will calculate the 5 furthest neighbors of each"
     "point in " + PRINT_DATASET("input") + " and store the distances in " +
     PRINT_DATASET("distances") + " and the neighbors in " +
@@ -57,13 +63,15 @@ PROGRAM_INFO("k-Furthest-Neighbors Search",
     "neighbors output matrix corresponds to the index of the point in the "
     "reference set which is the j'th furthest neighbor from the point in the "
     "query set with index i.  Row i and column j in the distances output file "
-    "corresponds to the distance between those two points.",
-    SEE_ALSO("@approx_kfn", "#approx_kfn"),
-    SEE_ALSO("@knn", "#knn"),
-    SEE_ALSO("Tree-independent dual-tree algorithms (pdf)",
-        "http://proceedings.mlr.press/v28/curtin13.pdf"),
-    SEE_ALSO("mlpack::neighbor::NeighborSearch C++ class documentation",
-        "@doxygen/classmlpack_1_1neighbor_1_1NeighborSearch.html"));
+    "corresponds to the distance between those two points.");
+
+// See also...
+BINDING_SEE_ALSO("@approx_kfn", "#approx_kfn");
+BINDING_SEE_ALSO("@knn", "#knn");
+BINDING_SEE_ALSO("Tree-independent dual-tree algorithms (pdf)",
+        "http://proceedings.mlr.press/v28/curtin13.pdf");
+BINDING_SEE_ALSO("mlpack::neighbor::NeighborSearch C++ class documentation",
+        "@doxygen/classmlpack_1_1neighbor_1_1NeighborSearch.html");
 
 // Define our input parameters that this program will take.
 PARAM_MATRIX_IN("reference", "Matrix containing the reference dataset.", "r");
@@ -109,8 +117,8 @@ PARAM_DOUBLE_IN("percentage", "If specified, will do approximate furthest "
 
 static void mlpackMain()
 {
-  if (CLI::GetParam<int>("seed") != 0)
-    math::RandomSeed((size_t) CLI::GetParam<int>("seed"));
+  if (IO::GetParam<int>("seed") != 0)
+    math::RandomSeed((size_t) IO::GetParam<int>("seed"));
   else
     math::RandomSeed((size_t) std::time(NULL));
 
@@ -122,7 +130,7 @@ static void mlpackMain()
 
   // Notify the user of parameters that will be only be considered for query
   // tree.
-  if (CLI::HasParam("input_model") && CLI::HasParam("leaf_size"))
+  if (IO::HasParam("input_model") && IO::HasParam("leaf_size"))
   {
     Log::Warn << PRINT_PARAM_STRING("leaf_size") << " will only be considered"
         << " for the query tree, because "
@@ -134,7 +142,7 @@ static void mlpackMain()
       "no results will be saved");
 
   // If the user specifies k but no output files, they should be warned.
-  if (CLI::HasParam("k"))
+  if (IO::HasParam("k"))
   {
     RequireAtLeastOnePassed({ "neighbors", "distances" }, false,
         "furthest neighbor search results will not be saved");
@@ -150,29 +158,29 @@ static void mlpackMain()
   // Sanity check on leaf size.
   RequireParamValue<int>("leaf_size", [](int x) { return x > 0; },
       true, "leaf size must be positive");
-  const int lsInt = CLI::GetParam<int>("leaf_size");
+  const int lsInt = IO::GetParam<int>("leaf_size");
 
   // Sanity check on epsilon.
-  double epsilon = CLI::GetParam<double>("epsilon");
+  double epsilon = IO::GetParam<double>("epsilon");
   RequireParamValue<double>("epsilon", [](double x)
       { return x >= 0.0 && x < 1; }, true,
           "epsilon must be in the range [0, 1).");
 
   // Sanity check on percentage.
-  const double percentage = CLI::GetParam<double>("percentage");
+  const double percentage = IO::GetParam<double>("percentage");
   RequireParamValue<double>("percentage",
       [](double x) { return x > 0.0 && x <= 1.0; }, true,
       "percentage must be in the range (0, 1]");
 
   ReportIgnoredParam({{ "epsilon", true }}, "percentage");
 
-  if (CLI::HasParam("percentage"))
+  if (IO::HasParam("percentage"))
     epsilon = 1 - percentage;
 
   // We either have to load the reference data, or we have to load the model.
   NSModel<FurthestNS>* kfn;
 
-  const string algorithm = CLI::GetParam<string>("algorithm");
+  const string algorithm = IO::GetParam<string>("algorithm");
   RequireParamInSet<string>("algorithm", { "naive", "single_tree", "dual_tree",
       "greedy" }, true, "unknown neighbor search algorithm");
   NeighborSearchMode searchMode = DUAL_TREE_MODE;
@@ -186,14 +194,14 @@ static void mlpackMain()
   else if (algorithm == "greedy")
     searchMode = GREEDY_SINGLE_TREE_MODE;
 
-  if (CLI::HasParam("reference"))
+  if (IO::HasParam("reference"))
   {
     // Get all the parameters.
     RequireParamInSet<string>("tree_type", { "kd", "cover", "r", "r-star",
         "ball", "x", "hilbert-r", "r-plus", "r-plus-plus", "vp", "rp", "max-rp",
         "ub", "oct" }, true, "unknown tree type");
-    const string treeType = CLI::GetParam<string>("tree_type");
-    const bool randomBasis = CLI::HasParam("random_basis");
+    const string treeType = IO::GetParam<string>("tree_type");
+    const bool randomBasis = IO::HasParam("random_basis");
 
     kfn = new KFNModel();
 
@@ -231,9 +239,9 @@ static void mlpackMain()
     kfn->RandomBasis() = randomBasis;
 
     Log::Info << "Using reference data from "
-        << CLI::GetPrintableParam<arma::mat>("reference") << "." << endl;
+        << IO::GetPrintableParam<arma::mat>("reference") << "." << endl;
 
-    arma::mat referenceSet = std::move(CLI::GetParam<arma::mat>("reference"));
+    arma::mat referenceSet = std::move(IO::GetParam<arma::mat>("reference"));
 
     kfn->BuildModel(std::move(referenceSet), size_t(lsInt), searchMode,
         epsilon);
@@ -241,7 +249,7 @@ static void mlpackMain()
   else
   {
     // Load the model from file.
-    kfn = CLI::GetParam<KFNModel*>("input_model");
+    kfn = IO::GetParam<KFNModel*>("input_model");
 
     // Adjust search mode.
     kfn->SearchMode() = searchMode;
@@ -250,31 +258,31 @@ static void mlpackMain()
     // If leaf_size wasn't provided, let's consider the current value in the
     // loaded model.  Else, update it (only considered when building the query
     // tree).
-    if (CLI::HasParam("leaf_size"))
+    if (IO::HasParam("leaf_size"))
       kfn->LeafSize() = size_t(lsInt);
 
     Log::Info << "Using kFN model from '"
-        << CLI::GetPrintableParam<KFNModel*>("input_model") << "' (trained on "
+        << IO::GetPrintableParam<KFNModel*>("input_model") << "' (trained on "
         << kfn->Dataset().n_rows << "x" << kfn->Dataset().n_cols
         << " dataset)." << endl;
   }
 
   // Perform search, if desired.
-  if (CLI::HasParam("k"))
+  if (IO::HasParam("k"))
   {
-    const size_t k = (size_t) CLI::GetParam<int>("k");
+    const size_t k = (size_t) IO::GetParam<int>("k");
 
     arma::mat queryData;
-    if (CLI::HasParam("query"))
+    if (IO::HasParam("query"))
     {
       Log::Info << "Using query data from "
-          << CLI::GetPrintableParam<arma::mat>("query") << "." << endl;
-      queryData = std::move(CLI::GetParam<arma::mat>("query"));
+          << IO::GetPrintableParam<arma::mat>("query") << "." << endl;
+      queryData = std::move(IO::GetParam<arma::mat>("query"));
       if (queryData.n_rows != kfn->Dataset().n_rows)
       {
         // Clean memory if needed.
         const size_t dimensions = kfn->Dataset().n_rows;
-        if (CLI::HasParam("reference"))
+        if (IO::HasParam("reference"))
           delete kfn;
         Log::Fatal << "Query has invalid dimensions (" << queryData.n_rows <<
             "); should be " << dimensions << "!" << endl;
@@ -288,7 +296,7 @@ static void mlpackMain()
     {
       // Clean memory if needed.
       const size_t referencePoints = kfn->Dataset().n_cols;
-      if (CLI::HasParam("reference"))
+      if (IO::HasParam("reference"))
         delete kfn;
       Log::Fatal << "Invalid k: " << k << "; must be greater than 0 and less "
           << "than or equal to the number of reference points ("
@@ -297,11 +305,11 @@ static void mlpackMain()
 
     // Sanity check on k value: must not be equal to the number of reference
     // points when query data has not been provided.
-    if (!CLI::HasParam("query") && k == kfn->Dataset().n_cols)
+    if (!IO::HasParam("query") && k == kfn->Dataset().n_cols)
     {
       // Clean memory if needed.
       const size_t referencePoints = kfn->Dataset().n_cols;
-      if (CLI::HasParam("reference"))
+      if (IO::HasParam("reference"))
         delete kfn;
       Log::Fatal << "Invalid k: " << k << "; must be less than the number of "
           << "reference points (" << referencePoints << ") if query data has "
@@ -312,14 +320,14 @@ static void mlpackMain()
     arma::Mat<size_t> neighbors;
     arma::mat distances;
 
-    if (CLI::HasParam("query"))
+    if (IO::HasParam("query"))
       kfn->Search(std::move(queryData), k, neighbors, distances);
     else
       kfn->Search(k, neighbors, distances);
     Log::Info << "Search complete." << endl;
 
     // Calculate the effective error, if desired.
-    if (CLI::HasParam("true_distances"))
+    if (IO::HasParam("true_distances"))
     {
       if (kfn->Epsilon() == 0)
         Log::Warn << PRINT_PARAM_STRING("true_distances") << " specified, but "
@@ -327,13 +335,13 @@ static void mlpackMain()
             << "error!" << endl;
 
       arma::mat trueDistances =
-          std::move(CLI::GetParam<arma::mat>("true_distances"));
+          std::move(IO::GetParam<arma::mat>("true_distances"));
 
       if (trueDistances.n_rows != distances.n_rows ||
           trueDistances.n_cols != distances.n_cols)
       {
         // Clean memory if needed.
-        if (CLI::HasParam("reference"))
+        if (IO::HasParam("reference"))
           delete kfn;
         Log::Fatal << "The true distances file must have the same number of "
             << "values than the set of distances being queried!" << endl;
@@ -344,7 +352,7 @@ static void mlpackMain()
     }
 
     // Calculate the recall, if desired.
-    if (CLI::HasParam("true_neighbors"))
+    if (IO::HasParam("true_neighbors"))
     {
       if (kfn->Epsilon() == 0)
         Log::Warn << PRINT_PARAM_STRING("true_neighbors") << " specified, but "
@@ -352,13 +360,13 @@ static void mlpackMain()
             << "recall!" << endl;
 
       arma::Mat<size_t> trueNeighbors =
-          std::move(CLI::GetParam<arma::Mat<size_t>>("true_neighbors"));
+          std::move(IO::GetParam<arma::Mat<size_t>>("true_neighbors"));
 
       if (trueNeighbors.n_rows != neighbors.n_rows ||
           trueNeighbors.n_cols != neighbors.n_cols)
       {
         // Clean memory if needed.
-        if (CLI::HasParam("reference"))
+        if (IO::HasParam("reference"))
           delete kfn;
         Log::Fatal << "The true neighbors file must have the same number of "
             << "values than the set of neighbors being queried!" << endl;
@@ -368,9 +376,9 @@ static void mlpackMain()
     }
 
     // Save output.
-    CLI::GetParam<arma::Mat<size_t>>("neighbors") = std::move(neighbors);
-    CLI::GetParam<arma::mat>("distances") = std::move(distances);
+    IO::GetParam<arma::Mat<size_t>>("neighbors") = std::move(neighbors);
+    IO::GetParam<arma::mat>("distances") = std::move(distances);
   }
 
-  CLI::GetParam<KFNModel*>("output_model") = kfn;
+  IO::GetParam<KFNModel*>("output_model") = kfn;
 }
