@@ -11,7 +11,7 @@
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/prereqs.hpp>
-#include <mlpack/core/util/cli.hpp>
+#include <mlpack/core/util/io.hpp>
 #include <mlpack/core/metrics/lmetric.hpp>
 #include <mlpack/core/tree/cover_tree.hpp>
 #include <mlpack/core/util/mlpack_main.hpp>
@@ -34,20 +34,26 @@ using namespace mlpack::util;
 // Convenience typedef.
 typedef NSModel<NearestNeighborSort> KNNModel;
 
-// Information about the program itself.
-PROGRAM_INFO("k-Nearest-Neighbors Search",
-    // Short description.
+// Program Name.
+BINDING_NAME("k-Nearest-Neighbors Search");
+
+// Short description.
+BINDING_SHORT_DESC(
     "An implementation of k-nearest-neighbor search using single-tree and "
     "dual-tree algorithms.  Given a set of reference points and query points, "
     "this can find the k nearest neighbors in the reference set of each query "
-    "point using trees; trees that are built can be saved for future use.",
-    // Long description.
+    "point using trees; trees that are built can be saved for future use.");
+
+// Long description.
+BINDING_LONG_DESC(
     "This program will calculate the k-nearest-neighbors of a set of "
     "points using kd-trees or cover trees (cover tree support is experimental "
     "and may be slow). You may specify a separate set of "
     "reference points and query points, or just a reference set which will be "
-    "used as both the reference and query set."
-    "\n\n"
+    "used as both the reference and query set.");
+
+// Example.
+BINDING_EXAMPLE(
     "For example, the following command will calculate the 5 nearest neighbors "
     "of each point in " + PRINT_DATASET("input") + " and store the distances "
     "in " + PRINT_DATASET("distances") + " and the neighbors in " +
@@ -60,16 +66,18 @@ PROGRAM_INFO("k-Nearest-Neighbors Search",
     "output matrix corresponds to the index of the point in the reference set "
     "which is the j'th nearest neighbor from the point in the query set with "
     "index i.  Row j and column i in the distances output matrix corresponds to"
-    " the distance between those two points.",
-    SEE_ALSO("@lsh", "#lsh"),
-    SEE_ALSO("@krann", "#krann"),
-    SEE_ALSO("@kfn", "#kfn"),
-    SEE_ALSO("NeighborSearch tutorial (k-nearest-neighbors)",
-        "@doxygen/nstutorial.html"),
-    SEE_ALSO("Tree-independent dual-tree algorithms (pdf)",
-        "http://proceedings.mlr.press/v28/curtin13.pdf"),
-    SEE_ALSO("mlpack::neighbor::NeighborSearch C++ class documentation",
-        "@doxygen/classmlpack_1_1neighbor_1_1NeighborSearch.html"));
+    " the distance between those two points.");
+
+// See also...
+BINDING_SEE_ALSO("@lsh", "#lsh");
+BINDING_SEE_ALSO("@krann", "#krann");
+BINDING_SEE_ALSO("@kfn", "#kfn");
+BINDING_SEE_ALSO("NeighborSearch tutorial (k-nearest-neighbors)",
+        "@doxygen/nstutorial.html");
+BINDING_SEE_ALSO("Tree-independent dual-tree algorithms (pdf)",
+        "http://proceedings.mlr.press/v28/curtin13.pdf");
+BINDING_SEE_ALSO("mlpack::neighbor::NeighborSearch C++ class documentation",
+        "@doxygen/classmlpack_1_1neighbor_1_1NeighborSearch.html");
 
 // Define our input parameters that this program will take.
 PARAM_MATRIX_IN("reference", "Matrix containing the reference dataset.", "r");
@@ -117,8 +125,8 @@ PARAM_DOUBLE_IN("epsilon", "If specified, will do approximate nearest neighbor "
 
 static void mlpackMain()
 {
-  if (CLI::GetParam<int>("seed") != 0)
-    math::RandomSeed((size_t) CLI::GetParam<int>("seed"));
+  if (IO::GetParam<int>("seed") != 0)
+    math::RandomSeed((size_t) IO::GetParam<int>("seed"));
   else
     math::RandomSeed((size_t) std::time(NULL));
 
@@ -129,7 +137,7 @@ static void mlpackMain()
   ReportIgnoredParam({{ "input_model", true }}, "random_basis");
   ReportIgnoredParam({{ "input_model", true }}, "tau");
   ReportIgnoredParam({{ "input_model", true }}, "rho");
-  if (CLI::HasParam("input_model") && CLI::HasParam("leaf_size"))
+  if (IO::HasParam("input_model") && IO::HasParam("leaf_size"))
   {
     Log::Warn << PRINT_PARAM_STRING("leaf_size") << " will only be considered"
         << " for the query tree, because --input_model_file is specified."
@@ -141,7 +149,7 @@ static void mlpackMain()
       "no results will be saved");
 
   // If the user specifies k but no output files, they should be warned.
-  if (CLI::HasParam("k"))
+  if (IO::HasParam("k"))
   {
     RequireAtLeastOnePassed({ "neighbors", "distances" }, false,
         "nearest neighbor search results will not be saved");
@@ -157,34 +165,34 @@ static void mlpackMain()
   // Sanity check on leaf size.
   RequireParamValue<int>("leaf_size", [](int x) { return x > 0; },
       true, "leaf size must be positive");
-  const int lsInt = CLI::GetParam<int>("leaf_size");
+  const int lsInt = IO::GetParam<int>("leaf_size");
 
   // Sanity check on tau.
   RequireParamValue<double>("tau", [](double x) { return x >= 0.0; },
       true, "tau must be positive");
-  const double tau = CLI::GetParam<double>("tau");
+  const double tau = IO::GetParam<double>("tau");
 
 
   // Sanity check on rho.
-  const double rho = CLI::GetParam<double>("rho");
+  const double rho = IO::GetParam<double>("rho");
   RequireParamValue<double>("rho",
       [](double x) { return x >= 0.0 && x <= 1.0; }, true,
       "rho must be in the range [0, 1]");
-  if (CLI::GetParam<string>("tree_type") != "spill")
+  if (IO::GetParam<string>("tree_type") != "spill")
   {
     ReportIgnoredParam("tau", "spill trees are not being used");
     ReportIgnoredParam("rho", "spill trees are not being used");
   }
 
   // Sanity check on epsilon.
-  const double epsilon = CLI::GetParam<double>("epsilon");
+  const double epsilon = IO::GetParam<double>("epsilon");
   RequireParamValue<double>("epsilon", [](double x) { return x >= 0.0; }, true,
       "epsilon must be positive");
 
   // We either have to load the reference data, or we have to load the model.
   KNNModel* knn;
 
-  const string algorithm = CLI::GetParam<string>("algorithm");
+  const string algorithm = IO::GetParam<string>("algorithm");
   RequireParamInSet<string>("algorithm", { "naive", "single_tree", "dual_tree",
       "greedy" }, true, "unknown neighbor search algorithm");
   NeighborSearchMode searchMode = DUAL_TREE_MODE;
@@ -198,11 +206,11 @@ static void mlpackMain()
   else if (algorithm == "greedy")
     searchMode = GREEDY_SINGLE_TREE_MODE;
 
-  if (CLI::HasParam("reference"))
+  if (IO::HasParam("reference"))
   {
     // Get all the parameters.
-    const string treeType = CLI::GetParam<string>("tree_type");
-    const bool randomBasis = CLI::HasParam("random_basis");
+    const string treeType = IO::GetParam<string>("tree_type");
+    const bool randomBasis = IO::HasParam("random_basis");
 
     KNNModel::TreeTypes tree = KNNModel::KD_TREE;
     RequireParamInSet<string>("tree_type", { "kd", "cover", "r", "r-star",
@@ -249,9 +257,9 @@ static void mlpackMain()
     knn->Rho() = rho;
 
     Log::Info << "Using reference data from "
-        << CLI::GetPrintableParam<arma::mat>("reference") << "." << endl;
+        << IO::GetPrintableParam<arma::mat>("reference") << "." << endl;
 
-    arma::mat referenceSet = std::move(CLI::GetParam<arma::mat>("reference"));
+    arma::mat referenceSet = std::move(IO::GetParam<arma::mat>("reference"));
 
     knn->BuildModel(std::move(referenceSet), size_t(lsInt), searchMode,
         epsilon);
@@ -259,7 +267,7 @@ static void mlpackMain()
   else
   {
     // Load the model from file.
-    knn = CLI::GetParam<KNNModel*>("input_model");
+    knn = IO::GetParam<KNNModel*>("input_model");
 
     // Adjust search mode.
     knn->SearchMode() = searchMode;
@@ -268,31 +276,31 @@ static void mlpackMain()
     // If leaf_size wasn't provided, let's consider the current value in the
     // loaded model.  Else, update it (only considered when building the query
     // tree).
-    if (CLI::HasParam("leaf_size"))
+    if (IO::HasParam("leaf_size"))
       knn->LeafSize() = size_t(lsInt);
 
     Log::Info << "Loaded kNN model from '"
-        << CLI::GetPrintableParam<KNNModel*>("input_model") << "' (trained on "
+        << IO::GetPrintableParam<KNNModel*>("input_model") << "' (trained on "
         << knn->Dataset().n_rows << "x" << knn->Dataset().n_cols
         << " dataset)." << endl;
   }
 
   // Perform search, if desired.
-  if (CLI::HasParam("k"))
+  if (IO::HasParam("k"))
   {
-    const size_t k = (size_t) CLI::GetParam<int>("k");
+    const size_t k = (size_t) IO::GetParam<int>("k");
 
     arma::mat queryData;
-    if (CLI::HasParam("query"))
+    if (IO::HasParam("query"))
     {
       Log::Info << "Using query data from "
-          << CLI::GetPrintableParam<arma::mat>("query") << "." << endl;
-      queryData = std::move(CLI::GetParam<arma::mat>("query"));
+          << IO::GetPrintableParam<arma::mat>("query") << "." << endl;
+      queryData = std::move(IO::GetParam<arma::mat>("query"));
       if (queryData.n_rows != knn->Dataset().n_rows)
       {
         // Clean memory if needed before crashing.
         const size_t dimensions = knn->Dataset().n_rows;
-        if (CLI::HasParam("reference"))
+        if (IO::HasParam("reference"))
           delete knn;
         Log::Fatal << "Query has invalid dimensions(" << queryData.n_rows <<
             "); should be " << dimensions << "!" << endl;
@@ -306,7 +314,7 @@ static void mlpackMain()
     {
       // Clean memory if needed before crashing.
       const size_t referencePoints = knn->Dataset().n_cols;
-      if (CLI::HasParam("reference"))
+      if (IO::HasParam("reference"))
         delete knn;
       Log::Fatal << "Invalid k: " << k << "; must be greater than 0 and less "
           << "than or equal to the number of reference points ("
@@ -315,11 +323,11 @@ static void mlpackMain()
 
     // Sanity check on k value: must not be equal to the number of reference
     // points when query data has not been provided.
-    if (!CLI::HasParam("query") && k == knn->Dataset().n_cols)
+    if (!IO::HasParam("query") && k == knn->Dataset().n_cols)
     {
       // Clean memory if needed before crashing.
       const size_t referencePoints = knn->Dataset().n_cols;
-      if (CLI::HasParam("reference"))
+      if (IO::HasParam("reference"))
         delete knn;
       Log::Fatal << "Invalid k: " << k << "; must be less than the number of "
           << "reference points (" << referencePoints << ") if query data has "
@@ -330,14 +338,14 @@ static void mlpackMain()
     arma::Mat<size_t> neighbors;
     arma::mat distances;
 
-    if (CLI::HasParam("query"))
+    if (IO::HasParam("query"))
       knn->Search(std::move(queryData), k, neighbors, distances);
     else
       knn->Search(k, neighbors, distances);
     Log::Info << "Search complete." << endl;
 
     // Calculate the effective error, if desired.
-    if (CLI::HasParam("true_distances"))
+    if (IO::HasParam("true_distances"))
     {
       if (knn->TreeType() != KNNModel::SPILL_TREE && knn->Epsilon() == 0)
         Log::Warn << PRINT_PARAM_STRING("true_distances") << "specified, but "
@@ -345,12 +353,12 @@ static void mlpackMain()
             << "error!" << endl;
 
       arma::mat trueDistances =
-          std::move(CLI::GetParam<arma::mat>("true_distances"));
+          std::move(IO::GetParam<arma::mat>("true_distances"));
 
       if (trueDistances.n_rows != distances.n_rows ||
           trueDistances.n_cols != distances.n_cols)
       {
-        if (CLI::HasParam("reference"))
+        if (IO::HasParam("reference"))
           delete knn;
         Log::Fatal << "The true distances file must have the same number of "
             << "values than the set of distances being queried!" << endl;
@@ -361,7 +369,7 @@ static void mlpackMain()
     }
 
     // Calculate the recall, if desired.
-    if (CLI::HasParam("true_neighbors"))
+    if (IO::HasParam("true_neighbors"))
     {
       if (knn->TreeType() != KNNModel::SPILL_TREE && knn->Epsilon() == 0)
         Log::Warn << PRINT_PARAM_STRING("true_neighbors") << " specified, but "
@@ -369,12 +377,12 @@ static void mlpackMain()
             << "recall!" << endl;
 
       arma::Mat<size_t> trueNeighbors =
-          std::move(CLI::GetParam<arma::Mat<size_t>>("true_neighbors"));
+          std::move(IO::GetParam<arma::Mat<size_t>>("true_neighbors"));
 
       if (trueNeighbors.n_rows != neighbors.n_rows ||
           trueNeighbors.n_cols != neighbors.n_cols)
       {
-        if (CLI::HasParam("reference"))
+        if (IO::HasParam("reference"))
           delete knn;
         Log::Fatal << "The true neighbors file must have the same number of "
             << "values than the set of neighbors being queried!" << endl;
@@ -384,9 +392,9 @@ static void mlpackMain()
     }
 
     // Save output.
-    CLI::GetParam<arma::Mat<size_t>>("neighbors") = std::move(neighbors);
-    CLI::GetParam<arma::mat>("distances") = std::move(distances);
+    IO::GetParam<arma::Mat<size_t>>("neighbors") = std::move(neighbors);
+    IO::GetParam<arma::mat>("distances") = std::move(distances);
   }
 
-  CLI::GetParam<KNNModel*>("output_model") = knn;
+  IO::GetParam<KNNModel*>("output_model") = knn;
 }
