@@ -11,18 +11,23 @@
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/prereqs.hpp>
-#include <mlpack/core/util/cli.hpp>
+#include <mlpack/core/util/io.hpp>
 #include <mlpack/core/util/mlpack_main.hpp>
 #include <mlpack/core/math/random.hpp>
 #include "radical.hpp"
 
-PROGRAM_INFO("RADICAL",
-    // Short description.
+// Program Name.
+BINDING_NAME("RADICAL");
+
+// Short description.
+BINDING_SHORT_DESC(
     "An implementation of RADICAL, a method for independent component analysis "
     "(ICA).  Given a dataset, this can decompose the dataset into an unmixing "
     "matrix and an independent component matrix; this can be useful for "
-    "preprocessing.",
-    // Long description.
+    "preprocessing.");
+
+// Long description.
+BINDING_LONG_DESC(
     "An implementation of RADICAL, a method for independent component analysis "
     "(ICA).  Assuming that we have an input matrix X, the goal is to find a "
     "square unmixing matrix W such that Y = W * X and the dimensions of Y are "
@@ -33,20 +38,24 @@ PROGRAM_INFO("RADICAL",
     PRINT_PARAM_STRING("input") + " parameter.  The output matrix Y may be "
     "saved with the " + PRINT_PARAM_STRING("output_ic") + " output parameter, "
     "and the output unmixing matrix W may be saved with the " +
-    PRINT_PARAM_STRING("output_unmixing") + " output parameter."
-    "\n\n"
+    PRINT_PARAM_STRING("output_unmixing") + " output parameter.");
+
+// Example.
+BINDING_EXAMPLE(
     "For example, to perform ICA on the matrix " + PRINT_DATASET("X") + " with "
     "40 replicates, saving the independent components to " +
     PRINT_DATASET("ic") + ", the following command may be used: "
     "\n\n" +
-    PRINT_CALL("radical", "input", "X", "replicates", 40, "output_ic", "ic"),
-    SEE_ALSO("Independent component analysis on Wikipedia",
-        "https://en.wikipedia.org/wiki/Independent_component_analysis"),
-    SEE_ALSO("ICA using spacings estimates of entropy (pdf)",
+    PRINT_CALL("radical", "input", "X", "replicates", 40, "output_ic", "ic"));
+
+// See also...
+BINDING_SEE_ALSO("Independent component analysis on Wikipedia",
+        "https://en.wikipedia.org/wiki/Independent_component_analysis");
+BINDING_SEE_ALSO("ICA using spacings estimates of entropy (pdf)",
         "http://www.jmlr.org/papers/volume4/learned-miller03a/"
-        "learned-miller03a.pdf"),
-    SEE_ALSO("mlpack::radical::Radical C++ class documentation",
-        "@doxygen/classmlpack_1_1radical_1_1Radical.html"));
+        "learned-miller03a.pdf");
+BINDING_SEE_ALSO("mlpack::radical::Radical C++ class documentation",
+        "@doxygen/classmlpack_1_1radical_1_1Radical.html");
 
 PARAM_MATRIX_IN_REQ("input", "Input dataset for ICA.", "i");
 
@@ -75,8 +84,8 @@ using namespace arma;
 static void mlpackMain()
 {
   // Set random seed.
-  if (CLI::GetParam<int>("seed") != 0)
-    RandomSeed((size_t) CLI::GetParam<int>("seed"));
+  if (IO::GetParam<int>("seed") != 0)
+    RandomSeed((size_t) IO::GetParam<int>("seed"));
   else
     RandomSeed((size_t) std::time(NULL));
 
@@ -95,13 +104,13 @@ static void mlpackMain()
       "number of sweeps must be 0 or greater");
 
   // Load the data.
-  mat matX = std::move(CLI::GetParam<mat>("input"));
+  mat matX = std::move(IO::GetParam<mat>("input"));
 
   // Load parameters.
-  double noiseStdDev = CLI::GetParam<double>("noise_std_dev");
-  size_t nReplicates = CLI::GetParam<int>("replicates");
-  size_t nAngles = CLI::GetParam<int>("angles");
-  size_t nSweeps = CLI::GetParam<int>("sweeps");
+  double noiseStdDev = IO::GetParam<double>("noise_std_dev");
+  size_t nReplicates = IO::GetParam<int>("replicates");
+  size_t nAngles = IO::GetParam<int>("angles");
+  size_t nSweeps = IO::GetParam<int>("sweeps");
 
   if (nSweeps == 0)
   {
@@ -115,18 +124,18 @@ static void mlpackMain()
   rad.DoRadical(matX, matY, matW);
 
   // Save results.
-  if (CLI::HasParam("output_ic"))
-    CLI::GetParam<mat>("output_ic") = std::move(matY);
+  if (IO::HasParam("output_ic"))
+    IO::GetParam<mat>("output_ic") = std::move(matY);
 
-  if (CLI::HasParam("output_unmixing"))
-    CLI::GetParam<mat>("output_unmixing") = std::move(matW);
+  if (IO::HasParam("output_unmixing"))
+    IO::GetParam<mat>("output_unmixing") = std::move(matW);
 
-  if (CLI::HasParam("objective"))
+  if (IO::HasParam("objective"))
   {
     // Compute and print objective.
     mat matYT = trans(matY);
     double valEst = 0;
-    for (size_t i = 0; i < matYT.n_cols; i++)
+    for (size_t i = 0; i < matYT.n_cols; ++i)
     {
       vec y = vec(matYT.col(i));
       valEst += rad.Vasicek(y);
