@@ -19,13 +19,18 @@ using namespace mlpack::tree;
 using namespace mlpack::util;
 using namespace std;
 
-PROGRAM_INFO("Random forests",
-    // Short description.
+// Program Name.
+BINDING_NAME("Random forests");
+
+// Short description.
+BINDING_SHORT_DESC(
     "An implementation of the standard random forest algorithm by Leo Breiman "
     "for classification.  Given labeled data, a random forest can be trained "
     "and saved for future use; or, a pre-trained random forest can be used for "
-    "classification.",
-    // Long description.
+    "classification.");
+
+// Long description.
+BINDING_LONG_DESC(
     "This program is an implementation of the standard random forest "
     "classification algorithm by Leo Breiman.  A random forest can be "
     "trained and saved for later use, or a random forest may be loaded "
@@ -64,8 +69,10 @@ PROGRAM_INFO("Random forests",
     PRINT_PARAM_STRING("test_labels") + " parameter.  Predictions for each "
     "test point may be saved via the " + PRINT_PARAM_STRING("predictions") +
     "output parameter.  Class probabilities for each prediction may be saved "
-    "with the " + PRINT_PARAM_STRING("probabilities") + " output parameter."
-    "\n\n"
+    "with the " + PRINT_PARAM_STRING("probabilities") + " output parameter.");
+
+// Example.
+BINDING_EXAMPLE(
     "For example, to train a random forest with a minimum leaf size of 20 "
     "using 10 trees on the dataset contained in " + PRINT_DATASET("data") +
     "with labels " + PRINT_DATASET("labels") + ", saving the output random "
@@ -83,16 +90,18 @@ PROGRAM_INFO("Random forests",
     "could call "
     "\n\n" +
     PRINT_CALL("random_forest", "input_model", "rf_model", "test", "test_set",
-        "test_labels", "test_labels", "predictions", "predictions"),
-    SEE_ALSO("@decision_tree", "#decision_tree"),
-    SEE_ALSO("@hoeffding_tree", "#hoeffding_tree"),
-    SEE_ALSO("@softmax_regression", "#softmax_regression"),
-    SEE_ALSO("Random forest on Wikipedia",
-        "https://en.wikipedia.org/wiki/Random_forest"),
-    SEE_ALSO("Random forests (pdf)",
-        "https://link.springer.com/content/pdf/10.1023/A:1010933404324.pdf"),
-    SEE_ALSO("mlpack::tree::RandomForest C++ class documentation",
-        "@doxygen/classmlpack_1_1tree_1_1RandomForest.html"));
+        "test_labels", "test_labels", "predictions", "predictions"));
+
+// See also...
+BINDING_SEE_ALSO("@decision_tree", "#decision_tree");
+BINDING_SEE_ALSO("@hoeffding_tree", "#hoeffding_tree");
+BINDING_SEE_ALSO("@softmax_regression", "#softmax_regression");
+BINDING_SEE_ALSO("Random forest on Wikipedia",
+        "https://en.wikipedia.org/wiki/Random_forest");
+BINDING_SEE_ALSO("Random forests (pdf)",
+        "https://link.springer.com/content/pdf/10.1023/A:1010933404324.pdf");
+BINDING_SEE_ALSO("mlpack::tree::RandomForest C++ class documentation",
+        "@doxygen/classmlpack_1_1tree_1_1RandomForest.html");
 
 PARAM_MATRIX_IN("training", "Training dataset.", "t");
 PARAM_UROW_IN("labels", "Labels for training dataset.", "l");
@@ -152,8 +161,8 @@ PARAM_MODEL_OUT(RandomForestModel, "output_model", "Model to save trained "
 static void mlpackMain()
 {
   // Initialize random seed if needed.
-  if (CLI::GetParam<int>("seed") != 0)
-    math::RandomSeed((size_t) CLI::GetParam<int>("seed"));
+  if (IO::GetParam<int>("seed") != 0)
+    math::RandomSeed((size_t) IO::GetParam<int>("seed"));
   else
     math::RandomSeed((size_t) std::time(NULL));
 
@@ -166,7 +175,7 @@ static void mlpackMain()
   RequireAtLeastOnePassed({ "test", "output_model", "print_training_accuracy" },
       false, "the trained forest model will not be used or saved");
 
-  if (CLI::HasParam("training"))
+  if (IO::HasParam("training"))
   {
     RequireAtLeastOnePassed({ "labels" }, true, "must pass labels when training"
         " set given");
@@ -192,29 +201,29 @@ static void mlpackMain()
   ReportIgnoredParam({{ "training", false }}, "minimum_leaf_size");
 
   RandomForestModel* rfModel;
-  if (CLI::HasParam("training"))
+  if (IO::HasParam("training"))
   {
     Timer::Start("rf_training");
     rfModel = new RandomForestModel();
 
     // Train the model on the given input data.
-    arma::mat data = std::move(CLI::GetParam<arma::mat>("training"));
+    arma::mat data = std::move(IO::GetParam<arma::mat>("training"));
     arma::Row<size_t> labels =
-        std::move(CLI::GetParam<arma::Row<size_t>>("labels"));
+        std::move(IO::GetParam<arma::Row<size_t>>("labels"));
 
     // Make sure the subspace dimensionality is valid.
     RequireParamValue<int>("subspace_dim",
         [data](int x) { return (size_t) x <= data.n_rows; }, true, "subspace "
         "dimensionality must not be greater than data dimensionality");
 
-    const size_t numTrees = (size_t) CLI::GetParam<int>("num_trees");
+    const size_t numTrees = (size_t) IO::GetParam<int>("num_trees");
     const size_t minimumLeafSize =
-        (size_t) CLI::GetParam<int>("minimum_leaf_size");
-    const size_t maxDepth = (size_t) CLI::GetParam<int>("maximum_depth");
-    const double minimumGainSplit = CLI::GetParam<double>("minimum_gain_split");
-    const size_t randomDims = (CLI::GetParam<int>("subspace_dim") == 0) ?
+        (size_t) IO::GetParam<int>("minimum_leaf_size");
+    const size_t maxDepth = (size_t) IO::GetParam<int>("maximum_depth");
+    const double minimumGainSplit = IO::GetParam<double>("minimum_gain_split");
+    const size_t randomDims = (IO::GetParam<int>("subspace_dim") == 0) ?
         (size_t) std::sqrt(data.n_rows) :
-        (size_t) CLI::GetParam<int>("subspace_dim");
+        (size_t) IO::GetParam<int>("subspace_dim");
     MultipleRandomDimensionSelect mrds(randomDims);
 
     Log::Info << "Training random forest with " << numTrees << " trees..."
@@ -228,7 +237,7 @@ static void mlpackMain()
     Timer::Stop("rf_training");
 
     // Did we want training accuracy?
-    if (CLI::HasParam("print_training_accuracy"))
+    if (IO::HasParam("print_training_accuracy"))
     {
       Timer::Start("rf_prediction");
       arma::Row<size_t> predictions;
@@ -245,12 +254,12 @@ static void mlpackMain()
   else
   {
     // Then we must be loading a model.
-    rfModel = CLI::GetParam<RandomForestModel*>("input_model");
+    rfModel = IO::GetParam<RandomForestModel*>("input_model");
   }
 
-  if (CLI::HasParam("test"))
+  if (IO::HasParam("test"))
   {
-    arma::mat testData = std::move(CLI::GetParam<arma::mat>("test"));
+    arma::mat testData = std::move(IO::GetParam<arma::mat>("test"));
     Timer::Start("rf_prediction");
 
     // Get predictions and probabilities.
@@ -259,10 +268,10 @@ static void mlpackMain()
     rfModel->rf.Classify(testData, predictions, probabilities);
 
     // Did we want to calculate test accuracy?
-    if (CLI::HasParam("test_labels"))
+    if (IO::HasParam("test_labels"))
     {
       arma::Row<size_t> testLabels =
-          std::move(CLI::GetParam<arma::Row<size_t>>("test_labels"));
+          std::move(IO::GetParam<arma::Row<size_t>>("test_labels"));
 
       const size_t correct = arma::accu(predictions == testLabels);
 
@@ -273,10 +282,10 @@ static void mlpackMain()
     }
 
     // Save the outputs.
-    CLI::GetParam<arma::mat>("probabilities") = std::move(probabilities);
-    CLI::GetParam<arma::Row<size_t>>("predictions") = std::move(predictions);
+    IO::GetParam<arma::mat>("probabilities") = std::move(probabilities);
+    IO::GetParam<arma::Row<size_t>>("predictions") = std::move(predictions);
   }
 
   // Save the output model.
-  CLI::GetParam<RandomForestModel*>("output_model") = rfModel;
+  IO::GetParam<RandomForestModel*>("output_model") = rfModel;
 }
