@@ -33,7 +33,7 @@ class Pendulum
  public:
   /**
    * Implementation of state of Pendulum. Each state is a
-   * (theta, angular velocity) vector.
+   * (cos(theta), sin(theta), angular velocity) vector.
    */
   class State
   {
@@ -41,38 +41,49 @@ class Pendulum
     /**
      * Construct a state instance.
      */
-    State() : data(dimension, arma::fill::zeros)
+    State() : theta(0), data(dimension, arma::fill::zeros)
     { /* Nothing to do here. */ }
 
     /**
      * Construct a state based on the given data.
      *
-     * @param data Data for the theta and angular velocity.
+     * @param data Data for the cos(theta), sin(theta) and
+     *             angular velocity.
      */
-    State(const arma::colvec& data): data(data)
+    State(const arma::colvec& data): theta(0), data(data)
     { /* Nothing to do here. */ }
 
     //! Modify the internal representation of the state.
     arma::colvec& Data() { return data; }
 
     //! Get the theta.
-    double Theta() const { return data[0]; }
+    double Theta() const { return theta; }
     //! Modify the value of theta.
-    double& Theta() { return data[0]; }
+    double& Theta() { return theta; }
 
     //! Get the angular velocity.
-    double AngularVelocity() const { return data[1]; }
+    double AngularVelocity() const { return data[2]; }
     //! Modify the value of angular velocity.
-    double& AngularVelocity() { return data[1]; }
+    double& AngularVelocity() { return data[2]; }
 
     //! Encode the state to a column vector.
-    const arma::colvec& Encode() const { return data; }
+    const arma::colvec& Encode() { return data; }
+
+    //! Updates the theta transformations in data.
+    void SetState()
+    {
+      data[0] = std::sin(theta);
+      data[1] = std::cos(theta);
+    }
 
     //! Dimension of the encoded state.
-    static constexpr size_t dimension = 2;
+    static constexpr size_t dimension = 3;
 
    private:
-    //! Locally-stored (theta, angular velocity) vector
+    //! Locally-stored theta.
+    double theta;
+
+    //! Locally-stored (sin(theta), cos(theta), angular velocity) vector.
     arma::colvec data;
   };
 
@@ -81,33 +92,39 @@ class Pendulum
    * In Pendulum, the action represents the torque to be applied.
    * This value is bounded in range -2.0 to 2.0 by default.
    */
-  struct Action
+  class Action
   {
-    double action[1];
-    // Storing degree of freedom
-    const int size = 1;
+   public:
+    /**
+     * Construct an action instance.
+     */
+    Action() : action(1)
+    { /* Nothing to do here */ }
+    std::vector<double> action;
+    // Storing degree of freedom.
+    static const size_t size = 1;
   };
 
   /**
    * Construct a Pendulum instance using the given values.
    *
+   * @param maxSteps The number of steps after which the episode
+   *    terminates. If the value is 0, there is no limit (Default: 200 steps). 
    * @param maxAngularVelocity Maximum angular velocity.
    * @param maxTorque Maximum torque.
    * @param dt The differential value.
    * @param doneReward The reward recieved by the agent on success.
-   * @param maxSteps The number of steps after which the episode
-   *    terminates. If the value is 0, there is no limit (Default: 200 steps). 
    */
-  Pendulum(const double maxAngularVelocity = 8,
+  Pendulum(const size_t maxSteps = 200,
+           const double maxAngularVelocity = 8,
            const double maxTorque = 2.0,
            const double dt = 0.05,
-           const double doneReward = 0.0,
-           const size_t maxSteps = 200) :
+           const double doneReward = 0.0) :
+      maxSteps(maxSteps),
       maxAngularVelocity(maxAngularVelocity),
       maxTorque(maxTorque),
       dt(dt),
       doneReward(doneReward),
-      maxSteps(maxSteps),
       stepsPerformed(0)
   { /* Nothing to do here */ }
 
@@ -151,6 +168,8 @@ class Pendulum
     nextState.AngularVelocity() = math::ClampRange(newAngularVelocity,
         -maxAngularVelocity, maxAngularVelocity);
 
+    nextState.SetState();
+
     // Return the reward of taking the action in current state.
     // The reward is simply the negative of cost incurred for the action.
     return -costs;
@@ -181,6 +200,7 @@ class Pendulum
     state.Theta() = math::Random(-M_PI, M_PI);
     state.AngularVelocity() = math::Random(-1.0, 1.0);
     stepsPerformed = 0;
+    state.SetState();
     return state;
   }
 
@@ -201,10 +221,10 @@ class Pendulum
   /**
    * This function checks if the pendulum has reaches a terminal state
    * 
-   * @param state desired state.
+   * @param * (state) desired state.
    * @return true if state is a terminal state, otherwise false.
    */
-  bool IsTerminal(const State& state) const
+  bool IsTerminal(const State& /* state */) const
   {
     if (maxSteps != 0 && stepsPerformed >= maxSteps)
     {
@@ -224,6 +244,9 @@ class Pendulum
   size_t& MaxSteps() { return maxSteps; }
 
  private:
+  //! Locally-stored maximum number of steps.
+  size_t maxSteps;
+
   //! Locally-stored maximum legal angular velocity.
   double maxAngularVelocity;
 
@@ -236,9 +259,6 @@ class Pendulum
   //! Locally-stored done reward.
   double doneReward;
 
-  //! Locally-stored maximum number of steps.
-  size_t maxSteps;
-
   //! Locally-stored number of steps performed.
   size_t stepsPerformed;
 };
