@@ -18,32 +18,31 @@
 
 #include <ensmallen.hpp>
 
-#include <boost/test/unit_test.hpp>
-#include "test_tools.hpp"
+#include "serialization_catch.hpp"
+#include "catch.hpp"
+#include "test_catch_tools.hpp"
 
 using namespace mlpack;
 using namespace mlpack::ann;
 
-BOOST_AUTO_TEST_SUITE(ConvolutionalNetworkTest);
-
 /**
  * Train the vanilla network on a larger dataset.
  */
-BOOST_AUTO_TEST_CASE(VanillaNetworkTest)
+TEST_CASE("VanillaNetworkTest", "[ConvolutionalNetworkTest]")
 {
   arma::mat X;
   X.load("mnist_first250_training_4s_and_9s.arm");
 
   // Normalize each point since these are images.
   arma::uword nPoints = X.n_cols;
-  for (arma::uword i = 0; i < nPoints; i++)
+  for (arma::uword i = 0; i < nPoints; ++i)
   {
     X.col(i) /= norm(X.col(i), 2);
   }
 
   // Build the target matrix.
   arma::mat Y = arma::zeros<arma::mat>(1, nPoints);
-  for (size_t i = 0; i < nPoints; i++)
+  for (size_t i = 0; i < nPoints; ++i)
   {
     if (i < nPoints / 2)
     {
@@ -102,7 +101,7 @@ BOOST_AUTO_TEST_CASE(VanillaNetworkTest)
     double objVal = model.Train(X, Y, opt);
 
     // Test that objective value returned by FFN::Train() is finite.
-    BOOST_REQUIRE_EQUAL(std::isfinite(objVal), true);
+    REQUIRE(std::isfinite(objVal) == true);
 
     arma::mat predictionTemp;
     model.Predict(X, predictionTemp);
@@ -123,7 +122,5 @@ BOOST_AUTO_TEST_CASE(VanillaNetworkTest)
     }
   }
 
-  BOOST_REQUIRE_EQUAL(success, true);
+  REQUIRE(success == true);
 }
-
-BOOST_AUTO_TEST_SUITE_END();
