@@ -13,17 +13,15 @@
 #include <mlpack/methods/dbscan/dbscan.hpp>
 #include <mlpack/methods/dbscan/random_point_selection.hpp>
 
-#include <boost/test/unit_test.hpp>
-#include "test_tools.hpp"
+#include "test_catch_tools.hpp"
+#include "catch.hpp"
 
 using namespace mlpack;
 using namespace mlpack::range;
 using namespace mlpack::dbscan;
 using namespace mlpack::distribution;
 
-BOOST_AUTO_TEST_SUITE(DBSCANTest);
-
-BOOST_AUTO_TEST_CASE(OneClusterTest)
+TEST_CASE("OneClusterTest", "[DBSCANTest]")
 {
   // Make sure that if we have points in the unit box, and if we set epsilon
   // large enough, all points end up as in one cluster.
@@ -34,16 +32,16 @@ BOOST_AUTO_TEST_CASE(OneClusterTest)
   arma::Row<size_t> assignments;
   const size_t clusters = d.Cluster(points, assignments);
 
-  BOOST_REQUIRE_EQUAL(clusters, 1);
-  BOOST_REQUIRE_EQUAL(assignments.n_elem, points.n_cols);
+  REQUIRE(clusters == 1);
+  REQUIRE(assignments.n_elem == points.n_cols);
   for (size_t i = 0; i < assignments.n_elem; ++i)
-    BOOST_REQUIRE_EQUAL(assignments[i], 0);
+    REQUIRE(assignments[i] == 0);
 }
 
 /**
  * When epsilon is small enough, every point returned should be noise.
  */
-BOOST_AUTO_TEST_CASE(TinyEpsilonTest)
+TEST_CASE("TinyEpsilonTest", "[DBSCANTest]")
 {
   arma::mat points(10, 200, arma::fill::randu);
 
@@ -52,16 +50,16 @@ BOOST_AUTO_TEST_CASE(TinyEpsilonTest)
   arma::Row<size_t> assignments;
   const size_t clusters = d.Cluster(points, assignments);
 
-  BOOST_REQUIRE_EQUAL(clusters, 0);
-  BOOST_REQUIRE_EQUAL(assignments.n_elem, points.n_cols);
+  REQUIRE(clusters == 0);
+  REQUIRE(assignments.n_elem == points.n_cols);
   for (size_t i = 0; i < assignments.n_elem; ++i)
-    BOOST_REQUIRE_EQUAL(assignments[i], SIZE_MAX);
+    REQUIRE(assignments[i] == SIZE_MAX);
 }
 
 /**
  * Check that outliers are properly labeled as noise.
  */
-BOOST_AUTO_TEST_CASE(OutlierTest)
+TEST_CASE("OutlierTest", "[DBSCANTest]")
 {
   arma::mat points(2, 200, arma::fill::randu);
 
@@ -75,17 +73,17 @@ BOOST_AUTO_TEST_CASE(OutlierTest)
   arma::Row<size_t> assignments;
   const size_t clusters = d.Cluster(points, assignments);
 
-  BOOST_REQUIRE_GT(clusters, 0);
-  BOOST_REQUIRE_EQUAL(assignments.n_elem, points.n_cols);
-  BOOST_REQUIRE_EQUAL(assignments[15], SIZE_MAX);
-  BOOST_REQUIRE_EQUAL(assignments[45], SIZE_MAX);
-  BOOST_REQUIRE_EQUAL(assignments[101], SIZE_MAX);
+  REQUIRE(clusters > 0);
+  REQUIRE(assignments.n_elem == points.n_cols);
+  REQUIRE(assignments[15] == SIZE_MAX);
+  REQUIRE(assignments[45] == SIZE_MAX);
+  REQUIRE(assignments[101] == SIZE_MAX);
 }
 
 /**
  * Check that the Gaussian clusters are correctly found.
  */
-BOOST_AUTO_TEST_CASE(GaussiansTest)
+TEST_CASE("GaussiansTest", "[DBSCANTest]")
 {
   arma::mat points(3, 300);
 
@@ -105,7 +103,7 @@ BOOST_AUTO_TEST_CASE(GaussiansTest)
   arma::Row<size_t> assignments;
   arma::mat centroids;
   const size_t clusters = d.Cluster(points, assignments, centroids);
-  BOOST_REQUIRE_EQUAL(clusters, 3);
+  REQUIRE(clusters == 3);
 
   // Our centroids should be close to one of our Gaussians.
   arma::Row<size_t> matches(3);
@@ -120,35 +118,35 @@ BOOST_AUTO_TEST_CASE(GaussiansTest)
       matches(2) = j;
   }
 
-  BOOST_REQUIRE_NE(matches(0), matches(1));
-  BOOST_REQUIRE_NE(matches(1), matches(2));
-  BOOST_REQUIRE_NE(matches(2), matches(0));
+  REQUIRE(matches(0) != matches(1));
+  REQUIRE(matches(1) != matches(2));
+  REQUIRE(matches(2) != matches(0));
 
-  BOOST_REQUIRE_NE(matches(0), 3);
-  BOOST_REQUIRE_NE(matches(1), 3);
-  BOOST_REQUIRE_NE(matches(2), 3);
+  REQUIRE(matches(0) != 3);
+  REQUIRE(matches(1) != 3);
+  REQUIRE(matches(2) != 3);
 
   for (size_t i = 0; i < 100; ++i)
   {
     // Each point should either be noise or in cluster matches(0).
-    BOOST_REQUIRE_NE(assignments(i), matches(1));
-    BOOST_REQUIRE_NE(assignments(i), matches(2));
+    REQUIRE(assignments(i) != matches(1));
+    REQUIRE(assignments(i) != matches(2));
   }
 
   for (size_t i = 100; i < 200; ++i)
   {
-    BOOST_REQUIRE_NE(assignments(i), matches(0));
-    BOOST_REQUIRE_NE(assignments(i), matches(2));
+    REQUIRE(assignments(i) != matches(0));
+    REQUIRE(assignments(i) != matches(2));
   }
 
   for (size_t i = 200; i < 300; ++i)
   {
-    BOOST_REQUIRE_NE(assignments(i), matches(0));
-    BOOST_REQUIRE_NE(assignments(i), matches(1));
+    REQUIRE(assignments(i) != matches(0));
+    REQUIRE(assignments(i) != matches(1));
   }
 }
 
-BOOST_AUTO_TEST_CASE(OneClusterSingleModeTest)
+TEST_CASE("OneClusterSingleModeTest", "[DBSCANTest]")
 {
   // Make sure that if we have points in the unit box, and if we set epsilon
   // large enough, all points end up as in one cluster.
@@ -159,16 +157,16 @@ BOOST_AUTO_TEST_CASE(OneClusterSingleModeTest)
   arma::Row<size_t> assignments;
   const size_t clusters = d.Cluster(points, assignments);
 
-  BOOST_REQUIRE_EQUAL(clusters, 1);
-  BOOST_REQUIRE_EQUAL(assignments.n_elem, points.n_cols);
+  REQUIRE(clusters == 1);
+  REQUIRE(assignments.n_elem == points.n_cols);
   for (size_t i = 0; i < assignments.n_elem; ++i)
-    BOOST_REQUIRE_EQUAL(assignments[i], 0);
+    REQUIRE(assignments[i] == 0);
 }
 
 /**
  * When epsilon is small enough, every point returned should be noise.
  */
-BOOST_AUTO_TEST_CASE(TinyEpsilonSingleModeTest)
+TEST_CASE("TinyEpsilonSingleModeTest", "[DBSCANTest]")
 {
   arma::mat points(10, 200, arma::fill::randu);
 
@@ -177,16 +175,16 @@ BOOST_AUTO_TEST_CASE(TinyEpsilonSingleModeTest)
   arma::Row<size_t> assignments;
   const size_t clusters = d.Cluster(points, assignments);
 
-  BOOST_REQUIRE_EQUAL(clusters, 0);
-  BOOST_REQUIRE_EQUAL(assignments.n_elem, points.n_cols);
+  REQUIRE(clusters == 0);
+  REQUIRE(assignments.n_elem == points.n_cols);
   for (size_t i = 0; i < assignments.n_elem; ++i)
-    BOOST_REQUIRE_EQUAL(assignments[i], SIZE_MAX);
+    REQUIRE(assignments[i] == SIZE_MAX);
 }
 
 /**
  * Check that outliers are properly labeled as noise.
  */
-BOOST_AUTO_TEST_CASE(OutlierSingleModeTest)
+TEST_CASE("OutlierSingleModeTest", "[DBSCANTest]")
 {
   arma::mat points(2, 200, arma::fill::randu);
 
@@ -200,17 +198,17 @@ BOOST_AUTO_TEST_CASE(OutlierSingleModeTest)
   arma::Row<size_t> assignments;
   const size_t clusters = d.Cluster(points, assignments);
 
-  BOOST_REQUIRE_GT(clusters, 0);
-  BOOST_REQUIRE_EQUAL(assignments.n_elem, points.n_cols);
-  BOOST_REQUIRE_EQUAL(assignments[15], SIZE_MAX);
-  BOOST_REQUIRE_EQUAL(assignments[45], SIZE_MAX);
-  BOOST_REQUIRE_EQUAL(assignments[101], SIZE_MAX);
+  REQUIRE(clusters > 0);
+  REQUIRE(assignments.n_elem == points.n_cols);
+  REQUIRE(assignments[15] == SIZE_MAX);
+  REQUIRE(assignments[45] == SIZE_MAX);
+  REQUIRE(assignments[101] == SIZE_MAX);
 }
 
 /**
  * Check that the Gaussian clusters are correctly found.
  */
-BOOST_AUTO_TEST_CASE(GaussiansSingleModeTest)
+TEST_CASE("GaussiansSingleModeTest", "[DBSCANTest]")
 {
   arma::mat points(3, 300);
 
@@ -230,7 +228,7 @@ BOOST_AUTO_TEST_CASE(GaussiansSingleModeTest)
   arma::Row<size_t> assignments;
   arma::mat centroids;
   const size_t clusters = d.Cluster(points, assignments, centroids);
-  BOOST_REQUIRE_EQUAL(clusters, 3);
+  REQUIRE(clusters == 3);
 
   // Our centroids should be close to one of our Gaussians.
   arma::Row<size_t> matches(3);
@@ -245,38 +243,38 @@ BOOST_AUTO_TEST_CASE(GaussiansSingleModeTest)
       matches(2) = j;
   }
 
-  BOOST_REQUIRE_NE(matches(0), matches(1));
-  BOOST_REQUIRE_NE(matches(1), matches(2));
-  BOOST_REQUIRE_NE(matches(2), matches(0));
+  REQUIRE(matches(0) != matches(1));
+  REQUIRE(matches(1) != matches(2));
+  REQUIRE(matches(2) != matches(0));
 
-  BOOST_REQUIRE_NE(matches(0), 3);
-  BOOST_REQUIRE_NE(matches(1), 3);
-  BOOST_REQUIRE_NE(matches(2), 3);
+  REQUIRE(matches(0) != 3);
+  REQUIRE(matches(1) != 3);
+  REQUIRE(matches(2) != 3);
 
   for (size_t i = 0; i < 100; ++i)
   {
     // Each point should either be noise or in cluster matches(0).
-    BOOST_REQUIRE_NE(assignments(i), matches(1));
-    BOOST_REQUIRE_NE(assignments(i), matches(2));
+    REQUIRE(assignments(i) != matches(1));
+    REQUIRE(assignments(i) != matches(2));
   }
 
   for (size_t i = 100; i < 200; ++i)
   {
-    BOOST_REQUIRE_NE(assignments(i), matches(0));
-    BOOST_REQUIRE_NE(assignments(i), matches(2));
+    REQUIRE(assignments(i) != matches(0));
+    REQUIRE(assignments(i) != matches(2));
   }
 
   for (size_t i = 200; i < 300; ++i)
   {
-    BOOST_REQUIRE_NE(assignments(i), matches(0));
-    BOOST_REQUIRE_NE(assignments(i), matches(1));
+    REQUIRE(assignments(i) != matches(0));
+    REQUIRE(assignments(i) != matches(1));
   }
 }
 
 /**
  * Check that OrderedPointSelection works correctly.
  */
-BOOST_AUTO_TEST_CASE(OrderedPointSelectionTest)
+TEST_CASE("OrderedPointSelectionTest", "[DBSCANTest]")
 {
   arma::mat points(10, 200, arma::fill::randu);
 
@@ -285,16 +283,16 @@ BOOST_AUTO_TEST_CASE(OrderedPointSelectionTest)
   arma::Row<size_t> assignments;
   const size_t clusters = d.Cluster(points, assignments);
 
-  BOOST_REQUIRE_EQUAL(clusters, 1);
+  REQUIRE(clusters == 1);
 
   // The number of assignments returned should be the same as points.
-  BOOST_REQUIRE_EQUAL(assignments.n_elem, points.n_cols);
+  REQUIRE(assignments.n_elem == points.n_cols);
 }
 
 /**
  * Check that RandomPointSelection works correctly.
  */
-BOOST_AUTO_TEST_CASE(RandomPointSelectionTest)
+TEST_CASE("RandomPointSelectionTest", "[DBSCANTest]")
 {
   arma::mat points(10, 200, arma::fill::randu);
 
@@ -303,10 +301,8 @@ BOOST_AUTO_TEST_CASE(RandomPointSelectionTest)
   arma::Row<size_t> assignments;
   const size_t clusters = d.Cluster(points, assignments);
 
-  BOOST_REQUIRE_EQUAL(clusters, 1);
+  REQUIRE(clusters == 1);
 
   // The number of assignments returned should be the same as points.
-  BOOST_REQUIRE_EQUAL(assignments.n_elem, points.n_cols);
+  REQUIRE(assignments.n_elem == points.n_cols);
 }
-
-BOOST_AUTO_TEST_SUITE_END();
