@@ -14,20 +14,18 @@
 #include <mlpack/core.hpp>
 #include <mlpack/core/math/lin_alg.hpp>
 
-#include <boost/test/unit_test.hpp>
-#include "test_tools.hpp"
+#include "catch.hpp"
+#include "test_catch_tools.hpp"
 
 using namespace arma;
 using namespace mlpack;
 using namespace mlpack::math;
 
-BOOST_AUTO_TEST_SUITE(LinAlgTest);
-
 /**
  * Test for linalg__private::Center().  There are no edge cases here, so we'll
  * just try it once for now.
  */
-BOOST_AUTO_TEST_CASE(TestCenterA)
+TEST_CASE("TestCenterA", "[LinAlgTest]")
 {
   mat tmp(5, 5);
   // [[0  0  0  0  0]
@@ -51,11 +49,16 @@ BOOST_AUTO_TEST_CASE(TestCenterA)
   //  [-6 -3  0  3  6 ]
   //  [-8 -4  0  4  8]]
   for (int row = 0; row < 5; row++)
+  {
     for (int col = 0; col < 5; col++)
-      BOOST_REQUIRE_CLOSE(tmp_out(row, col), (double) (col - 2) * row, 1e-5);
+    {
+      REQUIRE(tmp_out(row, col) ==
+          Approx((double) (col - 2) * row).epsilon(1e-7));
+    }
+  }
 }
 
-BOOST_AUTO_TEST_CASE(TestCenterB)
+TEST_CASE("TestCenterB", "[LinAlgTest]")
 {
   mat tmp(5, 6);
   for (int row = 0; row < 5; row++)
@@ -74,11 +77,16 @@ BOOST_AUTO_TEST_CASE(TestCenterB)
   //  [-7.5 -4.5 -1.5 1.5 1.5 4.5]
   //  [-10  -6   -2   2   6   10 ]]
   for (int row = 0; row < 5; row++)
+  {
     for (int col = 0; col < 6; col++)
-      BOOST_REQUIRE_CLOSE(tmp_out(row, col), (double) (col - 2.5) * row, 1e-5);
+    {
+      REQUIRE(tmp_out(row, col) ==
+          Approx((double) (col - 2.5) * row).epsilon(1e-7));
+    }
+  }
 }
 
-BOOST_AUTO_TEST_CASE(TestOrthogonalize)
+TEST_CASE("TestOrthogonalize", "[LinAlgTest]")
 {
   // Generate a random matrix; then, orthogonalize it and test if it's
   // orthogonal.
@@ -96,18 +104,18 @@ BOOST_AUTO_TEST_CASE(TestOrthogonalize)
       if (row == col)
       {
         if (std::abs(test(row, col)) > 1e-10)
-          BOOST_REQUIRE_CLOSE(test(row, col), ival, 1e-10);
+          REQUIRE(test(row, col) == Approx(ival).epsilon(1e-11));
       }
       else
       {
-        BOOST_REQUIRE_SMALL(test(row, col), 1e-10);
+        REQUIRE(test(row, col) == Approx(0.0).margin(1e-10));
       }
     }
   }
 }
 
 // Test RemoveRows().
-BOOST_AUTO_TEST_CASE(TestRemoveRows)
+TEST_CASE("TestRemoveRows", "[LinAlgTest]")
 {
   // Run this test several times.
   for (size_t run = 0; run < 10; ++run)
@@ -150,7 +158,7 @@ BOOST_AUTO_TEST_CASE(TestRemoveRows)
       else
       {
         // Compare.
-        BOOST_REQUIRE_EQUAL(accu(input.row(row) == output.row(outputRow)), 200);
+        REQUIRE(accu(input.row(row) == output.row(outputRow)) == 200);
 
         // Increment output row counter.
         ++outputRow;
@@ -159,7 +167,7 @@ BOOST_AUTO_TEST_CASE(TestRemoveRows)
   }
 }
 
-BOOST_AUTO_TEST_CASE(TestSvecSmat)
+TEST_CASE("TestSvecSmat", "[LinAlgTest]")
 {
   arma::mat X(3, 3);
   X(0, 0) = 0; X(0, 1) = 1, X(0, 2) = 2;
@@ -168,23 +176,24 @@ BOOST_AUTO_TEST_CASE(TestSvecSmat)
 
   arma::vec sx;
   Svec(X, sx);
-  BOOST_REQUIRE_CLOSE(sx(0), 0, 1e-7);
-  BOOST_REQUIRE_CLOSE(sx(1), M_SQRT2 * 1., 1e-7);
-  BOOST_REQUIRE_CLOSE(sx(2), M_SQRT2 * 2., 1e-7);
-  BOOST_REQUIRE_CLOSE(sx(3), 3., 1e-7);
-  BOOST_REQUIRE_CLOSE(sx(4), M_SQRT2 * 4., 1e-7);
-  BOOST_REQUIRE_CLOSE(sx(5), 5., 1e-7);
+  REQUIRE(sx(0) == Approx(0).epsilon(1e-9));
+  REQUIRE(sx(1) == Approx(M_SQRT2 * 1.).epsilon(1e-9));
+  REQUIRE(sx(2) == Approx(M_SQRT2 * 2.).epsilon(1e-9));
+  REQUIRE(sx(3) == Approx(3.).epsilon(1e-9));
+  REQUIRE(sx(4) == Approx(M_SQRT2 * 4.).epsilon(1e-9));
+  REQUIRE(sx(5) == Approx(5.).epsilon(1e-9));
 
   arma::mat Xtest;
   Smat(sx, Xtest);
-  BOOST_REQUIRE_EQUAL(Xtest.n_rows, 3);
-  BOOST_REQUIRE_EQUAL(Xtest.n_cols, 3);
-  for (size_t i = 0; i < 3; i++)
-    for (size_t j = 0; j < 3; j++)
-      BOOST_REQUIRE_CLOSE(X(i, j), Xtest(i, j), 1e-7);
+  REQUIRE(Xtest.n_rows == 3);
+  REQUIRE(Xtest.n_cols == 3);
+  for (size_t i = 0; i < 3; ++i)
+    for (size_t j = 0; j < 3; ++j)
+      REQUIRE(X(i, j) == Approx(Xtest(i, j)).epsilon(1e-9));
+
 }
 
-BOOST_AUTO_TEST_CASE(TestSparseSvec)
+TEST_CASE("TestSparseSvec", "[LinAlgTest]")
 {
   arma::sp_mat X;
   X.zeros(3, 3);
@@ -200,15 +209,15 @@ BOOST_AUTO_TEST_CASE(TestSparseSvec)
   const double v4 = sx(4);
   const double v5 = sx(5);
 
-  BOOST_REQUIRE_CLOSE(v0, 0, 1e-7);
-  BOOST_REQUIRE_CLOSE(v1, M_SQRT2 * 1., 1e-7);
-  BOOST_REQUIRE_CLOSE(v2, 0, 1e-7);
-  BOOST_REQUIRE_CLOSE(v3, 0, 1e-7);
-  BOOST_REQUIRE_CLOSE(v4, 0, 1e-7);
-  BOOST_REQUIRE_CLOSE(v5, 0, 1e-7);
+  REQUIRE(v0 == Approx(0).epsilon(1e-9));
+  REQUIRE(v1 == Approx(M_SQRT2 * 1.).epsilon(1e-9));
+  REQUIRE(v2 == Approx(0).epsilon(1e-9));
+  REQUIRE(v3 == Approx(0).epsilon(1e-9));
+  REQUIRE(v4 == Approx(0).epsilon(1e-9));
+  REQUIRE(v5 == Approx(0).epsilon(1e-9));
 }
 
-BOOST_AUTO_TEST_CASE(TestSymKronIdSimple)
+TEST_CASE("TestSymKronIdSimple", "[LinAlgTest]")
 {
   arma::mat A(3, 3);
   A(0, 0) = 1; A(0, 1) = 2, A(0, 2) = 3;
@@ -226,12 +235,12 @@ BOOST_AUTO_TEST_CASE(TestSymKronIdSimple)
   arma::vec rhs;
   Svec(Rhs, rhs);
 
-  BOOST_REQUIRE_EQUAL(lhs.n_elem, rhs.n_elem);
-  for (size_t j = 0; j < lhs.n_elem; j++)
-    BOOST_REQUIRE_CLOSE(lhs(j), rhs(j), 1e-5);
+  REQUIRE(lhs.n_elem == rhs.n_elem);
+  for (size_t j = 0; j < lhs.n_elem; ++j)
+    REQUIRE(lhs(j) == Approx(rhs(j)).epsilon(1e-7));
 }
 
-BOOST_AUTO_TEST_CASE(TestSymKronId)
+TEST_CASE("TestSymKronId", "[LinAlgTest]")
 {
   const size_t n = 10;
   arma::mat A = arma::randu<arma::mat>(n, n);
@@ -240,7 +249,7 @@ BOOST_AUTO_TEST_CASE(TestSymKronId)
   arma::mat Op;
   SymKronId(A, Op);
 
-  for (size_t i = 0; i < 5; i++)
+  for (size_t i = 0; i < 5; ++i)
   {
     arma::mat X = arma::randu<arma::mat>(n, n);
     X += X.t();
@@ -252,10 +261,8 @@ BOOST_AUTO_TEST_CASE(TestSymKronId)
     arma::vec rhs;
     Svec(Rhs, rhs);
 
-    BOOST_REQUIRE_EQUAL(lhs.n_elem, rhs.n_elem);
-    for (size_t j = 0; j < lhs.n_elem; j++)
-      BOOST_REQUIRE_CLOSE(lhs(j), rhs(j), 1e-5);
+    REQUIRE(lhs.n_elem == rhs.n_elem);
+    for (size_t j = 0; j < lhs.n_elem; ++j)
+      REQUIRE(lhs(j) == Approx(rhs(j)).epsilon(1e-7));
   }
 }
-
-BOOST_AUTO_TEST_SUITE_END();
