@@ -11,20 +11,18 @@
 #include <mlpack/core.hpp>
 #include <mlpack/methods/linear_regression/linear_regression.hpp>
 
-#include <boost/test/unit_test.hpp>
-#include "test_tools.hpp"
-#include "serialization.hpp"
+#include "serialization_catch.hpp"
+#include "test_catch_tools.hpp"
+#include "catch.hpp"
 
 using namespace mlpack;
 using namespace mlpack::regression;
 
-BOOST_AUTO_TEST_SUITE(LinearRegressionTest);
-
 /**
  * Creates two 10x3 random matrices and one 10x1 "results" matrix.
  * Finds B in y=BX with one matrix, then predicts against the other.
  */
-BOOST_AUTO_TEST_CASE(LinearRegressionTestCase)
+TEST_CASE("LinearRegressionTestCase", "[LinearRegressionTest]")
 {
   // Predictors and points are 10x3 matrices.
   arma::mat predictors(3, 10);
@@ -66,13 +64,13 @@ BOOST_AUTO_TEST_CASE(LinearRegressionTestCase)
   // Output result and verify we have less than 5% error from "correct" value
   // for each point.
   for (size_t i = 0; i < predictions.n_cols; ++i)
-    BOOST_REQUIRE_SMALL(predictions(i) - responses(i), .05);
+    REQUIRE(predictions(i) - responses(i) == Approx(0.0).margin(0.05));
 }
 
 /**
  * Check the functionality of ComputeError().
  */
-BOOST_AUTO_TEST_CASE(ComputeErrorTest)
+TEST_CASE("ComputeErrorTest", "[LinearRegressionTest]")
 {
   arma::mat predictors;
   predictors << 0 << 1 << 2 << 4 << 8 << 16 << arma::endr
@@ -83,14 +81,14 @@ BOOST_AUTO_TEST_CASE(ComputeErrorTest)
   // This dataset gives a cost of 1.189500337 (as calculated in Octave).
   LinearRegression lr(predictors, responses);
 
-  BOOST_REQUIRE_CLOSE(lr.ComputeError(predictors, responses), 1.189500337,
-      1e-3);
+  REQUIRE(lr.ComputeError(predictors, responses) ==
+      Approx(1.189500337).epsilon(1e-5));
 }
 
 /**
  * Ensure that the cost is 0 when a perfectly-fitting dataset is given.
  */
-BOOST_AUTO_TEST_CASE(ComputeErrorPerfectFitTest)
+TEST_CASE("ComputeErrorPerfectFitTest", "[LinearRegressionTest]")
 {
   // Linear regression should perfectly model this dataset.
   arma::mat predictors;
@@ -100,14 +98,14 @@ BOOST_AUTO_TEST_CASE(ComputeErrorPerfectFitTest)
 
   LinearRegression lr(predictors, responses);
 
-  BOOST_REQUIRE_SMALL(lr.ComputeError(predictors, responses), 1e-25);
+  REQUIRE(lr.ComputeError(predictors, responses) == Approx(0.0).margin(1e-25));
 }
 
 /**
  * Test ridge regression using an empty dataset, which is not invertible.  But
  * the ridge regression part should make it invertible.
  */
-BOOST_AUTO_TEST_CASE(RidgeRegressionTest)
+TEST_CASE("RidgeRegressionTest", "[LinearRegressionTest]")
 {
   // Create empty dataset.
   arma::mat data;
@@ -126,7 +124,7 @@ BOOST_AUTO_TEST_CASE(RidgeRegressionTest)
   lr.Predict(data, predictedResponses);
 
   for (size_t i = 0; i < 5000; ++i)
-    BOOST_REQUIRE_SMALL((double) predictedResponses[i], 1e-20);
+    REQUIRE((double) predictedResponses[i] == Approx(0.0).margin(1e-20));
 }
 
 /**
@@ -134,7 +132,7 @@ BOOST_AUTO_TEST_CASE(RidgeRegressionTest)
  * Finds B in y=BX with one matrix, then predicts against the other, but uses
  * ridge regression with an extremely small lambda value.
  */
-BOOST_AUTO_TEST_CASE(RidgeRegressionTestCase)
+TEST_CASE("RidgeRegressionTestCase", "[LinearRegressionTest]")
 {
   // Predictors and points are 10x3 matrices.
   arma::mat predictors(3, 10);
@@ -176,14 +174,14 @@ BOOST_AUTO_TEST_CASE(RidgeRegressionTestCase)
   // Output result and verify we have less than 5% error from "correct" value
   // for each point.
   for (size_t i = 0; i < predictions.n_cols; ++i)
-    BOOST_REQUIRE_SMALL(predictions(i) - responses(i), .05);
+    REQUIRE(predictions(i) - responses(i) == Approx(0.0).margin(0.05));
 }
 
 /**
  * Test that a LinearRegression model trained in the constructor and trained in
  * the Train() method give the same model.
  */
-BOOST_AUTO_TEST_CASE(LinearRegressionTrainTest)
+TEST_CASE("LinearRegressionTrainTest", "[LinearRegressionTest]")
 {
   // Random dataset.
   arma::mat dataset = arma::randu<arma::mat>(5, 1000);
@@ -195,15 +193,16 @@ BOOST_AUTO_TEST_CASE(LinearRegressionTrainTest)
 
   lrTrain.Train(dataset, responses);
 
-  BOOST_REQUIRE_EQUAL(lr.Parameters().n_elem, lrTrain.Parameters().n_elem);
+  REQUIRE(lr.Parameters().n_elem == lrTrain.Parameters().n_elem);
   for (size_t i = 0; i < lr.Parameters().n_elem; ++i)
-    BOOST_REQUIRE_CLOSE(lr.Parameters()[i], lrTrain.Parameters()[i], 1e-5);
+    REQUIRE(lr.Parameters()[i] ==
+        Approx(lrTrain.Parameters()[i]).epsilon(1e-7));
 }
 
 /*
  * Linear regression serialization test.
  */
-BOOST_AUTO_TEST_CASE(LinearRegressionTest)
+TEST_CASE("LinearRegressionTest", "[LinearRegressionTest]")
 {
   // Generate some random data.
   arma::mat data;
@@ -216,9 +215,9 @@ BOOST_AUTO_TEST_CASE(LinearRegressionTest)
 
   SerializeObjectAll(lr, xmlLr, textLr, binaryLr);
 
-  BOOST_REQUIRE_CLOSE(lr.Lambda(), xmlLr.Lambda(), 1e-8);
-  BOOST_REQUIRE_CLOSE(lr.Lambda(), textLr.Lambda(), 1e-8);
-  BOOST_REQUIRE_CLOSE(lr.Lambda(), binaryLr.Lambda(), 1e-8);
+  REQUIRE(lr.Lambda() == Approx(xmlLr.Lambda()).epsilon(1e-10));
+  REQUIRE(lr.Lambda() == Approx(textLr.Lambda()).epsilon(1e-10));
+  REQUIRE(lr.Lambda() == Approx(binaryLr.Lambda()).epsilon(1e-10));
 
   CheckMatrices(lr.Parameters(), xmlLr.Parameters(), textLr.Parameters(),
       binaryLr.Parameters());
@@ -227,7 +226,7 @@ BOOST_AUTO_TEST_CASE(LinearRegressionTest)
 /**
  * Test that LinearRegression::Train() returns finite OLS error.
  */
-BOOST_AUTO_TEST_CASE(LinearRegressionTrainReturnObjective)
+TEST_CASE("LinearRegressionTrainReturnObjective", "[LinearRegressionTest]")
 {
   arma::mat predictors(3, 10);
   arma::mat points(3, 10);
@@ -265,7 +264,5 @@ BOOST_AUTO_TEST_CASE(LinearRegressionTrainReturnObjective)
   LinearRegression lr;
   double error = lr.Train(predictors, responses);
 
-  BOOST_REQUIRE_EQUAL(std::isfinite(error), true);
+  REQUIRE(std::isfinite(error) == true);
 }
-
-BOOST_AUTO_TEST_SUITE_END();
