@@ -21,8 +21,8 @@ static const std::string testName = "HMMTrain";
 #include <mlpack/methods/hmm/hmm_train_main.cpp>
 #include <mlpack/methods/hmm/hmm_model.hpp>
 
-#include <boost/test/unit_test.hpp>
-#include "../test_tools.hpp"
+#include "../catch.hpp"
+#include "../test_catch_tools.hpp"
 
 #include <boost/archive/text_oarchive.hpp>
 #include <boost/archive/text_iarchive.hpp>
@@ -35,24 +35,22 @@ struct HMMTrainMainTestFixture
   HMMTrainMainTestFixture()
   {
     // Cache in the options for this program.
-    CLI::RestoreSettings(testName);
+    IO::RestoreSettings(testName);
   }
 
   ~HMMTrainMainTestFixture()
   {
     // Clear the settings.
     bindings::tests::CleanMemory();
-    CLI::ClearSettings();
+    IO::ClearSettings();
   }
 };
 
-BOOST_FIXTURE_TEST_SUITE(HMMTrainMainTest, HMMTrainMainTestFixture);
-
 inline void FileExists(std::string fileName)
 {
   ifstream ifp(fileName);
   if (!ifp.good())
-    BOOST_FAIL("Bad stream " + fileName);
+    FAIL("Bad stream " + fileName);
   ifp.close();
 }
 
@@ -64,7 +62,7 @@ inline void CheckMatricesDiffer(arma::mat& a, arma::mat& b, double tolerance)
   bool valsEqual = true;
   if (dimsEqual)
   {
-    for (size_t i=0; i<a.n_elem; i++)
+    for (size_t i = 0; i < a.n_elem; ++i)
     {
       if (std::abs(a[i]) < tolerance / 2)
         valsEqual = valsEqual && (std::abs(b[i]) < tolerance / 2);
@@ -72,14 +70,14 @@ inline void CheckMatricesDiffer(arma::mat& a, arma::mat& b, double tolerance)
         valsEqual = valsEqual && (std::abs(a[i] - b[i]) < tolerance);
     }
   }
-  BOOST_REQUIRE(!(dimsEqual && valsEqual));
+  REQUIRE(!(dimsEqual && valsEqual));
 }
 
 inline void ApproximatelyEqual(HMMModel& h1,
                                HMMModel& h2,
                                double tolerance = 1.0)
 {
-  BOOST_REQUIRE(h1.Type() == h2.Type());
+  REQUIRE(h1.Type() == h2.Type());
   HMMType  hmmType = h1.Type();
   if (hmmType ==  DiscreteHMM)
   {
@@ -98,11 +96,11 @@ inline void ApproximatelyEqual(HMMModel& h1,
     std::vector<distribution::DiscreteDistribution> d2 =
         h2.DiscreteHMM()->Emission();
 
-    BOOST_REQUIRE_EQUAL(d1.size(), d2.size());
+    REQUIRE(d1.size() == d2.size());
 
     size_t states = d1.size();
-    for (size_t i = 0; i < states; i++)
-      for (size_t j = 0; j < d1[i].Dimensionality(); j++)
+    for (size_t i = 0; i < states; ++i)
+      for (size_t j = 0; j < d1[i].Dimensionality(); ++j)
         CheckMatrices(d1[i].Probabilities(j)*100,
             d2[i].Probabilities(j)*100,
             tolerance);
@@ -123,10 +121,10 @@ inline void ApproximatelyEqual(HMMModel& h1,
     std::vector<distribution::GaussianDistribution> d2 =
         h2.GaussianHMM()->Emission();
 
-    BOOST_REQUIRE_EQUAL(d1.size(), d2.size());
+    REQUIRE(d1.size() == d2.size());
 
     size_t states = d1.size();
-    for (size_t i=0; i < states; i++)
+    for (size_t i=0; i < states; ++i)
     {
       CheckMatrices(d1[i].Mean()*100, d2[i].Mean()*100, tolerance);
       CheckMatrices(d1[i].Covariance()*100, d2[i].Covariance()*100, tolerance);
@@ -146,14 +144,14 @@ inline void ApproximatelyEqual(HMMModel& h1,
     std::vector<gmm::GMM> d1 = h1.GMMHMM()->Emission();
     std::vector<gmm::GMM> d2 = h2.GMMHMM()->Emission();
 
-    BOOST_REQUIRE_EQUAL(d1.size(), d2.size());
+    REQUIRE(d1.size() == d2.size());
 
     size_t states = d1.size();
-    for (size_t i=0; i < states; i++)
+    for (size_t i=0; i < states; ++i)
     {
-      BOOST_REQUIRE_EQUAL(d1[i].Gaussians(), d2[i].Gaussians());
+      REQUIRE(d1[i].Gaussians() == d2[i].Gaussians());
       size_t gaussians = d1[i].Gaussians();
-      for (size_t j=0; j<gaussians; j++)
+      for (size_t j=0; j<gaussians; ++j)
       {
         CheckMatrices(d1[i].Component(j).Mean()*100,
             d2[i].Component(j).Mean()*100,
@@ -179,15 +177,15 @@ inline void ApproximatelyEqual(HMMModel& h1,
     std::vector<gmm::DiagonalGMM> d1 = h1.DiagGMMHMM()->Emission();
     std::vector<gmm::DiagonalGMM> d2 = h2.DiagGMMHMM()->Emission();
 
-    BOOST_REQUIRE_EQUAL(d1.size(), d2.size());
+    REQUIRE(d1.size() == d2.size());
 
     // Check if gaussian, mean, covariance and weights are equal.
     size_t states = d1.size();
-    for (size_t i = 0; i < states; i++)
+    for (size_t i = 0; i < states; ++i)
     {
-      BOOST_REQUIRE_EQUAL(d1[i].Gaussians(), d2[i].Gaussians());
+      REQUIRE(d1[i].Gaussians() == d2[i].Gaussians());
       size_t gaussians = d1[i].Gaussians();
-      for (size_t j = 0; j < gaussians; j++)
+      for (size_t j = 0; j < gaussians; ++j)
       {
         CheckMatrices(d1[i].Component(j).Mean()*100,
             d2[i].Component(j).Mean()*100,
@@ -202,7 +200,8 @@ inline void ApproximatelyEqual(HMMModel& h1,
 }
 
 // Make sure that the number of states cannot be negative
-BOOST_AUTO_TEST_CASE(HMMTrainStatesTest)
+TEST_CASE_METHOD(HMMTrainMainTestFixture, "HMMTrainStatesTest",
+                 "[HMMTrainMainTest][BindingTests]")
 {
   std::string inputFileName = "hmm_train_obs.csv";
   int states = -3;  // Invalid!
@@ -214,12 +213,13 @@ BOOST_AUTO_TEST_CASE(HMMTrainStatesTest)
   SetInputParam("type", std::move(hmmType));
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
 // Make sure that tolerance is non negative
-BOOST_AUTO_TEST_CASE(HMMTrainToleranceNonNegative)
+TEST_CASE_METHOD(HMMTrainMainTestFixture, "HMMTrainToleranceNonNegative",
+                 "[HMMTrainMainTest][BindingTests]")
 {
   std::string inputFileName = "hmm_train_obs.csv";
   int states = 3;
@@ -233,13 +233,14 @@ BOOST_AUTO_TEST_CASE(HMMTrainToleranceNonNegative)
   SetInputParam("tolerance", tol);
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
 // Make sure an error is thrown if type is something other than
 // "discrete", "gaussian" or "gmm"
-BOOST_AUTO_TEST_CASE(HMMTrainTypeTest)
+TEST_CASE_METHOD(HMMTrainMainTestFixture, "HMMTrainTypeTest",
+                 "[HMMTrainMainTest][BindingTests]")
 {
   std::string inputFileName = "hmm_train_obs.csv";
   int states = 3;
@@ -251,12 +252,13 @@ BOOST_AUTO_TEST_CASE(HMMTrainTypeTest)
   SetInputParam("type", std::move(hmmType));
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
 // Make sure that the number of gaussians cannot be less than 0
-BOOST_AUTO_TEST_CASE(HMMTrainGaussianTest)
+TEST_CASE_METHOD(HMMTrainMainTestFixture, "HMMTrainGaussianTest",
+                 "[HMMTrainMainTest][BindingTests]")
 {
   std::string inputFileName = "hmm_train_obs.csv";
   int states = 3;
@@ -270,12 +272,13 @@ BOOST_AUTO_TEST_CASE(HMMTrainGaussianTest)
   SetInputParam("gaussians", gaussians);
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
 // Make sure that the number of Gaussians cannot be less than 0.
-BOOST_AUTO_TEST_CASE(HMMTrainDiagonalGaussianTest)
+TEST_CASE_METHOD(HMMTrainMainTestFixture, "HMMTrainDiagonalGaussianTest",
+                 "[HMMTrainMainTest][BindingTests]")
 {
   std::string inputFileName = "hmm_train_obs.csv";
   int states = 3;
@@ -289,12 +292,13 @@ BOOST_AUTO_TEST_CASE(HMMTrainDiagonalGaussianTest)
   SetInputParam("gaussians", gaussians);
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
 // Make sure that model reuse is possible and work properly
-BOOST_AUTO_TEST_CASE(HMMTrainReuseDiscreteModelTest)
+TEST_CASE_METHOD(HMMTrainMainTestFixture, "HMMTrainReuseDiscreteModelTest",
+                 "[HMMTrainMainTest][BindingTests]")
 {
   std::string inputObsFileName = "hmm_train_obs.csv";
   std::string inputLabFileName = "hmm_train_lab.csv";
@@ -308,7 +312,7 @@ BOOST_AUTO_TEST_CASE(HMMTrainReuseDiscreteModelTest)
   arma::mat trainObs, trainLab;
   data::Load(inputObsFileName, trainObs);
   data::Load(inputLabFileName, trainLab);
-  BOOST_REQUIRE_EQUAL(trainObs.n_rows, trainLab.n_rows);
+  REQUIRE(trainObs.n_rows == trainLab.n_rows);
 
   SetInputParam("input_file", std::move(inputObsFileName));
   SetInputParam("labels_file", std::move(inputLabFileName));
@@ -317,22 +321,23 @@ BOOST_AUTO_TEST_CASE(HMMTrainReuseDiscreteModelTest)
 
   mlpackMain();
 
-  HMMModel h1 = *(CLI::GetParam<HMMModel*>("output_model"));
+  HMMModel h1 = *(IO::GetParam<HMMModel*>("output_model"));
 
-  SetInputParam("input_model", CLI::GetParam<HMMModel*>("output_model"));
+  SetInputParam("input_model", IO::GetParam<HMMModel*>("output_model"));
 
-  CLI::GetSingleton().Parameters()["type"].wasPassed = false;
-  CLI::GetSingleton().Parameters()["states"].wasPassed = false;
+  IO::GetSingleton().Parameters()["type"].wasPassed = false;
+  IO::GetSingleton().Parameters()["states"].wasPassed = false;
 
   mlpackMain();
 
-  HMMModel h2 = *(CLI::GetParam<HMMModel*>("output_model"));
+  HMMModel h2 = *(IO::GetParam<HMMModel*>("output_model"));
 
   ApproximatelyEqual(h1, h2);
 }
 
 // Make sure that model reuse is possible and work properly
-BOOST_AUTO_TEST_CASE(HMMTrainReuseGaussianModelTest)
+TEST_CASE_METHOD(HMMTrainMainTestFixture, "HMMTrainReuseGaussianModelTest",
+                 "[HMMTrainMainTest][BindingTests]")
 {
   std::string inputObsFileName = "hmm_train_obs.csv";
   std::string hmmType = "gaussian";
@@ -350,22 +355,23 @@ BOOST_AUTO_TEST_CASE(HMMTrainReuseGaussianModelTest)
 
   mlpackMain();
 
-  HMMModel h1 = *(CLI::GetParam<HMMModel*>("output_model"));
+  HMMModel h1 = *(IO::GetParam<HMMModel*>("output_model"));
 
-  SetInputParam("input_model", CLI::GetParam<HMMModel*>("output_model"));
+  SetInputParam("input_model", IO::GetParam<HMMModel*>("output_model"));
   SetInputParam("tolerance", 1e10);
 
-  CLI::GetSingleton().Parameters()["type"].wasPassed = false;
-  CLI::GetSingleton().Parameters()["states"].wasPassed = false;
+  IO::GetSingleton().Parameters()["type"].wasPassed = false;
+  IO::GetSingleton().Parameters()["states"].wasPassed = false;
 
   mlpackMain();
 
-  HMMModel h2 = *(CLI::GetParam<HMMModel*>("output_model"));
+  HMMModel h2 = *(IO::GetParam<HMMModel*>("output_model"));
 
   ApproximatelyEqual(h1, h2);
 }
 
-BOOST_AUTO_TEST_CASE(HMMTrainNoLabelsReuseModelTest)
+TEST_CASE_METHOD(HMMTrainMainTestFixture, "HMMTrainNoLabelsReuseModelTest",
+                 "[HMMTrainMainTest][BindingTests]")
 {
   std::string inputObsFileName = "hmm_train_obs.csv";
   std::string hmmType = "discrete";
@@ -381,23 +387,24 @@ BOOST_AUTO_TEST_CASE(HMMTrainNoLabelsReuseModelTest)
   // This call will train HMM using Baum-Welch training
   mlpackMain();
 
-  HMMModel h1 = *(CLI::GetParam<HMMModel*>("output_model"));
+  HMMModel h1 = *(IO::GetParam<HMMModel*>("output_model"));
 
-  SetInputParam("input_model", CLI::GetParam<HMMModel*>("output_model"));
+  SetInputParam("input_model", IO::GetParam<HMMModel*>("output_model"));
 
-  CLI::GetSingleton().Parameters()["type"].wasPassed = false;
-  CLI::GetSingleton().Parameters()["states"].wasPassed = false;
+  IO::GetSingleton().Parameters()["type"].wasPassed = false;
+  IO::GetSingleton().Parameters()["states"].wasPassed = false;
 
   // Train again using Baum Welch
   mlpackMain();
 
-  HMMModel h2 = *(CLI::GetParam<HMMModel*>("output_model"));
+  HMMModel h2 = *(IO::GetParam<HMMModel*>("output_model"));
 
   ApproximatelyEqual(h1, h2);
 }
 
 // Test batch mode
-BOOST_AUTO_TEST_CASE(HMMTrainBatchModeTest)
+TEST_CASE_METHOD(HMMTrainMainTestFixture, "HMMTrainBatchModeTest",
+                 "[HMMTrainMainTest][BindingTests]")
 {
   std::string observationsFileName = "observations.txt";
   std::string labelsFileName = "labels.txt";
@@ -408,7 +415,7 @@ BOOST_AUTO_TEST_CASE(HMMTrainBatchModeTest)
   SetInputParam("labels_file", std::move(labelsFileName));
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 
   SetInputParam("states", states);
@@ -422,7 +429,7 @@ BOOST_AUTO_TEST_CASE(HMMTrainBatchModeTest)
   SetInputParam("input_file", std::move(observationsFileName));
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 
   // Now a mismatch between #observation files and #label files
@@ -430,11 +437,12 @@ BOOST_AUTO_TEST_CASE(HMMTrainBatchModeTest)
   SetInputParam("input_file", std::move(observationsFileName));
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
-BOOST_AUTO_TEST_CASE(HMMTrainRetrainTest1)
+TEST_CASE_METHOD(HMMTrainMainTestFixture, "HMMTrainRetrainTest1",
+                 "[HMMTrainMainTest][BindingTests]")
 {
   std::string inputObsFile1 = "obs1.csv";
   std::string type = "discrete";
@@ -449,30 +457,31 @@ BOOST_AUTO_TEST_CASE(HMMTrainRetrainTest1)
 
   mlpackMain();
 
-  HMMModel h1 = *(CLI::GetParam<HMMModel*>("output_model"));
+  HMMModel h1 = *(IO::GetParam<HMMModel*>("output_model"));
 
   std::string inputObsFile2 = "obs4.csv";
 
-  CLI::GetSingleton().Parameters()["input_file"].wasPassed = false;
-  CLI::GetSingleton().Parameters()["type"].wasPassed = false;
-  CLI::GetSingleton().Parameters()["states"].wasPassed = false;
+  IO::GetSingleton().Parameters()["input_file"].wasPassed = false;
+  IO::GetSingleton().Parameters()["type"].wasPassed = false;
+  IO::GetSingleton().Parameters()["states"].wasPassed = false;
 
   FileExists(inputObsFile2);
   SetInputParam("input_file", std::move(inputObsFile2));
-  SetInputParam("input_model", CLI::GetParam<HMMModel*>("output_model"));
+  SetInputParam("input_model", IO::GetParam<HMMModel*>("output_model"));
 
   mlpackMain();
 
-  HMMModel h2 = *(CLI::GetParam<HMMModel*>("output_model"));
+  HMMModel h2 = *(IO::GetParam<HMMModel*>("output_model"));
 
-  BOOST_REQUIRE(h1.Type() == h2.Type());
+  REQUIRE(h1.Type() == h2.Type());
   // Since we know that type of HMMs is discrete
   CheckMatricesDiffer(h1.DiscreteHMM()->Transition(),
       h2.DiscreteHMM()->Transition(), 1e-50);
 }
 
 // Attempt to retrain but increase states the second time round
-BOOST_AUTO_TEST_CASE(HMMTrainRetrainTest2)
+TEST_CASE_METHOD(HMMTrainMainTestFixture, "HMMTrainRetrainTest2",
+                 "[HMMTrainMainTest][BindingTests]")
 {
   // Provide no labels file
   std::string inputObsFile1 = "obs1.csv";
@@ -485,7 +494,7 @@ BOOST_AUTO_TEST_CASE(HMMTrainRetrainTest2)
 
   mlpackMain();
 
-  HMMModel h1 = *(CLI::GetParam<HMMModel*>("output_model"));
+  HMMModel h1 = *(IO::GetParam<HMMModel*>("output_model"));
 
   std::string inputObsFile2 = "obs3.csv";
   std::string inputLabFile2 = "lab1_corrupt.csv";
@@ -493,18 +502,19 @@ BOOST_AUTO_TEST_CASE(HMMTrainRetrainTest2)
   SetInputParam("input_file", std::move(inputObsFile2));
   // Provide a labels file with more states than initially specified
   SetInputParam("labels_file", std::move(inputLabFile2));
-  SetInputParam("input_model", CLI::GetParam<HMMModel*>("output_model"));
+  SetInputParam("input_model", IO::GetParam<HMMModel*>("output_model"));
 
-  CLI::GetSingleton().Parameters()["type"].wasPassed = false;
-  CLI::GetSingleton().Parameters()["states"].wasPassed = false;
+  IO::GetSingleton().Parameters()["type"].wasPassed = false;
+  IO::GetSingleton().Parameters()["states"].wasPassed = false;
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
 // Attempt to retrain but change the emission distribution type
-BOOST_AUTO_TEST_CASE(HMMTrainRetrainTest3)
+TEST_CASE_METHOD(HMMTrainMainTestFixture, "HMMTrainRetrainTest3",
+                 "[HMMTrainMainTest][BindingTests]")
 {
   // Provide no labels file
   std::string inputObsFile1 = "obs1.csv";
@@ -517,7 +527,7 @@ BOOST_AUTO_TEST_CASE(HMMTrainRetrainTest3)
 
   mlpackMain();
 
-  HMMModel h1 = *(CLI::GetParam<HMMModel*>("output_model"));
+  HMMModel h1 = *(IO::GetParam<HMMModel*>("output_model"));
 
   std::string inputObsFile2 = "obs2.csv";
   std::string inputLabFile2 = "lab2.csv";
@@ -526,19 +536,17 @@ BOOST_AUTO_TEST_CASE(HMMTrainRetrainTest3)
   SetInputParam("input_file", std::move(inputObsFile2));
   SetInputParam("labels_file", std::move(inputLabFile2));
   SetInputParam("type", std::move(type));
-  SetInputParam("input_model", CLI::GetParam<HMMModel*>("output_model"));
+  SetInputParam("input_model", IO::GetParam<HMMModel*>("output_model"));
 
-  CLI::GetSingleton().Parameters()["states"].wasPassed = false;
+  IO::GetSingleton().Parameters()["states"].wasPassed = false;
 
   mlpackMain();
   // Note that when emission type is changed -- like in this test, a warning
   // is printed stating that the new type is being ignored (no error is raised)
 
-  HMMModel h2 = *(CLI::GetParam<HMMModel*>("output_model"));
+  HMMModel h2 = *(IO::GetParam<HMMModel*>("output_model"));
 
-  BOOST_REQUIRE(h1.Type() == DiscreteHMM);
-  BOOST_REQUIRE(h2.Type() == DiscreteHMM);
-  BOOST_REQUIRE(h2.Type() != GaussianHMM);
+  REQUIRE(h1.Type() == DiscreteHMM);
+  REQUIRE(h2.Type() == DiscreteHMM);
+  REQUIRE(h2.Type() != GaussianHMM);
 }
-
-BOOST_AUTO_TEST_SUITE_END();
