@@ -20,8 +20,7 @@ static const std::string testName = "KDE";
 #include "test_helper.hpp"
 #include <mlpack/methods/kde/kde_main.cpp>
 
-#include <boost/test/unit_test.hpp>
-#include "../test_tools.hpp"
+#include "../catch.hpp"
 
 using namespace mlpack;
 
@@ -31,30 +30,29 @@ struct KDETestFixture
   KDETestFixture()
   {
     // Cache in the options for this program.
-    CLI::RestoreSettings(testName);
+    IO::RestoreSettings(testName);
   }
 
   ~KDETestFixture()
   {
     // Clear the settings.
     bindings::tests::CleanMemory();
-    CLI::ClearSettings();
+    IO::ClearSettings();
   }
 };
 
 void ResetKDESettings()
 {
-  CLI::ClearSettings();
-  CLI::RestoreSettings(testName);
+  IO::ClearSettings();
+  IO::RestoreSettings(testName);
 }
 
-BOOST_FIXTURE_TEST_SUITE(KDEMainTest, KDETestFixture);
-
 /**
   * Ensure that the estimations we get for KDEMain, are the same as the ones we
   * get from the KDE class without any wrappers. Requires normalization.
  **/
-BOOST_AUTO_TEST_CASE(KDEGaussianRTreeResultsMain)
+TEST_CASE_METHOD(KDETestFixture, "KDEGaussianRTreeResultsMain",
+                "[KDEMainTest][BindingTests]")
 {
   // Datasets.
   arma::mat reference = arma::randu(3, 500);
@@ -85,18 +83,19 @@ BOOST_AUTO_TEST_CASE(KDEGaussianRTreeResultsMain)
 
   mlpackMain();
 
-  mainEstimations = std::move(CLI::GetParam<arma::vec>("predictions"));
+  mainEstimations = std::move(IO::GetParam<arma::vec>("predictions"));
 
   // Check whether results are equal.
   for (size_t i = 0; i < query.n_cols; ++i)
-    BOOST_REQUIRE_CLOSE(kdeEstimations[i], mainEstimations[i], 100 * relError);
+    REQUIRE(kdeEstimations[i] == Approx( mainEstimations[i]).epsilon(relError));
 }
 
 /**
   * Ensure that the estimations we get for KDEMain, are the same as the ones we
   * get from the KDE class without any wrappers. Doesn't require normalization.
  **/
-BOOST_AUTO_TEST_CASE(KDETriangularBallTreeResultsMain)
+TEST_CASE_METHOD(KDETestFixture, "KDETriangularBallTreeResultsMain",
+                "[KDEMainTest][BindingTests]")
 {
   // Datasets.
   arma::mat reference = arma::randu(3, 300);
@@ -125,18 +124,19 @@ BOOST_AUTO_TEST_CASE(KDETriangularBallTreeResultsMain)
 
   mlpackMain();
 
-  mainEstimations = std::move(CLI::GetParam<arma::vec>("predictions"));
+  mainEstimations = std::move(IO::GetParam<arma::vec>("predictions"));
 
   // Check whether results are equal.
   for (size_t i = 0; i < query.n_cols; ++i)
-    BOOST_REQUIRE_CLOSE(kdeEstimations[i], mainEstimations[i], 100 * relError);
+    REQUIRE(kdeEstimations[i] == Approx( mainEstimations[i]).epsilon(relError));
 }
 
 /**
   * Ensure that the estimations we get for KDEMain, are the same as the ones we
   * get from the KDE class without any wrappers in the monochromatic case.
  **/
-BOOST_AUTO_TEST_CASE(KDEMonoResultsMain)
+TEST_CASE_METHOD(KDETestFixture, "KDEMonoResultsMain",
+                "[KDEMainTest][BindingTests]")
 {
   // Datasets.
   arma::mat reference = arma::randu(2, 300);
@@ -166,28 +166,30 @@ BOOST_AUTO_TEST_CASE(KDEMonoResultsMain)
 
   mlpackMain();
 
-  mainEstimations = std::move(CLI::GetParam<arma::vec>("predictions"));
+  mainEstimations = std::move(IO::GetParam<arma::vec>("predictions"));
 
   // Check whether results are equal.
   for (size_t i = 0; i < reference.n_cols; ++i)
-    BOOST_REQUIRE_CLOSE(kdeEstimations[i], mainEstimations[i], 100 * relError);
+    REQUIRE(kdeEstimations[i] == Approx( mainEstimations[i]).epsilon(relError));
 }
 
 /**
   * Ensuring that absence of input data is checked.
  **/
-BOOST_AUTO_TEST_CASE(KDENoInputData)
+TEST_CASE_METHOD(KDETestFixture, "KDENoInputData",
+                "[KDEMainTest][BindingTests]")
 {
   // No input data is not provided. Should throw a runtime error.
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
 /**
   * Check result has as many densities as query points.
  **/
-BOOST_AUTO_TEST_CASE(KDEOutputSize)
+TEST_CASE_METHOD(KDETestFixture, "KDEOutputSize",
+                "[KDEMainTest][BindingTests]")
 {
   const size_t dim = 3;
   const size_t samples = 110;
@@ -200,13 +202,14 @@ BOOST_AUTO_TEST_CASE(KDEOutputSize)
 
   mlpackMain();
   // Check number of output elements.
-  BOOST_REQUIRE_EQUAL(CLI::GetParam<arma::vec>("predictions").size(), samples);
+  REQUIRE(IO::GetParam<arma::vec>("predictions").size() == samples);
 }
 
 /**
   * Check that saved model can be reused.
  **/
-BOOST_AUTO_TEST_CASE(KDEModelReuse)
+TEST_CASE_METHOD(KDETestFixture, "KDEModelReuse",
+                "[KDEMainTest][BindingTests]")
 {
   const size_t dim = 3;
   const size_t samples = 100;
@@ -222,28 +225,29 @@ BOOST_AUTO_TEST_CASE(KDEModelReuse)
 
   mlpackMain();
 
-  arma::vec oldEstimations = std::move(CLI::GetParam<arma::vec>("predictions"));
+  arma::vec oldEstimations = std::move(IO::GetParam<arma::vec>("predictions"));
 
   // Change parameters and load model.
-  CLI::GetSingleton().Parameters()["reference"].wasPassed = false;
+  IO::GetSingleton().Parameters()["reference"].wasPassed = false;
   SetInputParam("query", query);
   SetInputParam("input_model",
-      std::move(CLI::GetParam<KDEModel*>("output_model")));
+      std::move(IO::GetParam<KDEModel*>("output_model")));
 
   mlpackMain();
 
-  arma::vec newEstimations = std::move(CLI::GetParam<arma::vec>("predictions"));
+  arma::vec newEstimations = std::move(IO::GetParam<arma::vec>("predictions"));
 
   // Check estimations are the same.
   for (size_t i = 0; i < samples; ++i)
-    BOOST_REQUIRE_CLOSE(oldEstimations[i], newEstimations[i], 100 * relError);
+    REQUIRE(oldEstimations[i] == Approx( newEstimations[i]).epsilon(relError));
 }
 
 /**
   * Ensure that the estimations we get for KDEMain, are the same as the ones we
   * get from the KDE class without any wrappers using single-tree mode.
  **/
-BOOST_AUTO_TEST_CASE(KDEGaussianSingleKDTreeResultsMain)
+TEST_CASE_METHOD(KDETestFixture, "KDEGaussianSingleKDTreeResultsMain",
+                "[KDEMainTest][BindingTests]")
 {
   // Datasets.
   arma::mat reference = arma::randu(3, 400);
@@ -274,17 +278,18 @@ BOOST_AUTO_TEST_CASE(KDEGaussianSingleKDTreeResultsMain)
 
   mlpackMain();
 
-  mainEstimations = std::move(CLI::GetParam<arma::vec>("predictions"));
+  mainEstimations = std::move(IO::GetParam<arma::vec>("predictions"));
 
   // Check whether results are equal.
   for (size_t i = 0; i < query.n_cols; ++i)
-    BOOST_REQUIRE_CLOSE(kdeEstimations[i], mainEstimations[i], 100 * relError);
+    REQUIRE(kdeEstimations[i] == Approx( mainEstimations[i]).epsilon(relError));
 }
 
 /**
   * Ensure we get an exception when an invalid kernel is specified.
  **/
-BOOST_AUTO_TEST_CASE(KDEMainInvalidKernel)
+TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidKernel",
+                "[KDEMainTest][BindingTests]")
 {
   arma::mat reference = arma::randu<arma::mat>(2, 10);
   arma::mat query = arma::randu<arma::mat>(2, 5);
@@ -295,14 +300,15 @@ BOOST_AUTO_TEST_CASE(KDEMainInvalidKernel)
   SetInputParam("kernel", std::string("linux"));
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
 /**
   * Ensure we get an exception when an invalid tree is specified.
  **/
-BOOST_AUTO_TEST_CASE(KDEMainInvalidTree)
+TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidTree",
+                "[KDEMainTest][BindingTests]")
 {
   arma::mat reference = arma::randu<arma::mat>(2, 10);
   arma::mat query = arma::randu<arma::mat>(2, 5);
@@ -313,14 +319,15 @@ BOOST_AUTO_TEST_CASE(KDEMainInvalidTree)
   SetInputParam("tree", std::string("olive"));
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
 /**
   * Ensure we get an exception when an invalid algorithm is specified.
  **/
-BOOST_AUTO_TEST_CASE(KDEMainInvalidAlgorithm)
+TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidAlgorithm",
+                "[KDEMainTest][BindingTests]")
 {
   arma::mat reference = arma::randu<arma::mat>(2, 10);
   arma::mat query = arma::randu<arma::mat>(2, 5);
@@ -331,7 +338,7 @@ BOOST_AUTO_TEST_CASE(KDEMainInvalidAlgorithm)
   SetInputParam("algorithm", std::string("bogosort"));
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
@@ -339,7 +346,8 @@ BOOST_AUTO_TEST_CASE(KDEMainInvalidAlgorithm)
   * Ensure we get an exception when both reference and input_model are
   * specified.
  **/
-BOOST_AUTO_TEST_CASE(KDEMainReferenceAndModel)
+TEST_CASE_METHOD(KDETestFixture, "KDEMainReferenceAndModel",
+                "[KDEMainTest][BindingTests]")
 {
   arma::mat reference = arma::randu<arma::mat>(2, 10);
   arma::mat query = arma::randu<arma::mat>(2, 5);
@@ -351,14 +359,15 @@ BOOST_AUTO_TEST_CASE(KDEMainReferenceAndModel)
   SetInputParam("input_model", model);
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
 /**
   * Ensure we get an exception when an invalid absolute error is specified.
  **/
-BOOST_AUTO_TEST_CASE(KDEMainInvalidAbsoluteError)
+TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidAbsoluteError",
+                "[KDEMainTest][BindingTests]")
 {
   arma::mat reference = arma::randu<arma::mat>(1, 10);
   arma::mat query = arma::randu<arma::mat>(1, 5);
@@ -370,18 +379,19 @@ BOOST_AUTO_TEST_CASE(KDEMainInvalidAbsoluteError)
   Log::Fatal.ignoreInput = true;
   // Invalid value.
   SetInputParam("abs_error", -0.1);
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
 
   // Valid value.
   SetInputParam("abs_error", 5.8);
-  BOOST_REQUIRE_NO_THROW(mlpackMain());
+  REQUIRE_NOTHROW(mlpackMain());
   Log::Fatal.ignoreInput = false;
 }
 
 /**
   * Ensure we get an exception when an invalid relative error is specified.
  **/
-BOOST_AUTO_TEST_CASE(KDEMainInvalidRelativeError)
+TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidRelativeError",
+                "[KDEMainTest][BindingTests]")
 {
   arma::mat reference = arma::randu<arma::mat>(1, 10);
   arma::mat query = arma::randu<arma::mat>(1, 5);
@@ -393,15 +403,15 @@ BOOST_AUTO_TEST_CASE(KDEMainInvalidRelativeError)
   Log::Fatal.ignoreInput = true;
   // Invalid under 0.
   SetInputParam("rel_error", -0.1);
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
 
   // Invalid over 1.
   SetInputParam("rel_error", 1.1);
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
 
   // Valid value.
   SetInputParam("rel_error", 0.3);
-  BOOST_REQUIRE_NO_THROW(mlpackMain());
+  REQUIRE_NOTHROW(mlpackMain());
   Log::Fatal.ignoreInput = false;
 }
 
@@ -409,7 +419,8 @@ BOOST_AUTO_TEST_CASE(KDEMainInvalidRelativeError)
   * Ensure we get an exception when an invalid Monte Carlo probability is
   * specified.
  **/
-BOOST_AUTO_TEST_CASE(KDEMainInvalidMCProbability)
+TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidMCProbability",
+                "[KDEMainTest][BindingTests]")
 {
   arma::mat reference = arma::randu<arma::mat>(1, 10);
   arma::mat query = arma::randu<arma::mat>(1, 5);
@@ -423,15 +434,15 @@ BOOST_AUTO_TEST_CASE(KDEMainInvalidMCProbability)
   Log::Fatal.ignoreInput = true;
   // Invalid under 0.
   SetInputParam("mc_probability", -0.1);
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
 
   // Invalid over 1.
   SetInputParam("mc_probability", 1.1);
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
 
   // Valid value.
   SetInputParam("mc_probability", 0.3);
-  BOOST_REQUIRE_NO_THROW(mlpackMain());
+  REQUIRE_NOTHROW(mlpackMain());
   Log::Fatal.ignoreInput = false;
 }
 
@@ -439,7 +450,8 @@ BOOST_AUTO_TEST_CASE(KDEMainInvalidMCProbability)
   * Ensure we get an exception when an invalid Monte Carlo initial sample size
   * is specified.
  **/
-BOOST_AUTO_TEST_CASE(KDEMainInvalidMCInitialSampleSize)
+TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidMCInitialSampleSize",
+                "[KDEMainTest][BindingTests]")
 {
   arma::mat reference = arma::randu<arma::mat>(1, 10);
   arma::mat query = arma::randu<arma::mat>(1, 5);
@@ -453,15 +465,15 @@ BOOST_AUTO_TEST_CASE(KDEMainInvalidMCInitialSampleSize)
   Log::Fatal.ignoreInput = true;
   // Invalid under 0.
   SetInputParam("initial_sample_size", -1);
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
 
   // Invalid 0.
   SetInputParam("initial_sample_size", 0);
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
 
   // Valid value.
   SetInputParam("initial_sample_size", 20);
-  BOOST_REQUIRE_NO_THROW(mlpackMain());
+  REQUIRE_NOTHROW(mlpackMain());
   Log::Fatal.ignoreInput = false;
 }
 
@@ -469,7 +481,8 @@ BOOST_AUTO_TEST_CASE(KDEMainInvalidMCInitialSampleSize)
   * Ensure we get an exception when an invalid Monte Carlo entry coefficient
   * is specified.
  **/
-BOOST_AUTO_TEST_CASE(KDEMainInvalidMCEntryCoef)
+TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidMCEntryCoef",
+                "[KDEMainTest][BindingTests]")
 {
   arma::mat reference = arma::randu<arma::mat>(1, 10);
   arma::mat query = arma::randu<arma::mat>(1, 5);
@@ -483,11 +496,11 @@ BOOST_AUTO_TEST_CASE(KDEMainInvalidMCEntryCoef)
   Log::Fatal.ignoreInput = true;
   // Invalid under 1.
   SetInputParam("mc_entry_coef", 0.5);
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
 
   // Valid greater than 1.
   SetInputParam("mc_entry_coef", 1.1);
-  BOOST_REQUIRE_NO_THROW(mlpackMain());
+  REQUIRE_NOTHROW(mlpackMain());
   Log::Fatal.ignoreInput = false;
 }
 
@@ -495,7 +508,8 @@ BOOST_AUTO_TEST_CASE(KDEMainInvalidMCEntryCoef)
   * Ensure we get an exception when an invalid Monte Carlo break coefficient
   * is specified.
  **/
-BOOST_AUTO_TEST_CASE(KDEMainInvalidMCBreakCoef)
+TEST_CASE_METHOD(KDETestFixture, "KDEMainInvalidMCBreakCoef",
+                "[KDEMainTest][BindingTests]")
 {
   arma::mat reference = arma::randu<arma::mat>(1, 10);
   arma::mat query = arma::randu<arma::mat>(1, 5);
@@ -509,15 +523,15 @@ BOOST_AUTO_TEST_CASE(KDEMainInvalidMCBreakCoef)
   Log::Fatal.ignoreInput = true;
   // Invalid under 0.
   SetInputParam("mc_break_coef", -0.5);
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
 
   // Valid between 0 and 1.
   SetInputParam("mc_break_coef", 0.3);
-  BOOST_REQUIRE_NO_THROW(mlpackMain());
+  REQUIRE_NOTHROW(mlpackMain());
 
   // Invalid greater than 1.
   SetInputParam("mc_break_coef", 1.1);
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
@@ -526,7 +540,8 @@ BOOST_AUTO_TEST_CASE(KDEMainInvalidMCBreakCoef)
   * Carlo estimations. Since this test has a random component, it might fail
   * (although it's unlikely).
  **/
-BOOST_AUTO_TEST_CASE(KDEMainMonteCarloFlag)
+TEST_CASE_METHOD(KDETestFixture, "KDEMainMonteCarloFlag",
+                "[KDEMainTest][BindingTests]")
 {
   // Datasets.
   arma::mat reference = arma::randu(1, 5000);
@@ -544,20 +559,18 @@ BOOST_AUTO_TEST_CASE(KDEMainMonteCarloFlag)
 
   // Compute estimations 1.
   mlpackMain();
-  estimations1 = std::move(CLI::GetParam<arma::vec>("predictions"));
+  estimations1 = std::move(IO::GetParam<arma::vec>("predictions"));
 
-  delete CLI::GetParam<KDEModel*>("output_model");
+  delete IO::GetParam<KDEModel*>("output_model");
 
   // Compute estimations 2.
   SetInputParam("reference", reference);
   SetInputParam("query", query);
   mlpackMain();
-  estimations2 = std::move(CLI::GetParam<arma::vec>("predictions"));
+  estimations2 = std::move(IO::GetParam<arma::vec>("predictions"));
 
   // Check whether results are equal.
   differences = arma::abs(estimations1 - estimations2);
   const double sumDifferences = arma::accu(differences);
-  BOOST_REQUIRE_GT(sumDifferences, 0);
+  REQUIRE(sumDifferences > 0);
 }
-
-BOOST_AUTO_TEST_SUITE_END();
