@@ -18,8 +18,8 @@ static const std::string testName = "PreprocessBinarize";
 #include <mlpack/methods/preprocess/preprocess_binarize_main.cpp>
 
 #include "test_helper.hpp"
-#include <boost/test/unit_test.hpp>
-#include "../test_tools.hpp"
+#include "../test_catch_tools.hpp"
+#include "../catch.hpp"
 
 using namespace mlpack;
 
@@ -29,24 +29,23 @@ struct PreprocessBinarizeTestFixture
   PreprocessBinarizeTestFixture()
   {
     // Cache in the options for this program.
-    CLI::RestoreSettings(testName);
+    IO::RestoreSettings(testName);
   }
 
   ~PreprocessBinarizeTestFixture()
   {
     // Clear the settings.
     bindings::tests::CleanMemory();
-    CLI::ClearSettings();
+    IO::ClearSettings();
   }
 };
 
-BOOST_FIXTURE_TEST_SUITE(PreprocessBinarizeMainTest,
-                         PreprocessBinarizeTestFixture);
-
 /**
  * Check that input and output have same dimensions.
  */
-BOOST_AUTO_TEST_CASE(PreprocessBinarizeDimensionTest)
+TEST_CASE_METHOD(
+    PreprocessBinarizeTestFixture, "PreprocessBinarizeDimensionTest",
+    "[PreprocessBinarizeMainTest][BindingTests]")
 {
   // Create a synthetic dataset.
   arma::mat inputData = arma::randu<arma::mat>(2, 5);
@@ -62,14 +61,16 @@ BOOST_AUTO_TEST_CASE(PreprocessBinarizeDimensionTest)
   mlpackMain();
 
   // Now check that the output has desired dimensions.
-  BOOST_REQUIRE_EQUAL(CLI::GetParam<arma::mat>("output").n_rows, 2);
-  BOOST_REQUIRE_EQUAL(CLI::GetParam<arma::mat>("output").n_cols, inputSize);
+  REQUIRE(IO::GetParam<arma::mat>("output").n_rows == 2);
+  REQUIRE(IO::GetParam<arma::mat>("output").n_cols == inputSize);
 }
 
 /**
  * Check that specified dimension is non-negative.
  */
-BOOST_AUTO_TEST_CASE(PreprocessBinarizeNegativeDimensionTest)
+TEST_CASE_METHOD(
+    PreprocessBinarizeTestFixture, "PreprocessBinarizeNegativeDimensionTest",
+    "[PreprocessBinarizeMainTest][BindingTests]")
 {
   arma::mat inputData = arma::randu<arma::mat>(2, 2);
 
@@ -78,14 +79,16 @@ BOOST_AUTO_TEST_CASE(PreprocessBinarizeNegativeDimensionTest)
   SetInputParam("dimension", (int) -2); // Invalid.
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
 /**
  * Check that we can't specify a dimension larger than input.
  */
-BOOST_AUTO_TEST_CASE(PreprocessBinarizelargerDimensionTest)
+TEST_CASE_METHOD(
+    PreprocessBinarizeTestFixture, "PreprocessBinarizelargerDimensionTest",
+    "[PreprocessBinarizeMainTest][BindingTests]")
 {
   arma::mat inputData = arma::randu<arma::mat>(2, 2);
 
@@ -94,14 +97,16 @@ BOOST_AUTO_TEST_CASE(PreprocessBinarizelargerDimensionTest)
   SetInputParam("dimension", (int) 6); // Invalid.
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
 /**
  * Check that binarization took place for the specified dimension.
  */
-BOOST_AUTO_TEST_CASE(PreprocessBinarizeVerificationTest)
+TEST_CASE_METHOD(
+    PreprocessBinarizeTestFixture, "PreprocessBinarizeVerificationTest",
+    "[PreprocessBinarizeMainTest][BindingTests]")
 {
   arma::mat inputData({{7.0, 4.0, 5.0}, {2.0, 5.0, 9.0}, {7.0, 3.0, 8.0}});
 
@@ -112,28 +117,30 @@ BOOST_AUTO_TEST_CASE(PreprocessBinarizeVerificationTest)
   mlpackMain();
 
   arma::mat output;
-  output = std::move(CLI::GetParam<arma::mat>("output"));
+  output = std::move(IO::GetParam<arma::mat>("output"));
 
   // All values dimension should remain unchanged.
-  BOOST_REQUIRE_CLOSE(output(0, 0), 7.0, 1e-5);
-  BOOST_REQUIRE_CLOSE(output(0, 1), 4.0, 1e-5);
-  BOOST_REQUIRE_CLOSE(output(0, 2), 5.0, 1e-5);
+  REQUIRE(output(0, 0) == Approx(7.0).epsilon(1e-7));
+  REQUIRE(output(0, 1) == Approx(4.0).epsilon(1e-7));
+  REQUIRE(output(0, 2) == Approx(5.0).epsilon(1e-7));
 
   // All values should be binarized according to the threshold.
-  BOOST_REQUIRE_SMALL(output(1, 0), 1e-5);
-  BOOST_REQUIRE_SMALL(output(1, 1), 1e-5);
-  BOOST_REQUIRE_CLOSE(output(1, 2), 1.0, 1e-5);
+  REQUIRE(output(1, 0) == Approx(0.0).margin(1e-5));
+  REQUIRE(output(1, 1) == Approx(0.0).margin(1e-5));
+  REQUIRE(output(1, 2) == Approx(1.0).epsilon(1e-7));
 
   // All values dimension should remain unchanged.
-  BOOST_REQUIRE_CLOSE(output(2, 0), 7.0, 1e-5);
-  BOOST_REQUIRE_CLOSE(output(2, 1), 3.0, 1e-5);
-  BOOST_REQUIRE_CLOSE(output(2, 2), 8.0, 1e-5);
+  REQUIRE(output(2, 0) == Approx(7.0).epsilon(1e-7));
+  REQUIRE(output(2, 1) == Approx(3.0).epsilon(1e-7));
+  REQUIRE(output(2, 2) == Approx(8.0).epsilon(1e-7));
 }
 
 /**
  * Check that all dimensions are binarized when dimension is not specified.
  */
-BOOST_AUTO_TEST_CASE(PreprocessBinarizeDimensionLessVerTest)
+TEST_CASE_METHOD(
+    PreprocessBinarizeTestFixture, "PreprocessBinarizeDimensionLessVerTest",
+    "[PreprocessBinarizeMainTest][BindingTests]")
 {
   arma::mat inputData({{7.0, 4.0, 5.0}, {2.0, 5.0, 9.0}, {7.0, 3.0, 8.0}});
 
@@ -143,18 +150,16 @@ BOOST_AUTO_TEST_CASE(PreprocessBinarizeDimensionLessVerTest)
   mlpackMain();
 
   arma::mat output;
-  output = std::move(CLI::GetParam<arma::mat>("output"));
+  output = std::move(IO::GetParam<arma::mat>("output"));
 
   // All values should be binarized according to the threshold.
-  BOOST_REQUIRE_CLOSE(output(0, 0), 1.0, 1e-5);
-  BOOST_REQUIRE_SMALL(output(0, 1), 1e-5);
-  BOOST_REQUIRE_SMALL(output(0, 2), 1e-5);
-  BOOST_REQUIRE_SMALL(output(1, 0), 1e-5);
-  BOOST_REQUIRE_SMALL(output(1, 1), 1e-5);
-  BOOST_REQUIRE_CLOSE(output(1, 2), 1.0, 1e-5);
-  BOOST_REQUIRE_CLOSE(output(2, 0), 1.0, 1e-5);
-  BOOST_REQUIRE_SMALL(output(2, 1), 1e-5);
-  BOOST_REQUIRE_CLOSE(output(2, 2), 1.0, 1e-5);
+  REQUIRE(output(0, 0) == Approx(1.0).epsilon(1e-7));
+  REQUIRE(output(0, 1) == Approx(0.0).margin(1e-5));
+  REQUIRE(output(0, 2) == Approx(0.0).margin(1e-5));
+  REQUIRE(output(1, 0) == Approx(0.0).margin(1e-5));
+  REQUIRE(output(1, 1) == Approx(0.0).margin(1e-5));
+  REQUIRE(output(1, 2) == Approx(1.0).epsilon(1e-7));
+  REQUIRE(output(2, 0) == Approx(1.0).epsilon(1e-7));
+  REQUIRE(output(2, 1) == Approx(0.0).margin(1e-5));
+  REQUIRE(output(2, 2) == Approx(1.0).epsilon(1e-7));
 }
-
-BOOST_AUTO_TEST_SUITE_END();
