@@ -18,8 +18,8 @@ static const std::string testName = "SoftmaxRegression";
 #include <mlpack/methods/softmax_regression/softmax_regression_main.cpp>
 #include "test_helper.hpp"
 
-#include <boost/test/unit_test.hpp>
-#include "../test_tools.hpp"
+#include "../test_catch_tools.hpp"
+#include "../catch.hpp"
 
 using namespace mlpack;
 
@@ -29,29 +29,29 @@ struct SoftmaxRegressionTestFixture
   SoftmaxRegressionTestFixture()
   {
     // Cache in the options for this program.
-    CLI::RestoreSettings(testName);
+    IO::RestoreSettings(testName);
   }
 
   ~SoftmaxRegressionTestFixture()
   {
     // Clear the settings.
     bindings::tests::CleanMemory();
-    CLI::ClearSettings();
+    IO::ClearSettings();
   }
 };
 
-BOOST_FIXTURE_TEST_SUITE(SoftmaxRegressionMainTest,
-                         SoftmaxRegressionTestFixture);
-
 /**
  * Ensure that we get desired dimensions when both training
  * data and labels are passed.
  */
-BOOST_AUTO_TEST_CASE(SoftmaxRegressionOutputDimensionTest)
+TEST_CASE_METHOD(
+    SoftmaxRegressionTestFixture,
+    "SoftmaxRegressionOutputDimensionTest",
+    "[SoftmaxRegressionMainTest][BindingsTest]")
 {
   arma::mat inputData;
   if (!data::Load("trainSet.csv", inputData))
-    BOOST_FAIL("Cannot load train dataset trainSet.csv!");
+    FAIL("Cannot load train dataset trainSet.csv!");
 
   // Get the labels out.
   arma::Row<size_t> labels(inputData.n_cols);
@@ -63,7 +63,7 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionOutputDimensionTest)
 
   arma::mat testData;
   if (!data::Load("testSet.csv", testData))
-    BOOST_FAIL("Cannot load test dataset testSet.csv!");
+    FAIL("Cannot load test dataset testSet.csv!");
 
   // Delete the last row containing labels from test dataset.
   testData.shed_row(testData.n_rows - 1);
@@ -80,39 +80,43 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionOutputDimensionTest)
   mlpackMain();
 
   // Check that number of output points are equal to number of input points.
-  BOOST_REQUIRE_EQUAL(CLI::GetParam<arma::Row<size_t>>("predictions").n_cols,
-                      testSize);
+  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_cols == testSize);
 
   // Check prediction have only single row.
-  BOOST_REQUIRE_EQUAL(CLI::GetParam<arma::Row<size_t>>("predictions").n_rows,
-                      1);
+  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_rows == 1);
 }
 
 /**
  * Ensure that labels are necessarily passed when training.
  */
-BOOST_AUTO_TEST_CASE(SoftmaxRegressionLabelsLessDimensionTest)
+TEST_CASE_METHOD(
+    SoftmaxRegressionTestFixture,
+    "SoftmaxRegressionLabelsLessDimensionTest",
+    "[SoftmaxRegressionMainTest][BindingsTest]")
 {
   arma::mat inputData;
   if (!data::Load("trainSet.csv", inputData))
-    BOOST_FAIL("Cannot load train dataset trainSet.csv!");
+    FAIL("Cannot load train dataset trainSet.csv!");
 
   // Input training data.
   SetInputParam("training", std::move(inputData));
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
 /**
  * Ensure that saved model can be used again.
  */
-BOOST_AUTO_TEST_CASE(SoftmaxRegressionModelReuseTest)
+TEST_CASE_METHOD(
+    SoftmaxRegressionTestFixture,
+    "SoftmaxRegressionModelReuseTest",
+    "[SoftmaxRegressionMainTest][BindingsTest]")
 {
   arma::mat inputData;
   if (!data::Load("trainSet.csv", inputData))
-    BOOST_FAIL("Cannot load train dataset trainSet.csv!");
+    FAIL("Cannot load train dataset trainSet.csv!");
 
   // Get the labels out.
   arma::Row<size_t> labels(inputData.n_cols);
@@ -124,7 +128,7 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionModelReuseTest)
 
   arma::mat testData;
   if (!data::Load("testSet.csv", testData))
-    BOOST_FAIL("Cannot load test dataset testSet.csv!");
+    FAIL("Cannot load test dataset testSet.csv!");
 
   // Delete the last row containing labels from test dataset.
   testData.shed_row(testData.n_rows - 1);
@@ -141,41 +145,41 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionModelReuseTest)
   mlpackMain();
 
   arma::Row<size_t> predictions;
-  predictions = std::move(CLI::GetParam<arma::Row<size_t>>("predictions"));
+  predictions = std::move(IO::GetParam<arma::Row<size_t>>("predictions"));
 
   // Reset passed parameters.
-  CLI::GetSingleton().Parameters()["training"].wasPassed = false;
-  CLI::GetSingleton().Parameters()["labels"].wasPassed = false;
-  CLI::GetSingleton().Parameters()["test"].wasPassed = false;
+  IO::GetSingleton().Parameters()["training"].wasPassed = false;
+  IO::GetSingleton().Parameters()["labels"].wasPassed = false;
+  IO::GetSingleton().Parameters()["test"].wasPassed = false;
 
   // Input trained model.
   SetInputParam("test", std::move(testData));
   SetInputParam("input_model",
-                CLI::GetParam<SoftmaxRegression*>("output_model"));
+                IO::GetParam<SoftmaxRegression*>("output_model"));
 
   mlpackMain();
 
   // Check that number of output points are equal to number of input points.
-  BOOST_REQUIRE_EQUAL(CLI::GetParam<arma::Row<size_t>>("predictions").n_cols,
-                      testSize);
+  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_cols == testSize);
 
   // Check predictions have only single row.
-  BOOST_REQUIRE_EQUAL(CLI::GetParam<arma::Row<size_t>>("predictions").n_rows,
-                      1);
+  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_rows == 1);
 
   // Check that initial predictions and final predicitons matrix
   // using saved model are same.
-  CheckMatrices(predictions, CLI::GetParam<arma::Row<size_t>>("predictions"));
+  CheckMatrices(predictions, IO::GetParam<arma::Row<size_t>>("predictions"));
 }
 
 /**
  * Ensure that max_iterations is always non-negative.
  */
-BOOST_AUTO_TEST_CASE(SoftmaxRegressionMaxItrTest)
+TEST_CASE_METHOD(
+    SoftmaxRegressionTestFixture,
+    "SoftmaxRegressionMaxItrTest", "[SoftmaxRegressionMainTest][BindingsTest]")
 {
   arma::mat inputData;
   if (!data::Load("trainSet.csv", inputData))
-    BOOST_FAIL("Cannot load train dataset trainSet.csv!");
+    FAIL("Cannot load train dataset trainSet.csv!");
 
   // Get the labels out.
   arma::Row<size_t> labels(inputData.n_cols);
@@ -191,18 +195,20 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionMaxItrTest)
   SetInputParam("max_iterations", (int) -1);
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
 /**
  * Ensure that lambda is always non-negative.
  */
-BOOST_AUTO_TEST_CASE(SoftmaxRegressionLambdaTest)
+TEST_CASE_METHOD(
+    SoftmaxRegressionTestFixture,
+    "SoftmaxRegressionLambdaTest", "[SoftmaxRegressionMainTest][BindingsTest]")
 {
   arma::mat inputData;
   if (!data::Load("trainSet.csv", inputData))
-    BOOST_FAIL("Cannot load train dataset trainSet.csv!");
+    FAIL("Cannot load train dataset trainSet.csv!");
 
   // Get the labels out.
   arma::Row<size_t> labels(inputData.n_cols);
@@ -218,18 +224,21 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionLambdaTest)
   SetInputParam("lambda", (double) -0.1);
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
 /**
  * Ensure that number_of_classes is always positive.
  */
-BOOST_AUTO_TEST_CASE(SoftmaxRegressionNumClassesTest)
+TEST_CASE_METHOD(
+    SoftmaxRegressionTestFixture,
+    "SoftmaxRegressionNumClassesTest",
+    "[SoftmaxRegressionMainTest][BindingsTest]")
 {
   arma::mat inputData;
   if (!data::Load("trainSet.csv", inputData))
-    BOOST_FAIL("Cannot load train dataset trainSet.csv!");
+    FAIL("Cannot load train dataset trainSet.csv!");
 
   // Get the labels out.
   arma::Row<size_t> labels(inputData.n_cols);
@@ -245,18 +254,21 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionNumClassesTest)
   SetInputParam("number_of_classes", (int) -1);
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
 /**
  * Make sure only one of training data or pre-trained model is passed.
  */
-BOOST_AUTO_TEST_CASE(SoftmaxRegressionTrainingVerTest)
+TEST_CASE_METHOD(
+    SoftmaxRegressionTestFixture,
+    "SoftmaxRegressionTrainingVerTest",
+    "[SoftmaxRegressionMainTest][BindingsTest]")
 {
   arma::mat inputData;
   if (!data::Load("trainSet.csv", inputData))
-    BOOST_FAIL("Cannot load train dataset trainSet.csv!");
+    FAIL("Cannot load train dataset trainSet.csv!");
 
   // Get the labels out.
   arma::Row<size_t> labels(inputData.n_cols);
@@ -274,10 +286,10 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionTrainingVerTest)
 
   // Input pre-trained model.
   SetInputParam("input_model",
-                CLI::GetParam<SoftmaxRegression*>("output_model"));
+                IO::GetParam<SoftmaxRegression*>("output_model"));
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
+  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
@@ -285,12 +297,15 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionTrainingVerTest)
  * Check that output object parameters are
  * different for different lambda values.
  */
-BOOST_AUTO_TEST_CASE(SoftmaxRegressionDiffLambdaTest)
+TEST_CASE_METHOD(
+    SoftmaxRegressionTestFixture,
+    "SoftmaxRegressionDiffLambdaTest",
+    "[SoftmaxRegressionMainTest][BindingsTest]")
 {
   // Train SR for lambda 0.1.
   arma::mat inputData;
   if (!data::Load("trainSet.csv", inputData))
-    BOOST_FAIL("Cannot load train dataset trainSet.csv!");
+    FAIL("Cannot load train dataset trainSet.csv!");
 
   // Get the labels out.
   arma::Row<size_t> labels(inputData.n_cols);
@@ -302,7 +317,7 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionDiffLambdaTest)
 
   arma::mat testData;
   if (!data::Load("testSet.csv", testData))
-    BOOST_FAIL("Cannot load test dataset testSet.csv!");
+    FAIL("Cannot load test dataset testSet.csv!");
 
   // Delete the last row containing labels from test dataset.
   testData.shed_row(testData.n_rows - 1);
@@ -319,14 +334,14 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionDiffLambdaTest)
 
   // Store output parameters.
   arma::mat modelParam;
-  modelParam = CLI::GetParam<SoftmaxRegression*>("output_model")->Parameters();
+  modelParam = IO::GetParam<SoftmaxRegression*>("output_model")->Parameters();
 
   bindings::tests::CleanMemory();
 
   // Reset passed parameters.
-  CLI::GetSingleton().Parameters()["training"].wasPassed = false;
-  CLI::GetSingleton().Parameters()["labels"].wasPassed = false;
-  CLI::GetSingleton().Parameters()["test"].wasPassed = false;
+  IO::GetSingleton().Parameters()["training"].wasPassed = false;
+  IO::GetSingleton().Parameters()["labels"].wasPassed = false;
+  IO::GetSingleton().Parameters()["test"].wasPassed = false;
 
   // Train SR for lamda 0.9.
 
@@ -342,8 +357,8 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionDiffLambdaTest)
   // using saved model are different.
   for (size_t i = 0; i < modelParam.n_elem; ++i)
   {
-    BOOST_REQUIRE_NE(modelParam[i],
-        CLI::GetParam<SoftmaxRegression*>("output_model")->Parameters()[i]);
+    REQUIRE(modelParam[i] !=
+        IO::GetParam<SoftmaxRegression*>("output_model")->Parameters()[i]);
   }
 }
 
@@ -351,12 +366,15 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionDiffLambdaTest)
  * Check that output object parameters are different for different numbers of
  * max_iterations.
  */
-BOOST_AUTO_TEST_CASE(SoftmaxRegressionDiffMaxItrTest)
+TEST_CASE_METHOD(
+    SoftmaxRegressionTestFixture,
+    "SoftmaxRegressionDiffMaxItrTest",
+    "[SoftmaxRegressionMainTest][BindingsTest]")
 {
   // Train SR for lambda 0.1.
   arma::mat inputData;
   if (!data::Load("trainSet.csv", inputData))
-    BOOST_FAIL("Cannot load train dataset trainSet.csv!");
+    FAIL("Cannot load train dataset trainSet.csv!");
 
   // Get the labels out.
   arma::Row<size_t> labels(inputData.n_cols);
@@ -368,7 +386,7 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionDiffMaxItrTest)
 
   arma::mat testData;
   if (!data::Load("testSet.csv", testData))
-    BOOST_FAIL("Cannot load test dataset testSet.csv!");
+    FAIL("Cannot load test dataset testSet.csv!");
 
   // Delete the last row containing labels from test dataset.
   testData.shed_row(testData.n_rows - 1);
@@ -385,14 +403,14 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionDiffMaxItrTest)
 
   // Store output parameters.
   arma::mat modelParam;
-  modelParam = CLI::GetParam<SoftmaxRegression*>("output_model")->Parameters();
+  modelParam = IO::GetParam<SoftmaxRegression*>("output_model")->Parameters();
 
   bindings::tests::CleanMemory();
 
   // Reset passed parameters.
-  CLI::GetSingleton().Parameters()["training"].wasPassed = false;
-  CLI::GetSingleton().Parameters()["labels"].wasPassed = false;
-  CLI::GetSingleton().Parameters()["test"].wasPassed = false;
+  IO::GetSingleton().Parameters()["training"].wasPassed = false;
+  IO::GetSingleton().Parameters()["labels"].wasPassed = false;
+  IO::GetSingleton().Parameters()["test"].wasPassed = false;
 
   // Train SR for lamda 0.9.
 
@@ -408,8 +426,8 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionDiffMaxItrTest)
   // using saved model are different.
   for (size_t i = 0; i < modelParam.n_elem; ++i)
   {
-    BOOST_REQUIRE_NE(modelParam[i],
-        CLI::GetParam<SoftmaxRegression*>("output_model")->Parameters()[i]);
+    REQUIRE(modelParam[i] !=
+        IO::GetParam<SoftmaxRegression*>("output_model")->Parameters()[i]);
   }
 }
 
@@ -417,12 +435,15 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionDiffMaxItrTest)
  * Check that output object parameter for no_intercept
  * term is one less than with intercept term.
  */
-BOOST_AUTO_TEST_CASE(SoftmaxRegressionDiffInterceptTest)
+TEST_CASE_METHOD(
+    SoftmaxRegressionTestFixture,
+    "SoftmaxRegressionDiffInterceptTest",
+    "[SoftmaxRegressionMainTest][BindingsTest]")
 {
   // Train SR with intercept.
   arma::mat inputData;
   if (!data::Load("trainSet.csv", inputData))
-    BOOST_FAIL("Cannot load train dataset trainSet.csv!");
+    FAIL("Cannot load train dataset trainSet.csv!");
 
   // Get the labels out.
   arma::Row<size_t> labels(inputData.n_cols);
@@ -434,7 +455,7 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionDiffInterceptTest)
 
   arma::mat testData;
   if (!data::Load("testSet.csv", testData))
-    BOOST_FAIL("Cannot load test dataset testSet.csv!");
+    FAIL("Cannot load test dataset testSet.csv!");
 
   // Delete the last row containing labels from test dataset.
   testData.shed_row(testData.n_rows - 1);
@@ -451,15 +472,15 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionDiffInterceptTest)
 
   // Store output parameters.
   arma::mat modelParam;
-  modelParam = CLI::GetParam<SoftmaxRegression*>("output_model")->Parameters();
+  modelParam = IO::GetParam<SoftmaxRegression*>("output_model")->Parameters();
 
   bindings::tests::CleanMemory();
 
   // Reset passed parameters.
-  CLI::GetSingleton().Parameters()["training"].wasPassed = false;
-  CLI::GetSingleton().Parameters()["labels"].wasPassed = false;
-  CLI::GetSingleton().Parameters()["no_intercept"].wasPassed = false;
-  CLI::GetSingleton().Parameters()["test"].wasPassed = false;
+  IO::GetSingleton().Parameters()["training"].wasPassed = false;
+  IO::GetSingleton().Parameters()["labels"].wasPassed = false;
+  IO::GetSingleton().Parameters()["no_intercept"].wasPassed = false;
+  IO::GetSingleton().Parameters()["test"].wasPassed = false;
 
   // Train SR for no_intercept.
 
@@ -472,9 +493,7 @@ BOOST_AUTO_TEST_CASE(SoftmaxRegressionDiffInterceptTest)
 
   // Check that initial parameters has 1 more parameter than
   // final parameters matrix.
-  BOOST_REQUIRE_EQUAL(
-      CLI::GetParam<SoftmaxRegression*>("output_model")->Parameters().n_cols,
+  REQUIRE(
+      IO::GetParam<SoftmaxRegression*>("output_model")->Parameters().n_cols ==
       modelParam.n_cols + 1);
 }
-
-BOOST_AUTO_TEST_SUITE_END();
