@@ -11,17 +11,14 @@
  */
 #include <mlpack/core.hpp>
 #include <mlpack/methods/radical/radical.hpp>
-#include <boost/test/unit_test.hpp>
-#include "test_tools.hpp"
-
-BOOST_AUTO_TEST_SUITE(RadicalTest);
+#include "catch.hpp"
 
 using namespace mlpack;
 using namespace mlpack::radical;
 using namespace std;
 using namespace arma;
 
-BOOST_AUTO_TEST_CASE(Radical_Test_Radical3D)
+TEST_CASE("Radical_Test_Radical3D", "[RadicalTest]")
 {
   mat matX;
   data::Load("data_3d_mixed.txt", matX);
@@ -35,7 +32,7 @@ BOOST_AUTO_TEST_CASE(Radical_Test_Radical3D)
   mat matYT = trans(matY);
   double valEst = 0;
 
-  for (uword i = 0; i < matYT.n_cols; i++)
+  for (uword i = 0; i < matYT.n_cols; ++i)
   {
     vec y = vec(matYT.col(i));
     valEst += rad.Vasicek(y);
@@ -48,14 +45,12 @@ BOOST_AUTO_TEST_CASE(Radical_Test_Radical3D)
   matYT = trans(matY);
   double valBest = 0;
 
-  for (uword i = 0; i < matYT.n_cols; i++)
+  for (uword i = 0; i < matYT.n_cols; ++i)
   {
     vec y = vec(matYT.col(i));
     valBest += rad.Vasicek(y);
   }
 
   // Larger tolerance is sometimes needed.
-  BOOST_REQUIRE_CLOSE(valBest, valEst, 2.0);
+  REQUIRE(valBest == Approx(valEst).epsilon(0.02));
 }
-
-BOOST_AUTO_TEST_SUITE_END();
