@@ -13,10 +13,7 @@
 #include <mlpack/core.hpp>
 #include <mlpack/methods/randomized_svd/randomized_svd.hpp>
 
-#include <boost/test/unit_test.hpp>
-#include "test_tools.hpp"
-
-BOOST_AUTO_TEST_SUITE(RandomizedSVDTest);
+#include "catch.hpp"
 
 using namespace mlpack;
 
@@ -24,7 +21,7 @@ using namespace mlpack;
  * The reconstruction and sigular value error of the obtained SVD should be
  * small.
  */
-BOOST_AUTO_TEST_CASE(RandomizedSVDReconstructionError)
+TEST_CASE("RandomizedSVDReconstructionError", "[RandomizedSVDTest]")
 {
   arma::mat U = arma::randn<arma::mat>(3, 20);
   arma::mat V = arma::randn<arma::mat>(10, 3);
@@ -54,14 +51,12 @@ BOOST_AUTO_TEST_CASE(RandomizedSVDReconstructionError)
 
   // The sigular value error should be small.
   double error = arma::norm(s2 - s3, "frob") / arma::norm(s2, "frob");
-  BOOST_REQUIRE_SMALL(error, 1e-5);
+  REQUIRE(error == Approx(0.0).margin(1e-5));
 
   arma::mat reconstruct = U2 * arma::diagmat(s2) * V2.t();
 
   // The relative reconstruction error should be small.
   error = arma::norm(centeredData - reconstruct, "frob") /
       arma::norm(centeredData, "frob");
-  BOOST_REQUIRE_SMALL(error, 1e-5);
+  REQUIRE(error == Approx(0.0).margin(1e-5));
 }
-
-BOOST_AUTO_TEST_SUITE_END();
