@@ -23,19 +23,17 @@
 #include <mlpack/methods/reinforcement_learning/replay/random_replay.hpp>
 #include <mlpack/methods/reinforcement_learning/policy/greedy_policy.hpp>
 
-#include <boost/test/unit_test.hpp>
-#include "test_tools.hpp"
+#include "catch.hpp"
+#include "test_catch_tools.hpp"
 
 using namespace mlpack;
 using namespace mlpack::rl;
 
-BOOST_AUTO_TEST_SUITE(RLComponentsTest)
-
 /**
  * Constructs a Pendulum instance and check if the main routine works as it
  * should be working.
  */
-BOOST_AUTO_TEST_CASE(SimplePendulumTest)
+TEST_CASE("SimplePendulumTest", "[RLComponentsTest]")
 {
   Pendulum task = Pendulum();
   task.MaxSteps() = 20;
@@ -45,7 +43,7 @@ BOOST_AUTO_TEST_CASE(SimplePendulumTest)
   action.action[0] = math::Random(-2.0, 2.0);
   double reward, minReward = 0.0;
 
-  BOOST_REQUIRE(!task.IsTerminal(state));
+  REQUIRE(!task.IsTerminal(state));
 
   while (!task.IsTerminal(state))
   {
@@ -54,22 +52,22 @@ BOOST_AUTO_TEST_CASE(SimplePendulumTest)
   }
 
   // The reward is always negative. Check if not lower than lowest possible.
-  BOOST_REQUIRE(minReward >= -(pow(M_PI, 2) + 6.404));
+  REQUIRE(minReward >= -(pow(M_PI, 2) + 6.404));
 
   // Check if the number of steps performed is less or equal as the maximum
   // allowed, since we use a random action there is no guarantee that we will
   // reach the maximum number of steps.
-  BOOST_REQUIRE_LE(task.StepsPerformed(), 20);
+  REQUIRE(task.StepsPerformed() <= 20);
 
   // The action is simply the torque. Check if dimension is 1.
-  BOOST_REQUIRE_EQUAL(1, action.size);
+  REQUIRE(1 == static_cast<size_t>(Pendulum::Action::size));
 }
 
 /**
  * Constructs a Continuous MountainCar instance and check if the main rountine
  * works as it should be.
  */
-BOOST_AUTO_TEST_CASE(SimpleContinuousMountainCarTest)
+TEST_CASE("SimpleContinuousMountainCarTest", "[RLComponentsTest]")
 {
   ContinuousMountainCar task = ContinuousMountainCar();
   task.MaxSteps() = 5;
@@ -79,125 +77,129 @@ BOOST_AUTO_TEST_CASE(SimpleContinuousMountainCarTest)
   action.action[0] = math::Random(-1.0, 1.0);
   double reward = task.Sample(state, action);
   // Maximum reward possible is 100.
-  BOOST_REQUIRE(reward <= 100.0);
-  BOOST_REQUIRE(!task.IsTerminal(state));
+  REQUIRE(reward <= 100.0);
+  REQUIRE(!task.IsTerminal(state));
 
   while (!task.IsTerminal(state))
     task.Sample(state, action, state);
 
   // Check if the number of steps performed is the same as the maximum allowed.
-  BOOST_REQUIRE_EQUAL(task.StepsPerformed(), 5);
+  REQUIRE(task.StepsPerformed() == 5);
 
   // Check if the size of the action space is 1.
-  BOOST_REQUIRE_EQUAL(1, action.size);
+  REQUIRE(1 == action.size);
 }
 
 /**
  * Constructs a Acrobot instance and check if the main rountine works as
  * it should be.
  */
-BOOST_AUTO_TEST_CASE(SimpleAcrobotTest)
+TEST_CASE("SimpleAcrobotTest", "[RLComponentsTest]")
 {
   Acrobot task = Acrobot();
   task.MaxSteps() = 5;
 
   Acrobot::State state = task.InitialSample();
-  Acrobot::Action action = Acrobot::Action::negativeTorque;
+  Acrobot::Action action;
+  action.action = Acrobot::Action::actions::negativeTorque;
   double reward = task.Sample(state, action);
 
-  BOOST_REQUIRE_EQUAL(reward, -1.0);
-  BOOST_REQUIRE(!task.IsTerminal(state));
+  REQUIRE(reward == -1.0);
+  REQUIRE(!task.IsTerminal(state));
 
   while (!task.IsTerminal(state))
     task.Sample(state, action, state);
 
   // Check if the number of steps performed is the same as the maximum allowed.
-  BOOST_REQUIRE_EQUAL(task.StepsPerformed(), 5);
+  REQUIRE(task.StepsPerformed() == 5);
 
   // Check if the size of the action space is 3.
-  BOOST_REQUIRE_EQUAL(3, Acrobot::Action::size);
+  REQUIRE(3 == static_cast<size_t>(Acrobot::Action::size));
 }
 
 /**
  * Constructs a MountainCar instance and check if the main rountine works as
  * it should be.
  */
-BOOST_AUTO_TEST_CASE(SimpleMountainCarTest)
+TEST_CASE("SimpleMountainCarTest", "[RLComponentsTest]")
 {
   MountainCar task = MountainCar();
   task.MaxSteps() = 5;
 
   MountainCar::State state = task.InitialSample();
-  MountainCar::Action action = MountainCar::Action::backward;
+  MountainCar::Action action;
+  action.action = MountainCar::Action::actions::backward;
   double reward = task.Sample(state, action);
 
-  BOOST_REQUIRE_EQUAL(reward, -1.0);
-  BOOST_REQUIRE(!task.IsTerminal(state));
+  REQUIRE(reward == -1.0);
+  REQUIRE(!task.IsTerminal(state));
 
   while (!task.IsTerminal(state))
     task.Sample(state, action, state);
 
   // Check if the number of steps performed is the same as the maximum allowed.
-  BOOST_REQUIRE_EQUAL(task.StepsPerformed(), 5);
+  REQUIRE(task.StepsPerformed() == 5);
 
   // Check if the size of the action space is 3.
-  BOOST_REQUIRE_EQUAL(3, MountainCar::Action::size);
+  REQUIRE(3 == static_cast<size_t>(MountainCar::Action::size));
 }
 
 /**
  * Constructs a CartPole instance and check if the main routine works as
  * it should be.
  */
-BOOST_AUTO_TEST_CASE(SimpleCartPoleTest)
+TEST_CASE("SimpleCartPoleTest", "[RLComponentsTest]")
 {
   CartPole task = CartPole();
   task.MaxSteps() = 5;
 
   CartPole::State state = task.InitialSample();
-  CartPole::Action action = CartPole::Action::backward;
+  CartPole::Action action;
+  action.action = CartPole::Action::actions::backward;
   double reward = task.Sample(state, action);
 
-  BOOST_REQUIRE_EQUAL(reward, 1.0);
-  BOOST_REQUIRE(!task.IsTerminal(state));
+  REQUIRE(reward == 1.0);
+  REQUIRE(!task.IsTerminal(state));
 
   while (!task.IsTerminal(state))
     task.Sample(state, action, state);
 
   // Check if the number of steps performed is the same as the maximum allowed.
-  BOOST_REQUIRE_EQUAL(task.StepsPerformed(), 5);
+  REQUIRE(task.StepsPerformed() == 5);
 
-  BOOST_REQUIRE_EQUAL(2, CartPole::Action::size);
+  REQUIRE(2 == static_cast<size_t>(CartPole::Action::size));
 }
 
 /**
  * Constructs a DoublePoleCart instance and check if the main routine works as
  * it should be.
  */
-BOOST_AUTO_TEST_CASE(DoublePoleCartTest)
+TEST_CASE("DoublePoleCartTest", "[RLComponentsTest]")
 {
   DoublePoleCart task = DoublePoleCart();
   task.MaxSteps() = 5;
 
   DoublePoleCart::State state = task.InitialSample();
-  DoublePoleCart::Action action = DoublePoleCart::Action::backward;
+  DoublePoleCart::Action action;
+  action.action = DoublePoleCart::Action::actions::backward;
   double reward = task.Sample(state, action);
 
-  BOOST_REQUIRE_EQUAL(reward, 1.0);
-  BOOST_REQUIRE(!task.IsTerminal(state));
+  REQUIRE(reward == 1.0);
+  REQUIRE(!task.IsTerminal(state));
 
   while (!task.IsTerminal(state))
     task.Sample(state, action, state);
 
   // Check if the number of steps performed is the same as the maximum allowed.
-  BOOST_REQUIRE_EQUAL(task.StepsPerformed(), 5);
-  BOOST_REQUIRE_EQUAL(2, DoublePoleCart::Action::size);
+  REQUIRE(task.StepsPerformed() == 5);
+  REQUIRE(2 == static_cast<size_t>(DoublePoleCart::Action::size));
 }
 
 /**
  * Constructs a ContinuousDoublePoleCart instance and check if the main 
  * routine works as it should be.
  */
-BOOST_AUTO_TEST_CASE(ContinuousDoublePoleCartTest)
+TEST_CASE("ContinuousDoublePoleCartTest", "[RLComponentsTest]")
 {
   ContinuousDoublePoleCart task = ContinuousDoublePoleCart();
   task.MaxSteps() = 5;
@@ -207,52 +209,55 @@ BOOST_AUTO_TEST_CASE(ContinuousDoublePoleCartTest)
   action.action[0] = math::Random(-1.0, 1.0);
   double reward = task.Sample(state, action);
 
-  BOOST_REQUIRE_EQUAL(reward, 1.0);
-  BOOST_REQUIRE(!task.IsTerminal(state));
+  REQUIRE(reward == 1.0);
+  REQUIRE(!task.IsTerminal(state));
 
   while (!task.IsTerminal(state))
     task.Sample(state, action, state);
 
   // Check if the number of steps performed is the same as the maximum allowed.
-  BOOST_REQUIRE_EQUAL(task.StepsPerformed(), 5);
-  BOOST_REQUIRE_EQUAL(1, action.size);
+  REQUIRE(task.StepsPerformed() == 5);
+  REQUIRE(1 == action.size);
 }
 
 /**
  * Construct a random replay instance and check if it works as
  * it should be.
  */
-BOOST_AUTO_TEST_CASE(RandomReplayTest)
+TEST_CASE("RandomReplayTest", "[RLComponentsTest]")
 {
   RandomReplay<MountainCar> replay(1, 3);
   MountainCar env;
   MountainCar::State state = env.InitialSample();
-  MountainCar::Action action = MountainCar::Action::forward;
+  MountainCar::Action action;
+  action.action = MountainCar::Action::actions::forward;
   MountainCar::State nextState;
   double reward = env.Sample(state, action, nextState);
-  replay.Store(state, action, reward, nextState, env.IsTerminal(nextState));
+  replay.Store(state, action, reward, nextState, env.IsTerminal(nextState),
+      0.9);
   arma::mat sampledState;
-  arma::icolvec sampledAction;
-  arma::colvec sampledReward;
+  std::vector<MountainCar::Action> sampledAction;
+  arma::rowvec sampledReward;
   arma::mat sampledNextState;
-  arma::icolvec sampledTerminal;
+  arma::irowvec sampledTerminal;
 
   //! So far there should be only one record in the memory
   replay.Sample(sampledState, sampledAction, sampledReward, sampledNextState,
       sampledTerminal);
 
   CheckMatrices(state.Encode(), sampledState);
-  BOOST_REQUIRE_EQUAL(action, arma::as_scalar(sampledAction));
-  BOOST_REQUIRE_CLOSE(reward, arma::as_scalar(sampledReward), 1e-5);
+  REQUIRE(sampledAction.size() == 1);
+  REQUIRE(action.action == sampledAction[0].action);
+  REQUIRE(reward == Approx(arma::as_scalar(sampledReward)).epsilon(1e-7));
   CheckMatrices(nextState.Encode(), sampledNextState);
-  BOOST_REQUIRE_EQUAL(false, arma::as_scalar(sampledTerminal));
-  BOOST_REQUIRE_EQUAL(1, replay.Size());
+  REQUIRE(false == arma::as_scalar(sampledTerminal));
+  REQUIRE(1 == replay.Size());
 
   //! Overwrite the memory with a nonsense record
   for (size_t i = 0; i < 5; ++i)
-    replay.Store(nextState, action, reward, state, true);
+    replay.Store(nextState, action, reward, state, true, 0.9);
 
-  BOOST_REQUIRE_EQUAL(3, replay.Size());
+  REQUIRE(3 == replay.Size());
 
   //! Sample several times, the original record shouldn't appear
   for (size_t i = 0; i < 30; ++i)
@@ -262,7 +267,7 @@ BOOST_AUTO_TEST_CASE(RandomReplayTest)
 
     CheckMatrices(state.Encode(), sampledNextState);
     CheckMatrices(nextState.Encode(), sampledState);
-    BOOST_REQUIRE_EQUAL(true, arma::as_scalar(sampledTerminal));
+    REQUIRE(true == arma::as_scalar(sampledTerminal));
   }
 }
 
@@ -270,15 +275,15 @@ BOOST_AUTO_TEST_CASE(RandomReplayTest)
  * Construct a greedy policy instance and check if it works as
  * it should be.
  */
-BOOST_AUTO_TEST_CASE(GreedyPolicyTest)
+TEST_CASE("GreedyPolicyTest", "[RLComponentsTest]")
 {
   GreedyPolicy<CartPole> policy(1.0, 10, 0.0, 0.99);
   for (size_t i = 0; i < 15; ++i)
     policy.Anneal();
-  BOOST_REQUIRE_CLOSE(0.0, policy.Epsilon(), 1e-5);
+  REQUIRE(0.0 == Approx(policy.Epsilon()).epsilon(1e-7));
   arma::colvec actionValue = arma::randn<arma::colvec>(CartPole::Action::size);
   CartPole::Action action = policy.Sample(actionValue);
-  BOOST_REQUIRE_CLOSE(actionValue[action], actionValue.max(), 1e-5);
-}
+  REQUIRE(actionValue[action.action] ==
+      Approx(actionValue.max()).epsilon(1e-7));
 
-BOOST_AUTO_TEST_SUITE_END()
+}
