@@ -12,15 +12,13 @@
 #include <mlpack/core.hpp>
 #include <mlpack/core/data/split_data.hpp>
 
-#include <boost/test/unit_test.hpp>
-#include "test_tools.hpp"
+#include "test_catch_tools.hpp"
+#include "catch.hpp"
 
 using namespace mlpack;
 using namespace arma;
 using namespace mlpack::data;
 
-BOOST_AUTO_TEST_SUITE(SplitDataTest);
-
 /**
  * Compare the data after train test split.  This assumes that the labels
  * correspond to each column, so that we can easily check each point against its
@@ -42,9 +40,9 @@ void CompareData(const mat& inputData,
     for (size_t j = 0; j != lhsCol.n_rows; ++j)
     {
       if (std::abs(rhsCol(j)) < 1e-5)
-        BOOST_REQUIRE_SMALL(lhsCol(j), 1e-5);
+        REQUIRE(lhsCol(j) == Approx(0.0).margin(1e-5));
       else
-        BOOST_REQUIRE_CLOSE(lhsCol(j), rhsCol(j), 1e-5);
+        REQUIRE(lhsCol(j) == Approx(rhsCol(j)).epsilon(1e-7));
     }
   }
 }
@@ -61,9 +59,9 @@ void CheckMatEqual(const mat& inputData,
     for (size_t j = 0; j < lhsCol.n_rows; ++j)
     {
       if (std::abs(rhsCol(j)) < 1e-5)
-        BOOST_REQUIRE_SMALL(lhsCol(j), 1e-5);
+        REQUIRE(lhsCol(j) == Approx(0.0).margin(1e-5));
       else
-        BOOST_REQUIRE_CLOSE(lhsCol(j), rhsCol(j), 1e-5);
+        REQUIRE(lhsCol(j) == Approx(rhsCol(j)).epsilon(1e-7));
     }
   }
 }
@@ -80,80 +78,80 @@ void CheckDuplication(const Row<size_t>& trainLabels,
 
   for (size_t i = 0; i < trainLabels.n_elem; ++i)
   {
-    BOOST_REQUIRE_LT(trainLabels[i], counts.n_elem);
+    REQUIRE(trainLabels[i] < counts.n_elem);
     counts[trainLabels[i]]++;
   }
   for (size_t i = 0; i < testLabels.n_elem; ++i)
   {
-    BOOST_REQUIRE_LT(testLabels[i], counts.n_elem);
+    REQUIRE(testLabels[i] < counts.n_elem);
     counts[testLabels[i]]++;
   }
 
   // Now make sure each point has been used once.
   for (size_t i = 0; i < counts.n_elem; ++i)
-    BOOST_REQUIRE_EQUAL(counts[i], 1);
+    REQUIRE(counts[i] == 1);
 }
 
-BOOST_AUTO_TEST_CASE(SplitShuffleDataResultMat)
+TEST_CASE("SplitShuffleDataResultMat", "[SplitDataTest]")
 {
   mat input(2, 10);
   size_t count = 0; // Counter for unique sequential values.
   input.imbue([&count] () { return ++count; });
 
   const auto value = Split(input, 0.2);
-  BOOST_REQUIRE_EQUAL(std::get<0>(value).n_cols, 8); // Train data.
-  BOOST_REQUIRE_EQUAL(std::get<1>(value).n_cols, 2); // Test data.
+  REQUIRE(std::get<0>(value).n_cols == 8); // Train data.
+  REQUIRE(std::get<1>(value).n_cols == 2); // Test data.
 
   mat concat = arma::join_rows(std::get<0>(value), std::get<1>(value));
   CheckMatEqual(input, concat);
 }
 
-BOOST_AUTO_TEST_CASE(SplitDataResultMat)
+TEST_CASE("SplitDataResultMat", "[SplitDataTest]")
 {
   mat input(2, 10);
   size_t count = 0; // Counter for unique sequential values.
   input.imbue([&count] () { return ++count; });
 
   const auto value = Split(input, 0.2, false);
-  BOOST_REQUIRE_EQUAL(std::get<0>(value).n_cols, 8); // Train data.
-  BOOST_REQUIRE_EQUAL(std::get<1>(value).n_cols, 2); // Test data.
+  REQUIRE(std::get<0>(value).n_cols == 8); // Train data.
+  REQUIRE(std::get<1>(value).n_cols == 2); // Test data.
 
   mat concat = arma::join_rows(std::get<0>(value), std::get<1>(value));
   // Order matters here.
   CheckMatrices(input, concat);
 }
 
-BOOST_AUTO_TEST_CASE(ZeroRatioSplitData)
+TEST_CASE("ZeroRatioSplitData", "[SplitDataTest]")
 {
   mat input(2, 10);
   size_t count = 0; // Counter for unique sequential values.
   input.imbue([&count] () { return ++count; });
 
   const auto value = Split(input, 0, false);
-  BOOST_REQUIRE_EQUAL(std::get<0>(value).n_cols, 10); // Train data.
-  BOOST_REQUIRE_EQUAL(std::get<1>(value).n_cols, 0); // Test data.
+  REQUIRE(std::get<0>(value).n_cols == 10); // Train data.
+  REQUIRE(std::get<1>(value).n_cols == 0); // Test data.
 
   mat concat = arma::join_rows(std::get<0>(value), std::get<1>(value));
   // Order matters here.
   CheckMatrices(input, concat);
 }
 
-BOOST_AUTO_TEST_CASE(TotalRatioSplitData)
+TEST_CASE("TotalRatioSplitData", "[SplitDataTest]")
 {
   mat input(2, 10);
   size_t count = 0; // Counter for unique sequential values.
   input.imbue([&count] () { return ++count; });
 
   const auto value = Split(input, 1, false);
-  BOOST_REQUIRE_EQUAL(std::get<0>(value).n_cols, 0); // Train data.
-  BOOST_REQUIRE_EQUAL(std::get<1>(value).n_cols, 10); // Test data.
+  REQUIRE(std::get<0>(value).n_cols == 0); // Train data.
+  REQUIRE(std::get<1>(value).n_cols == 10); // Test data.
 
   mat concat = arma::join_rows(std::get<0>(value), std::get<1>(value));
   // Order matters here.
   CheckMatrices(input, concat);
 }
 
-BOOST_AUTO_TEST_CASE(SplitLabeledDataResultMat)
+TEST_CASE("SplitLabeledDataResultMat", "[SplitDataTest]")
 {
   mat input(2, 10);
   input.randu();
@@ -164,10 +162,10 @@ BOOST_AUTO_TEST_CASE(SplitLabeledDataResultMat)
       input.n_cols);
 
   const auto value = Split(input, labels, 0.2);
-  BOOST_REQUIRE_EQUAL(std::get<0>(value).n_cols, 8);
-  BOOST_REQUIRE_EQUAL(std::get<1>(value).n_cols, 2);
-  BOOST_REQUIRE_EQUAL(std::get<2>(value).n_cols, 8);
-  BOOST_REQUIRE_EQUAL(std::get<3>(value).n_cols, 2);
+  REQUIRE(std::get<0>(value).n_cols == 8);
+  REQUIRE(std::get<1>(value).n_cols == 2);
+  REQUIRE(std::get<2>(value).n_cols == 8);
+  REQUIRE(std::get<3>(value).n_cols == 2);
 
   CompareData(input, std::get<0>(value), std::get<2>(value));
   CompareData(input, std::get<1>(value), std::get<3>(value));
@@ -180,21 +178,21 @@ BOOST_AUTO_TEST_CASE(SplitLabeledDataResultMat)
 /**
  * The same test as above, but on a larger dataset.
  */
-BOOST_AUTO_TEST_CASE(SplitDataLargerTest)
+TEST_CASE("SplitDataLargerTest", "[SplitDataTest]")
 {
   size_t count = 0;
   mat input(10, 497);
   input.imbue([&count] () { return ++count; });
 
   const auto value = Split(input, 0.3);
-  BOOST_REQUIRE_EQUAL(std::get<0>(value).n_cols, 497 - size_t(0.3 * 497));
-  BOOST_REQUIRE_EQUAL(std::get<1>(value).n_cols, size_t(0.3 * 497));
+  REQUIRE(std::get<0>(value).n_cols == 497 - size_t(0.3 * 497));
+  REQUIRE(std::get<1>(value).n_cols == size_t(0.3 * 497));
 
   mat concat = arma::join_rows(std::get<0>(value), std::get<1>(value));
   CheckMatEqual(input, concat);
 }
 
-BOOST_AUTO_TEST_CASE(SplitLabeledDataLargerTest)
+TEST_CASE("SplitLabeledDataLargerTest", "[SplitDataTest]")
 {
   mat input(10, 497);
   input.randu();
@@ -204,15 +202,13 @@ BOOST_AUTO_TEST_CASE(SplitLabeledDataLargerTest)
       input.n_cols);
 
   const auto value = Split(input, labels, 0.3);
-  BOOST_REQUIRE_EQUAL(std::get<0>(value).n_cols, 497 - size_t(0.3 * 497));
-  BOOST_REQUIRE_EQUAL(std::get<1>(value).n_cols, size_t(0.3 * 497));
-  BOOST_REQUIRE_EQUAL(std::get<2>(value).n_cols, 497 - size_t(0.3 * 497));
-  BOOST_REQUIRE_EQUAL(std::get<3>(value).n_cols, size_t(0.3 * 497));
+  REQUIRE(std::get<0>(value).n_cols == 497 - size_t(0.3 * 497));
+  REQUIRE(std::get<1>(value).n_cols == size_t(0.3 * 497));
+  REQUIRE(std::get<2>(value).n_cols == 497 - size_t(0.3 * 497));
+  REQUIRE(std::get<3>(value).n_cols == size_t(0.3 * 497));
 
   CompareData(input, std::get<0>(value), std::get<2>(value));
   CompareData(input, std::get<1>(value), std::get<3>(value));
 
   CheckDuplication(std::get<2>(value), std::get<3>(value));
 }
-
-BOOST_AUTO_TEST_SUITE_END();
