@@ -19,82 +19,78 @@
 #include <mlpack/core/tree/cover_tree.hpp>
 #include <mlpack/core/tree/rectangle_tree.hpp>
 
-#include <boost/test/unit_test.hpp>
-#include "test_tools.hpp"
+#include "catch.hpp"
+#include "test_catch_tools.hpp"
 
 using namespace mlpack;
 using namespace mlpack::tree;
 using namespace mlpack::metric;
 
-BOOST_AUTO_TEST_SUITE(TreeTraitsTest);
-
 // Be careful!  When writing new tests, always get the boolean value of each
 // trait and store it in a temporary, because the Boost unit test macros do
 // weird things and will cause bizarre problems.
 
 // Test the defaults.
-BOOST_AUTO_TEST_CASE(DefaultsTraitsTest)
+TEST_CASE("DefaultsTraitsTest", "[TreeTraitsTestt]")
 {
   // An irrelevant non-tree type class is used here so that the default
   // implementation of TreeTraits is chosen.
   bool b = TreeTraits<int>::HasOverlappingChildren;
-  BOOST_REQUIRE_EQUAL(b, true);
+  REQUIRE(b == true);
   b = TreeTraits<int>::HasSelfChildren;
-  BOOST_REQUIRE_EQUAL(b, false);
+  REQUIRE(b == false);
   b = TreeTraits<int>::FirstPointIsCentroid;
-  BOOST_REQUIRE_EQUAL(b, false);
+  REQUIRE(b == false);
   b = TreeTraits<int>::RearrangesDataset;
-  BOOST_REQUIRE_EQUAL(b, false);
+  REQUIRE(b == false);
   b = TreeTraits<int>::BinaryTree;
-  BOOST_REQUIRE_EQUAL(b, false);
+  REQUIRE(b == false);
 }
 
 // Test the binary space tree traits.
-BOOST_AUTO_TEST_CASE(BinarySpaceTreeTraitsTest)
+TEST_CASE("BinarySpaceTreeTraitsTest", "[TreeTraitsTestt]")
 {
   typedef BinarySpaceTree<LMetric<2, false>> TreeType;
 
   // Children are non-overlapping.
   bool b = TreeTraits<TreeType>::HasOverlappingChildren;
-  BOOST_REQUIRE_EQUAL(b, false);
+  REQUIRE(b == false);
 
   // Points are not contained at multiple levels.
   b = TreeTraits<TreeType>::HasSelfChildren;
-  BOOST_REQUIRE_EQUAL(b, false);
+  REQUIRE(b == false);
 
   // The first point is not the centroid.
   b = TreeTraits<TreeType>::FirstPointIsCentroid;
-  BOOST_REQUIRE_EQUAL(b, false);
+  REQUIRE(b == false);
 
   // The dataset gets rearranged at build time.
   b = TreeTraits<TreeType>::RearrangesDataset;
-  BOOST_REQUIRE_EQUAL(b, true);
+  REQUIRE(b == true);
 
   // It is a binary tree.
   b = TreeTraits<TreeType>::BinaryTree;
-  BOOST_REQUIRE_EQUAL(b, true);
+  REQUIRE(b == true);
 }
 
 // Test the cover tree traits.
-BOOST_AUTO_TEST_CASE(CoverTreeTraitsTest)
+TEST_CASE("CoverTreeTraitsTest", "[TreeTraitsTestt]")
 {
   // Children may be overlapping.
   bool b = TreeTraits<CoverTree<>>::HasOverlappingChildren;
-  BOOST_REQUIRE_EQUAL(b, true);
+  REQUIRE(b == true);
 
   // The cover tree has self-children.
   b = TreeTraits<CoverTree<>>::HasSelfChildren;
-  BOOST_REQUIRE_EQUAL(b, true);
+  REQUIRE(b == true);
 
   // The first point is the center of the node.
   b = TreeTraits<CoverTree<>>::FirstPointIsCentroid;
-  BOOST_REQUIRE_EQUAL(b, true);
+  REQUIRE(b == true);
 
   b = TreeTraits<CoverTree<>>::RearrangesDataset;
-  BOOST_REQUIRE_EQUAL(b, false);
+  REQUIRE(b == false);
 
   b = TreeTraits<CoverTree<>>::BinaryTree;
-  BOOST_REQUIRE_EQUAL(b, false); // Not necessarily binary.
+  REQUIRE(b == false); // Not necessarily binary.
 }
-
-BOOST_AUTO_TEST_SUITE_END();
