@@ -14,8 +14,8 @@
 #include <mlpack/methods/neighbor_search/neighbor_search.hpp>
 #include <mlpack/core/tree/binary_space_tree.hpp>
 
-#include <boost/test/unit_test.hpp>
-#include "test_tools.hpp"
+#include "catch.hpp"
+#include "test_catch_tools.hpp"
 
 using namespace mlpack;
 using namespace mlpack::math;
@@ -24,112 +24,109 @@ using namespace mlpack::neighbor;
 using namespace mlpack::metric;
 using namespace mlpack::bound;
 
-BOOST_AUTO_TEST_SUITE(VantagePointTreeTest);
-
-BOOST_AUTO_TEST_CASE(VPTreeTraitsTest)
+TEST_CASE("VPTreeTraitsTest", "[VantagePointTreeTest]")
 {
   typedef VPTree<EuclideanDistance, EmptyStatistic, arma::mat> TreeType;
 
   bool b = TreeTraits<TreeType>::HasOverlappingChildren;
-  BOOST_REQUIRE_EQUAL(b, true);
+  REQUIRE(b == true);
   b = TreeTraits<TreeType>::FirstPointIsCentroid;
-  BOOST_REQUIRE_EQUAL(b, false);
+  REQUIRE(b == false);
   b = TreeTraits<TreeType>::HasSelfChildren;
-  BOOST_REQUIRE_EQUAL(b, false);
+  REQUIRE(b == false);
   b = TreeTraits<TreeType>::RearrangesDataset;
-  BOOST_REQUIRE_EQUAL(b, true);
+  REQUIRE(b == true);
   b = TreeTraits<TreeType>::BinaryTree;
-  BOOST_REQUIRE_EQUAL(b, true);
+  REQUIRE(b == true);
 }
 
-BOOST_AUTO_TEST_CASE(HollowBallBoundTest)
+TEST_CASE("HollowBallBoundTest", "[VantagePointTreeTest]")
 {
   HollowBallBound<EuclideanDistance> b(2, 4, arma::vec("1.0 2.0 3.0 4.0 5.0"));
 
-  BOOST_REQUIRE_EQUAL(b.Contains(arma::vec("1.0 2.0 3.0 7.0 5.0")), true);
+  REQUIRE(b.Contains(arma::vec("1.0 2.0 3.0 7.0 5.0")) == true);
 
-  BOOST_REQUIRE_EQUAL(b.Contains(arma::vec("1.0 2.0 3.0 9.0 5.0")), false);
+  REQUIRE(b.Contains(arma::vec("1.0 2.0 3.0 9.0 5.0")) == false);
 
-  BOOST_REQUIRE_EQUAL(b.Contains(arma::vec("1.0 2.0 3.0 5.0 5.0")), false);
+  REQUIRE(b.Contains(arma::vec("1.0 2.0 3.0 5.0 5.0")) == false);
 
   HollowBallBound<EuclideanDistance> b2(0.5, 1,
       arma::vec("1.0 2.0 3.0 7.0 5.0"));
-  BOOST_REQUIRE_EQUAL(b.Contains(b2), true);
+  REQUIRE(b.Contains(b2) == true);
 
   b2 = HollowBallBound<EuclideanDistance>(2.5, 3.5,
       arma::vec("1.0 2.0 3.0 4.5 5.0"));
-  BOOST_REQUIRE_EQUAL(b.Contains(b2), true);
+  REQUIRE(b.Contains(b2) == true);
 
   b2 = HollowBallBound<EuclideanDistance>(2.0, 3.5,
       arma::vec("1.0 2.0 3.0 4.5 5.0"));
-  BOOST_REQUIRE_EQUAL(b.Contains(b2), false);
+  REQUIRE(b.Contains(b2) == false);
 
-  BOOST_REQUIRE_CLOSE(b.MinDistance(arma::vec("1.0 2.0 8.0 4.0 5.0")), 1.0,
-      1e-5);
-  BOOST_REQUIRE_CLOSE(b.MinDistance(arma::vec("1.0 2.0 4.0 4.0 5.0")), 1.0,
-      1e-5);
-  BOOST_REQUIRE_CLOSE(b.MinDistance(arma::vec("1.0 2.0 3.0 4.0 5.0")), 2.0,
-      1e-5);
-  BOOST_REQUIRE_CLOSE(b.MinDistance(arma::vec("1.0 2.0 5.0 4.0 5.0")), 0.0,
-      1e-5);
-  BOOST_REQUIRE_CLOSE(b.MinDistance(arma::vec("5.0 2.0 3.0 4.0 5.0")), 0.0,
-      1e-5);
-  BOOST_REQUIRE_CLOSE(b.MinDistance(arma::vec("3.0 2.0 3.0 4.0 5.0")), 0.0,
-      1e-5);
-
-  BOOST_REQUIRE_CLOSE(b.MaxDistance(arma::vec("1.0 2.0 4.0 4.0 5.0")), 5.0,
-      1e-5);
-  BOOST_REQUIRE_CLOSE(b.MaxDistance(arma::vec("1.0 2.0 8.0 4.0 5.0")), 9.0,
-      1e-5);
-  BOOST_REQUIRE_CLOSE(b.MaxDistance(arma::vec("1.0 2.0 3.0 4.0 5.0")), 4.0,
-      1e-5);
+  REQUIRE(b.MinDistance(arma::vec("1.0 2.0 8.0 4.0 5.0")) ==
+      Approx(1.0).epsilon(1e-7));
+  REQUIRE(b.MinDistance(arma::vec("1.0 2.0 4.0 4.0 5.0")) ==
+      Approx(1.0).epsilon(1e-7));
+  REQUIRE(b.MinDistance(arma::vec("1.0 2.0 3.0 4.0 5.0")) ==
+      Approx(2.0).epsilon(1e-7));
+  REQUIRE(b.MinDistance(arma::vec("1.0 2.0 5.0 4.0 5.0")) ==
+      Approx(0.0).epsilon(1e-7));
+  REQUIRE(b.MinDistance(arma::vec("5.0 2.0 3.0 4.0 5.0")) ==
+      Approx(0.0).epsilon(1e-7));
+  REQUIRE(b.MinDistance(arma::vec("3.0 2.0 3.0 4.0 5.0")) ==
+      Approx(0.0).epsilon(1e-7));
+  REQUIRE(b.MaxDistance(arma::vec("1.0 2.0 4.0 4.0 5.0")) ==
+      Approx(5.0).epsilon(1e-7));
+  REQUIRE(b.MaxDistance(arma::vec("1.0 2.0 8.0 4.0 5.0")) ==
+      Approx(9.0).epsilon(1e-7));
+  REQUIRE(b.MaxDistance(arma::vec("1.0 2.0 3.0 4.0 5.0")) ==
+      Approx(4.0).epsilon(1e-7));
 
   b2 = HollowBallBound<EuclideanDistance>(3, 4,
       arma::vec("1.0 2.0 3.0 5.0 5.0"));
-  BOOST_REQUIRE_CLOSE(b.MinDistance(b2), 0.0, 1e-5);
+  REQUIRE(b.MinDistance(b2) == Approx(0.0).epsilon(1e-7));
 
   b2 = HollowBallBound<EuclideanDistance>(1, 2,
       arma::vec("1.0 2.0 3.0 4.0 5.0"));
-  BOOST_REQUIRE_CLOSE(b.MinDistance(b2), 0.0, 1e-5);
+  REQUIRE(b.MinDistance(b2) == Approx(0.0).epsilon(1e-7));
 
   b2 = HollowBallBound<EuclideanDistance>(0.5, 1.0,
       arma::vec("1.0 2.5 3.0 4.0 5.0"));
-  BOOST_REQUIRE_CLOSE(b.MinDistance(b2), 0.5, 1e-5);
+  REQUIRE(b.MinDistance(b2) == Approx(0.5).epsilon(1e-7));
 
   b2 = HollowBallBound<EuclideanDistance>(0.5, 1.0,
       arma::vec("1.0 8.0 3.0 4.0 5.0"));
-  BOOST_REQUIRE_CLOSE(b.MinDistance(b2), 1.0, 1e-5);
+  REQUIRE(b.MinDistance(b2) == Approx(1.0).epsilon(1e-7));
 
   b2 = HollowBallBound<EuclideanDistance>(0.5, 2.0,
       arma::vec("1.0 8.0 3.0 4.0 5.0"));
-  BOOST_REQUIRE_CLOSE(b.MinDistance(b2), 0.0, 1e-5);
+  REQUIRE(b.MinDistance(b2) == Approx(0.0).epsilon(1e-7));
 
   b2 = HollowBallBound<EuclideanDistance>(0.5, 2.0,
       arma::vec("1.0 8.0 3.0 4.0 5.0"));
-  BOOST_REQUIRE_CLOSE(b.MaxDistance(b2), 12.0, 1e-5);
+  REQUIRE(b.MaxDistance(b2) == Approx(12.0).epsilon(1e-7));
 
   b2 = HollowBallBound<EuclideanDistance>(0.5, 2.0,
       arma::vec("1.0 3.0 3.0 4.0 5.0"));
-  BOOST_REQUIRE_CLOSE(b.MaxDistance(b2), 7.0, 1e-5);
+  REQUIRE(b.MaxDistance(b2) == Approx(7.0).epsilon(1e-7));
 
   HollowBallBound<EuclideanDistance> b1 = b;
   b2 = HollowBallBound<EuclideanDistance>(1.0, 2.0,
       arma::vec("1.0 2.5 3.0 4.0 5.0"));
 
   b1 |= b2;
-  BOOST_REQUIRE_CLOSE(b1.InnerRadius(), 0.5, 1e-5);
+  REQUIRE(b1.InnerRadius() == Approx(0.5).epsilon(1e-7));
 
   b1 = b;
   b2 = HollowBallBound<EuclideanDistance>(0.5, 2.0,
       arma::vec("1.0 3.0 3.0 4.0 5.0"));
   b1 |= b2;
-  BOOST_REQUIRE_CLOSE(b1.InnerRadius(), 0.0, 1e-5);
+  REQUIRE(b1.InnerRadius() == Approx(0.0).epsilon(1e-7));
 
   b1 = b;
   b2 = HollowBallBound<EuclideanDistance>(0.5, 4.0,
       arma::vec("1.0 3.0 3.0 4.0 5.0"));
   b1 |= b2;
-  BOOST_REQUIRE_CLOSE(b1.OuterRadius(), 5.0, 1e-5);
+  REQUIRE(b1.OuterRadius() == Approx(5.0).epsilon(1e-7));
 }
 
 template<typename TreeType>
@@ -139,7 +136,7 @@ void CheckBound(TreeType& tree)
   if (tree.IsLeaf())
   {
     // Ensure that the bound contains all descendant points.
-    for (size_t i = 0; i < tree.NumPoints(); i++)
+    for (size_t i = 0; i < tree.NumPoints(); ++i)
     {
       ElemType dist = tree.Bound().Metric().Evaluate(tree.Bound().Center(),
           tree.Dataset().col(tree.Point(i)));
@@ -147,17 +144,17 @@ void CheckBound(TreeType& tree)
           tree.Bound().HollowCenter(),
           tree.Dataset().col(tree.Point(i)));
 
-      BOOST_REQUIRE_LE(tree.Bound().InnerRadius(), hollowDist  *
+      REQUIRE(tree.Bound().InnerRadius() <= hollowDist  *
           (1.0 + 10.0 * std::numeric_limits<ElemType>::epsilon()));
 
-      BOOST_REQUIRE_LE(dist, tree.Bound().OuterRadius() *
+      REQUIRE(dist <= tree.Bound().OuterRadius() *
           (1.0 + 10.0 * std::numeric_limits<ElemType>::epsilon()));
     }
   }
   else
   {
     // Ensure that the bound contains all descendant points.
-    for (size_t i = 0; i < tree.NumDescendants(); i++)
+    for (size_t i = 0; i < tree.NumDescendants(); ++i)
     {
       ElemType dist = tree.Bound().Metric().Evaluate(tree.Bound().Center(),
           tree.Dataset().col(tree.Descendant(i)));
@@ -165,10 +162,10 @@ void CheckBound(TreeType& tree)
           tree.Bound().HollowCenter(),
           tree.Dataset().col(tree.Descendant(i)));
 
-      BOOST_REQUIRE_LE(tree.Bound().InnerRadius(), hollowDist  *
+      REQUIRE(tree.Bound().InnerRadius() <= hollowDist  *
           (1.0 + 10.0 * std::numeric_limits<ElemType>::epsilon()));
 
-      BOOST_REQUIRE_LE(dist, tree.Bound().OuterRadius() *
+      REQUIRE(dist <= tree.Bound().OuterRadius() *
           (1.0 + 10.0 * std::numeric_limits<ElemType>::epsilon()));
     }
 
@@ -177,7 +174,7 @@ void CheckBound(TreeType& tree)
   }
 }
 
-BOOST_AUTO_TEST_CASE(VPTreeBoundTest)
+TEST_CASE("VPTreeBoundTest", "[VantagePointTreeTest]")
 {
   typedef VPTree<EuclideanDistance, EmptyStatistic, arma::mat> TreeType;
 
@@ -188,7 +185,7 @@ BOOST_AUTO_TEST_CASE(VPTreeBoundTest)
   CheckBound(tree);
 }
 
-BOOST_AUTO_TEST_CASE(VPTreeTest)
+TEST_CASE("VPTreeTest", "[VantagePointTreeTest]")
 {
   typedef VPTree<EuclideanDistance, EmptyStatistic, arma::mat> TreeType;
 
@@ -217,21 +214,21 @@ BOOST_AUTO_TEST_CASE(VPTreeTest)
     const arma::mat& treeset = root.Dataset();
 
     // Ensure the size of the tree is correct.
-    BOOST_REQUIRE_EQUAL(root.NumDescendants(), size);
+    REQUIRE(root.NumDescendants() == size);
 
     // Check the forward and backward mappings for correctness.
-    for (size_t i = 0; i < size; i++)
+    for (size_t i = 0; i < size; ++i)
     {
-      for (size_t j = 0; j < dimensions; j++)
+      for (size_t j = 0; j < dimensions; ++j)
       {
-        BOOST_REQUIRE_EQUAL(treeset(j, i), dataset(j, newToOld[i]));
-        BOOST_REQUIRE_EQUAL(treeset(j, oldToNew[i]), dataset(j, i));
+        REQUIRE(treeset(j, i) == dataset(j, newToOld[i]));
+        REQUIRE(treeset(j, oldToNew[i]) == dataset(j, i));
       }
     }
   }
 }
 
-BOOST_AUTO_TEST_CASE(SingleTreeTraverserTest)
+TEST_CASE("SingleVPTreeTraverserTest", "[VantagePointTreeTest]")
 {
   arma::mat dataset;
   dataset.randu(8, 1000); // 1000 points in 8 dimensions.
@@ -251,14 +248,14 @@ BOOST_AUTO_TEST_CASE(SingleTreeTraverserTest)
 
   knn2.Search(5, neighbors2, distances2);
 
-  for (size_t i = 0; i < neighbors1.size(); i++)
+  for (size_t i = 0; i < neighbors1.size(); ++i)
   {
-    BOOST_REQUIRE_EQUAL(neighbors1[i], neighbors2[i]);
-    BOOST_REQUIRE_EQUAL(distances1[i], distances2[i]);
+    REQUIRE(neighbors1[i] == neighbors2[i]);
+    REQUIRE(distances1[i] == distances2[i]);
   }
 }
 
-BOOST_AUTO_TEST_CASE(DualTreeTraverserTest)
+TEST_CASE("DualVPTreeTraverserTest", "[VantagePointTreeTest]")
 {
   arma::mat dataset;
   dataset.randu(8, 1000); // 1000 points in 8 dimensions.
@@ -278,11 +275,9 @@ BOOST_AUTO_TEST_CASE(DualTreeTraverserTest)
 
   knn2.Search(5, neighbors2, distances2);
 
-  for (size_t i = 0; i < neighbors1.size(); i++)
+  for (size_t i = 0; i < neighbors1.size(); ++i)
   {
-    BOOST_REQUIRE_EQUAL(neighbors1[i], neighbors2[i]);
-    BOOST_REQUIRE_EQUAL(distances1[i], distances2[i]);
+    REQUIRE(neighbors1[i] == neighbors2[i]);
+    REQUIRE(distances1[i] == distances2[i]);
   }
 }
-
-BOOST_AUTO_TEST_SUITE_END();
